@@ -154,6 +154,12 @@ public class FormatData_bg extends ListResourceBundle {
                "3. \u0442\u0440\u0438\u043c.",
                "4. \u0442\u0440\u0438\u043c.",
             };
+        final String[] metaValue_QuarterNarrows = new String[] {
+               "1",
+               "2",
+               "3",
+               "4",
+            };
         final String[] metaValue_AmPmMarkers = new String[] {
                "\u043f\u0440.\u043e\u0431.",
                "\u0441\u043b.\u043e\u0431.",
@@ -167,16 +173,10 @@ public class FormatData_bg extends ListResourceBundle {
                "\u0441\u043b.\u0425\u0440.",
             };
         final String[] metaValue_TimePatterns = new String[] {
-               "H:mm:ss '\u0447'. zzzz",
-               "H:mm:ss '\u0447'. z",
-               "H:mm:ss '\u0447'.",
-               "H:mm '\u0447'.",
-            };
-        final String[] metaValue_buddhist_QuarterNarrows = new String[] {
-               "1",
-               "2",
-               "3",
-               "4",
+               "H:mm:ss zzzz",
+               "H:mm:ss z",
+               "H:mm:ss",
+               "H:mm",
             };
         final String[] metaValue_java_time_buddhist_DatePatterns = new String[] {
                "EEEE, d MMMM y '\u0433'. G",
@@ -219,6 +219,7 @@ public class FormatData_bg extends ListResourceBundle {
                     "\u0441\u043b\u0435\u0434 \u0425\u0440\u0438\u0441\u0442\u0430",
                 }
             },
+            { "roc.QuarterNarrows", metaValue_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -271,6 +272,7 @@ public class FormatData_bg extends ListResourceBundle {
                     "",
                 }
             },
+            { "japanese.QuarterNarrows", metaValue_QuarterNarrows },
             { "calendarname.roc", "\u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440 \u043d\u0430 \u0420\u0435\u043f\u0443\u0431\u043b\u0438\u043a\u0430 \u041a\u0438\u0442\u0430\u0439" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
@@ -278,13 +280,6 @@ public class FormatData_bg extends ListResourceBundle {
             { "field.second", "\u0441\u0435\u043a\u0443\u043d\u0434\u0430" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "0.00\u00a0\u00a4",
-                    "#,##0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "\u0438\u0441\u043b\u044f\u043c\u0441\u043a\u0438 \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440" },
             { "japanese.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
@@ -295,22 +290,22 @@ public class FormatData_bg extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 \u0445\u0438\u043b'.'",
-                    "00 \u0445\u0438\u043b\u044f\u0434\u0438",
-                    "000 \u0445\u0438\u043b\u044f\u0434\u0438",
-                    "0 \u043c\u0438\u043b\u0438\u043e\u043d",
-                    "00 \u043c\u0438\u043b\u0438\u043e\u043d\u0430",
-                    "000 \u043c\u0438\u043b\u0438\u043e\u043d\u0430",
-                    "0 \u043c\u0438\u043b\u0438\u0430\u0440\u0434",
-                    "00 \u043c\u0438\u043b\u0438\u0430\u0440\u0434\u0430",
-                    "000 \u043c\u0438\u043b\u0438\u0430\u0440\u0434\u0430",
-                    "0 \u0442\u0440\u0438\u043b\u0438\u043e\u043d",
-                    "00 \u0442\u0440\u0438\u043b\u0438\u043e\u043d\u0430",
-                    "000 \u0442\u0440\u0438\u043b\u0438\u043e\u043d\u0430",
+                    "{one:0' '\u0445\u0438\u043b'.' other:0' '\u0445\u0438\u043b\u044f\u0434\u0438}",
+                    "{one:00' '\u0445\u0438\u043b\u044f\u0434\u0438 other:00' '\u0445\u0438\u043b\u044f\u0434\u0438}",
+                    "{one:000' '\u0445\u0438\u043b\u044f\u0434\u0438 other:000' '\u0445\u0438\u043b\u044f\u0434\u0438}",
+                    "{one:0' '\u043c\u0438\u043b\u0438\u043e\u043d other:0' '\u043c\u0438\u043b\u0438\u043e\u043d\u0430}",
+                    "{one:00' '\u043c\u0438\u043b\u0438\u043e\u043d\u0430 other:00' '\u043c\u0438\u043b\u0438\u043e\u043d\u0430}",
+                    "{one:000' '\u043c\u0438\u043b\u0438\u043e\u043d\u0430 other:000' '\u043c\u0438\u043b\u0438\u043e\u043d\u0430}",
+                    "{one:0' '\u043c\u0438\u043b\u0438\u0430\u0440\u0434 other:0' '\u043c\u0438\u043b\u0438\u0430\u0440\u0434\u0430}",
+                    "{one:00' '\u043c\u0438\u043b\u0438\u0430\u0440\u0434\u0430 other:00' '\u043c\u0438\u043b\u0438\u0430\u0440\u0434\u0430}",
+                    "{one:000' '\u043c\u0438\u043b\u0438\u0430\u0440\u0434\u0430 other:000' '\u043c\u0438\u043b\u0438\u0430\u0440\u0434\u0430}",
+                    "{one:0' '\u0442\u0440\u0438\u043b\u0438\u043e\u043d other:0' '\u0442\u0440\u0438\u043b\u0438\u043e\u043d\u0430}",
+                    "{one:00' '\u0442\u0440\u0438\u043b\u0438\u043e\u043d\u0430 other:00' '\u0442\u0440\u0438\u043b\u0438\u043e\u043d\u0430}",
+                    "{one:000' '\u0442\u0440\u0438\u043b\u0438\u043e\u043d\u0430 other:000' '\u0442\u0440\u0438\u043b\u0438\u043e\u043d\u0430}",
                 }
             },
+            { "buddhist.QuarterNarrows", metaValue_QuarterNarrows },
             { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
-            { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "standalone.QuarterNames", metaValue_QuarterNames },
             { "japanese.MonthNarrows", metaValue_MonthNarrows },
             { "islamic.QuarterAbbreviations", metaValue_QuarterAbbreviations },
@@ -326,6 +321,7 @@ public class FormatData_bg extends ListResourceBundle {
             { "Eras", metaValue_Eras },
             { "roc.DayNames", metaValue_DayNames },
             { "islamic.QuarterNames", metaValue_QuarterNames },
+            { "QuarterNarrows", metaValue_QuarterNarrows },
             { "islamic.abbreviated.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "field.weekday", "\u0434\u0435\u043d \u043e\u0442 \u0441\u0435\u0434\u043c\u0438\u0446\u0430\u0442\u0430" },
@@ -341,7 +337,7 @@ public class FormatData_bg extends ListResourceBundle {
             { "field.week", "\u0441\u0435\u0434\u043c\u0438\u0446\u0430" },
             { "buddhist.MonthNarrows", metaValue_MonthNarrows },
             { "buddhist.QuarterNames", metaValue_QuarterNames },
-            { "islamic.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
+            { "islamic.QuarterNarrows", metaValue_QuarterNarrows },
             { "roc.DayNarrows", metaValue_DayNarrows },
             { "roc.AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
@@ -351,18 +347,18 @@ public class FormatData_bg extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u00a0\u0445\u0438\u043b'.'",
-                    "00\u00a0\u0445\u0438\u043b'.'",
-                    "000\u00a0\u0445\u0438\u043b'.'",
-                    "0\u00a0\u043c\u043b\u043d'.'",
-                    "00\u00a0\u043c\u043b\u043d'.'",
-                    "000\u00a0\u043c\u043b\u043d'.'",
-                    "0\u00a0\u043c\u043b\u0440\u0434'.'",
-                    "00\u00a0\u043c\u043b\u0440\u0434'.'",
-                    "000\u00a0\u043c\u043b\u0440\u0434'.'",
-                    "0\u00a0\u0442\u0440\u043b\u043d'.'",
-                    "00\u00a0\u0442\u0440\u043b\u043d'.'",
-                    "000\u00a0\u0442\u0440\u043b\u043d'.'",
+                    "{one:0\u00a0\u0445\u0438\u043b'.' other:0\u00a0\u0445\u0438\u043b'.'}",
+                    "{one:00\u00a0\u0445\u0438\u043b'.' other:00\u00a0\u0445\u0438\u043b'.'}",
+                    "{one:000\u00a0\u0445\u0438\u043b'.' other:000\u00a0\u0445\u0438\u043b'.'}",
+                    "{one:0\u00a0\u043c\u043b\u043d'.' other:0\u00a0\u043c\u043b\u043d'.'}",
+                    "{one:00\u00a0\u043c\u043b\u043d'.' other:00\u00a0\u043c\u043b\u043d'.'}",
+                    "{one:000\u00a0\u043c\u043b\u043d'.' other:000\u00a0\u043c\u043b\u043d'.'}",
+                    "{one:0\u00a0\u043c\u043b\u0440\u0434'.' other:0\u00a0\u043c\u043b\u0440\u0434'.'}",
+                    "{one:00\u00a0\u043c\u043b\u0440\u0434'.' other:00\u00a0\u043c\u043b\u0440\u0434'.'}",
+                    "{one:000\u00a0\u043c\u043b\u0440\u0434'.' other:000\u00a0\u043c\u043b\u0440\u0434'.'}",
+                    "{one:0\u00a0\u0442\u0440\u043b\u043d'.' other:0\u00a0\u0442\u0440\u043b\u043d'.'}",
+                    "{one:00\u00a0\u0442\u0440\u043b\u043d'.' other:00\u00a0\u0442\u0440\u043b\u043d'.'}",
+                    "{one:000\u00a0\u0442\u0440\u043b\u043d'.' other:000\u00a0\u0442\u0440\u043b\u043d'.'}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -382,6 +378,14 @@ public class FormatData_bg extends ListResourceBundle {
             { "field.hour", "\u0447\u0430\u0441" },
             { "calendarname.buddhist", "\u0431\u0443\u0434\u0438\u0441\u0442\u043a\u0438 \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440" },
             { "standalone.MonthNames", metaValue_MonthNames },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "0.00\u00a0\u00a4",
+                    "#,##0%",
+                    "0.00\u00a0\u00a4;(0.00\u00a0\u00a4)",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
