@@ -81,23 +81,21 @@ public class FormatData_es_PR extends ListResourceBundle {
                "h:mm a",
             };
         final String[] metaValue_java_time_buddhist_DatePatterns = new String[] {
-               "G y MMMM d, EEEE",
-               "G y MMMM d",
+               "",
+               "",
                "MM/dd/y G",
                "MM/dd/yy GGGGG",
             };
         final String[] metaValue_buddhist_DatePatterns = new String[] {
-               "GGGG y MMMM d, EEEE",
-               "GGGG y MMMM d",
+               "",
+               "",
                "MM/dd/y GGGG",
                "MM/dd/yy G",
             };
         final Object[][] data = new Object[][] {
             { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
-            { "islamic.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
+            { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
             { "AmPmMarkers", metaValue_AmPmMarkers },
-            { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
-            { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "java.time.japanese.DatePatterns",
                 new String[] {
                     "EEEE, d 'de' MMMM 'de' y G",
@@ -107,8 +105,19 @@ public class FormatData_es_PR extends ListResourceBundle {
                 }
             },
             { "TimePatterns", metaValue_TimePatterns },
-            { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
+            { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
+            { "japanese.TimePatterns", metaValue_TimePatterns },
+            { "abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
+            { "japanese.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
+            { "buddhist.narrow.AmPmMarkers", metaValue_AmPmMarkers },
+            { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
+            { "buddhist.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
+            { "roc.AmPmMarkers", metaValue_AmPmMarkers },
+            { "islamic.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
+            { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
+            { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
+            { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "DatePatterns",
                 new String[] {
                     "EEEE, d 'de' MMMM 'de' y",
@@ -126,17 +135,9 @@ public class FormatData_es_PR extends ListResourceBundle {
                     "MM/dd/yy G",
                 }
             },
-            { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
             { "buddhist.TimePatterns", metaValue_TimePatterns },
-            { "japanese.TimePatterns", metaValue_TimePatterns },
-            { "abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
-            { "japanese.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
-            { "roc.narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "roc.TimePatterns", metaValue_TimePatterns },
-            { "buddhist.narrow.AmPmMarkers", metaValue_AmPmMarkers },
-            { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
-            { "buddhist.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "roc.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
         };
         return data;
