@@ -154,6 +154,12 @@ public class FormatData_gd extends ListResourceBundle {
                "C3",
                "C4",
             };
+        final String[] metaValue_QuarterNarrows = new String[] {
+               "1",
+               "2",
+               "3",
+               "4",
+            };
         final String[] metaValue_AmPmMarkers = new String[] {
                "m",
                "f",
@@ -164,12 +170,6 @@ public class FormatData_gd extends ListResourceBundle {
                "HH:mm:ss",
                "HH:mm",
             };
-        final String[] metaValue_buddhist_QuarterNarrows = new String[] {
-               "1",
-               "2",
-               "3",
-               "4",
-            };
         final String[] metaValue_java_time_buddhist_DatePatterns = new String[] {
                "EEEE, d'mh' MMMM y G",
                "d'mh' MMMM y G",
@@ -197,6 +197,12 @@ public class FormatData_gd extends ListResourceBundle {
                "M\u00edngu\u00f3",
             };
         final String metaValue_calendarname_gregorian = "Am M\u00ecosachan Griogarach";
+        final String[] metaValue_arabext_NumberPatterns = new String[] {
+               "#,##0.###",
+               "\u00a4\u00a0#,##0.00",
+               "#,##0%",
+               "",
+            };
         final String[] metaValue_brah_NumberElements = new String[] {
                ".",
                ",",
@@ -210,11 +216,376 @@ public class FormatData_gd extends ListResourceBundle {
                "\u221e",
                "NaN",
             };
+        final String[] metaValue_fullwide_NumberPatterns = new String[] {
+               "#,##0.###",
+               "\u00a4#,##0.00",
+               "#,##0%",
+               "\u00a4#,##0.00;(\u00a4#,##0.00)",
+            };
         final Object[][] data = new Object[][] {
             { "MonthNames", metaValue_MonthNames },
-            { "field.year", "bliadhna" },
             { "rohg.NumberElements", metaValue_brah_NumberElements },
             { "calendarname.islamic-umalqura", "Am M\u00ecosachan Ioslamach (Umm al-Qura)" },
+            { "osma.NumberPatterns", metaValue_arabext_NumberPatterns },
+            { "roc.QuarterNames", metaValue_QuarterNames },
+            { "lana.NumberElements",
+                new String[] {
+                    ".",
+                    ",",
+                    ";",
+                    "%",
+                    "\u1a80",
+                    "#",
+                    "-",
+                    "E",
+                    "\u2030",
+                    "\u221e",
+                    "NaN",
+                }
+            },
+            { "calendarname.islamic-civil", "Am M\u00ecosachan Ioslamach (cl\u00e0rach, linn s\u00ecobhalta)" },
+            { "talu.NumberElements",
+                new String[] {
+                    ".",
+                    ",",
+                    ";",
+                    "%",
+                    "\u19d0",
+                    "#",
+                    "-",
+                    "E",
+                    "\u2030",
+                    "\u221e",
+                    "NaN",
+                }
+            },
+            { "gonm.NumberPatterns", metaValue_arabext_NumberPatterns },
+            { "abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
+            { "mtei.NumberElements",
+                new String[] {
+                    ".",
+                    ",",
+                    ";",
+                    "%",
+                    "\uabf0",
+                    "#",
+                    "-",
+                    "E",
+                    "\u2030",
+                    "\u221e",
+                    "NaN",
+                }
+            },
+            { "japanese.MonthNames", metaValue_MonthNames },
+            { "standalone.DayAbbreviations", metaValue_DayAbbreviations },
+            { "islamic.DayNames", metaValue_DayNames },
+            { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "cakm.NumberPatterns", metaValue_arabext_NumberPatterns },
+            { "DateTimePatterns",
+                new String[] {
+                    "{1} {0}",
+                    "{1} {0}",
+                    "{1} {0}",
+                    "{1} {0}",
+                }
+            },
+            { "narrow.AmPmMarkers", metaValue_AmPmMarkers },
+            { "latn.NumberElements", metaValue_brah_NumberElements },
+            { "guru.NumberElements",
+                new String[] {
+                    ".",
+                    ",",
+                    ";",
+                    "%",
+                    "\u0a66",
+                    "#",
+                    "-",
+                    "E",
+                    "\u2030",
+                    "\u221e",
+                    "NaN",
+                }
+            },
+            { "field.minute", "mionaid" },
+            { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
+            { "bali.NumberPatterns", metaValue_arabext_NumberPatterns },
+            { "standalone.MonthNarrows", metaValue_MonthNarrows },
+            { "cham.NumberElements",
+                new String[] {
+                    ".",
+                    ",",
+                    ";",
+                    "%",
+                    "\uaa50",
+                    "#",
+                    "-",
+                    "E",
+                    "\u2030",
+                    "\u221e",
+                    "NaN",
+                }
+            },
+            { "japanese.QuarterNarrows", metaValue_QuarterNarrows },
+            { "saur.NumberPatterns", metaValue_arabext_NumberPatterns },
+            { "arab.NumberElements",
+                new String[] {
+                    "\u066b",
+                    "\u066c",
+                    "\u061b",
+                    "\u066a",
+                    "\u0660",
+                    "#",
+                    "\u061c-",
+                    "\u0627\u0633",
+                    "\u0609",
+                    "\u221e",
+                    "NaN",
+                }
+            },
+            { "beng.NumberPatterns", metaValue_arabext_NumberPatterns },
+            { "shrd.NumberElements", metaValue_brah_NumberElements },
+            { "takr.NumberElements", metaValue_brah_NumberElements },
+            { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
+            { "deva.NumberElements",
+                new String[] {
+                    ".",
+                    ",",
+                    ";",
+                    "%",
+                    "\u0966",
+                    "#",
+                    "-",
+                    "E",
+                    "\u2030",
+                    "\u221e",
+                    "NaN",
+                }
+            },
+            { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "sund.NumberPatterns", metaValue_arabext_NumberPatterns },
+            { "arabext.NumberPatterns", metaValue_arabext_NumberPatterns },
+            { "field.second", "diog" },
+            { "vaii.NumberPatterns", metaValue_arabext_NumberPatterns },
+            { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
+            { "calendarname.islamic", "Am M\u00ecosachan Ioslamach" },
+            { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
+            { "buddhist.TimePatterns", metaValue_TimePatterns },
+            { "brah.NumberElements", metaValue_brah_NumberElements },
+            { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "gong.NumberPatterns", metaValue_arabext_NumberPatterns },
+            { "olck.NumberElements",
+                new String[] {
+                    ".",
+                    ",",
+                    ";",
+                    "%",
+                    "\u1c50",
+                    "#",
+                    "-",
+                    "E",
+                    "\u2030",
+                    "\u221e",
+                    "NaN",
+                }
+            },
+            { "japanese.MonthNarrows", metaValue_MonthNarrows },
+            { "tibt.NumberPatterns", metaValue_arabext_NumberPatterns },
+            { "khmr.NumberPatterns", metaValue_arabext_NumberPatterns },
+            { "islamic.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "roc.DayAbbreviations", metaValue_DayAbbreviations },
+            { "orya.NumberPatterns", metaValue_arabext_NumberPatterns },
+            { "mymrshan.NumberElements",
+                new String[] {
+                    ".",
+                    ",",
+                    ";",
+                    "%",
+                    "\u1090",
+                    "#",
+                    "-",
+                    "E",
+                    "\u2030",
+                    "\u221e",
+                    "NaN",
+                }
+            },
+            { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
+            { "java.NumberElements",
+                new String[] {
+                    ".",
+                    ",",
+                    ";",
+                    "%",
+                    "\ua9d0",
+                    "#",
+                    "-",
+                    "E",
+                    "\u2030",
+                    "\u221e",
+                    "NaN",
+                }
+            },
+            { "TimePatterns", metaValue_TimePatterns },
+            { "islamic.DayNarrows", metaValue_DayNarrows },
+            { "roc.narrow.Eras", metaValue_java_time_roc_Eras },
+            { "laoo.NumberElements",
+                new String[] {
+                    ".",
+                    ",",
+                    ";",
+                    "%",
+                    "\u0ed0",
+                    "#",
+                    "-",
+                    "E",
+                    "\u2030",
+                    "\u221e",
+                    "NaN",
+                }
+            },
+            { "sund.NumberElements",
+                new String[] {
+                    ".",
+                    ",",
+                    ";",
+                    "%",
+                    "\u1bb0",
+                    "#",
+                    "-",
+                    "E",
+                    "\u2030",
+                    "\u221e",
+                    "NaN",
+                }
+            },
+            { "telu.NumberPatterns", metaValue_arabext_NumberPatterns },
+            { "buddhist.narrow.AmPmMarkers", metaValue_AmPmMarkers },
+            { "kali.NumberElements",
+                new String[] {
+                    ".",
+                    ",",
+                    ";",
+                    "%",
+                    "\ua900",
+                    "#",
+                    "-",
+                    "E",
+                    "\u2030",
+                    "\u221e",
+                    "NaN",
+                }
+            },
+            { "roc.DayNames", metaValue_DayNames },
+            { "QuarterNarrows", metaValue_QuarterNarrows },
+            { "lanatham.NumberPatterns", metaValue_arabext_NumberPatterns },
+            { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
+            { "buddhist.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "mong.NumberPatterns", metaValue_arabext_NumberPatterns },
+            { "tamldec.NumberPatterns", metaValue_arabext_NumberPatterns },
+            { "mymr.NumberPatterns", metaValue_arabext_NumberPatterns },
+            { "nkoo.NumberElements",
+                new String[] {
+                    ".",
+                    ",",
+                    ";",
+                    "%",
+                    "\u07c0",
+                    "#",
+                    "-",
+                    "E",
+                    "\u2030",
+                    "\u221e",
+                    "NaN",
+                }
+            },
+            { "cakm.NumberElements", metaValue_brah_NumberElements },
+            { "tibt.NumberElements",
+                new String[] {
+                    ".",
+                    ",",
+                    ";",
+                    "%",
+                    "\u0f20",
+                    "#",
+                    "-",
+                    "E",
+                    "\u2030",
+                    "\u221e",
+                    "NaN",
+                }
+            },
+            { "DayNames", metaValue_DayNames },
+            { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
+            { "roc.MonthNames", metaValue_MonthNames },
+            { "sora.NumberElements", metaValue_brah_NumberElements },
+            { "gujr.NumberElements",
+                new String[] {
+                    ".",
+                    ",",
+                    ";",
+                    "%",
+                    "\u0ae6",
+                    "#",
+                    "-",
+                    "E",
+                    "\u2030",
+                    "\u221e",
+                    "NaN",
+                }
+            },
+            { "buddhist.MonthNarrows", metaValue_MonthNarrows },
+            { "limb.NumberElements",
+                new String[] {
+                    ".",
+                    ",",
+                    ";",
+                    "%",
+                    "\u1946",
+                    "#",
+                    "-",
+                    "E",
+                    "\u2030",
+                    "\u221e",
+                    "NaN",
+                }
+            },
+            { "roc.DayNarrows", metaValue_DayNarrows },
+            { "shrd.NumberPatterns", metaValue_arabext_NumberPatterns },
+            { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
+            { "mlym.NumberPatterns", metaValue_arabext_NumberPatterns },
+            { "calendarname.gregorian", metaValue_calendarname_gregorian },
+            { "timezone.regionFormat.daylight", "T\u00ecde samhraidh: {0}" },
+            { "DatePatterns",
+                new String[] {
+                    "EEEE, d'mh' MMMM y",
+                    "d'mh' MMMM y",
+                    "d MMM y",
+                    "dd/MM/y",
+                }
+            },
+            { "islamic.TimePatterns", metaValue_TimePatterns },
+            { "japanese.DateTimePatterns", metaValue_japanese_DateTimePatterns },
+            { "MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "standalone.DayNames", metaValue_DayNames },
+            { "vaii.NumberElements",
+                new String[] {
+                    ".",
+                    ",",
+                    ";",
+                    "%",
+                    "\ua620",
+                    "#",
+                    "-",
+                    "E",
+                    "\u2030",
+                    "\u221e",
+                    "NaN",
+                }
+            },
+            { "QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "calendarname.gregory", metaValue_calendarname_gregorian },
+            { "field.year", "bliadhna" },
             { "arabext.NumberElements",
                 new String[] {
                     "\u066b",
@@ -234,25 +605,10 @@ public class FormatData_gd extends ListResourceBundle {
             { "AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.japanese.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "standalone.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "roc.QuarterNames", metaValue_QuarterNames },
-            { "lana.NumberElements",
-                new String[] {
-                    ".",
-                    ",",
-                    ";",
-                    "%",
-                    "\u1a80",
-                    "#",
-                    "-",
-                    "E",
-                    "\u2030",
-                    "\u221e",
-                    "NaN",
-                }
-            },
+            { "mtei.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "roc.MonthNarrows", metaValue_MonthNarrows },
-            { "calendarname.islamic-civil", "Am M\u00ecosachan Ioslamach (cl\u00e0rach, linn s\u00ecobhalta)" },
             { "islamic.narrow.AmPmMarkers", metaValue_AmPmMarkers },
+            { "takr.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "mymr.NumberElements",
                 new String[] {
                     ".",
@@ -276,22 +632,6 @@ public class FormatData_gd extends ListResourceBundle {
                     "A",
                 }
             },
-            { "talu.NumberElements",
-                new String[] {
-                    ".",
-                    ",",
-                    ";",
-                    "%",
-                    "\u19d0",
-                    "#",
-                    "-",
-                    "E",
-                    "\u2030",
-                    "\u221e",
-                    "NaN",
-                }
-            },
-            { "abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "timezone.regionFormat.standard", "Bun-\u00e0m: {0}" },
             { "tamldec.NumberElements",
                 new String[] {
@@ -310,23 +650,6 @@ public class FormatData_gd extends ListResourceBundle {
             },
             { "japanese.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "calendarname.japanese", "Am M\u00ecosachan Seapanach" },
-            { "mtei.NumberElements",
-                new String[] {
-                    ".",
-                    ",",
-                    ";",
-                    "%",
-                    "\uabf0",
-                    "#",
-                    "-",
-                    "E",
-                    "\u2030",
-                    "\u221e",
-                    "NaN",
-                }
-            },
-            { "japanese.MonthNames", metaValue_MonthNames },
-            { "standalone.DayAbbreviations", metaValue_DayAbbreviations },
             { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "beng.NumberElements",
                 new String[] {
@@ -349,6 +672,7 @@ public class FormatData_gd extends ListResourceBundle {
                     "An d\u00e8idh Chr\u00ecosta",
                 }
             },
+            { "roc.QuarterNarrows", metaValue_QuarterNarrows },
             { "saur.NumberElements",
                 new String[] {
                     ".",
@@ -364,110 +688,22 @@ public class FormatData_gd extends ListResourceBundle {
                     "NaN",
                 }
             },
-            { "islamic.DayNames", metaValue_DayNames },
-            { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
-            { "DateTimePatterns",
-                new String[] {
-                    "{1} {0}",
-                    "{1} {0}",
-                    "{1} {0}",
-                    "{1} {0}",
-                }
-            },
-            { "narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "gong.NumberElements", metaValue_brah_NumberElements },
-            { "latn.NumberElements", metaValue_brah_NumberElements },
             { "MonthNarrows", metaValue_MonthNarrows },
             { "japanese.DatePatterns", metaValue_buddhist_DatePatterns },
-            { "guru.NumberElements",
-                new String[] {
-                    ".",
-                    ",",
-                    ";",
-                    "%",
-                    "\u0a66",
-                    "#",
-                    "-",
-                    "E",
-                    "\u2030",
-                    "\u221e",
-                    "NaN",
-                }
-            },
             { "buddhist.DayNames", metaValue_DayNames },
-            { "field.minute", "mionaid" },
             { "field.era", "linn" },
-            { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
             { "field.dayperiod", "m/f" },
-            { "standalone.MonthNarrows", metaValue_MonthNarrows },
-            { "cham.NumberElements",
-                new String[] {
-                    ".",
-                    ",",
-                    ";",
-                    "%",
-                    "\uaa50",
-                    "#",
-                    "-",
-                    "E",
-                    "\u2030",
-                    "\u221e",
-                    "NaN",
-                }
-            },
-            { "arab.NumberElements",
-                new String[] {
-                    "\u066b",
-                    "\u066c",
-                    "\u061b",
-                    "\u066a",
-                    "\u0660",
-                    "#",
-                    "\u061c-",
-                    "\u0627\u0633",
-                    "\u0609",
-                    "\u221e",
-                    "NaN",
-                }
-            },
-            { "shrd.NumberElements", metaValue_brah_NumberElements },
-            { "takr.NumberElements", metaValue_brah_NumberElements },
+            { "lana.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "calendarname.roc", "M\u00ecosachan Poblachd na S\u00ecne" },
-            { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
-            { "deva.NumberElements",
-                new String[] {
-                    ".",
-                    ",",
-                    ";",
-                    "%",
-                    "\u0966",
-                    "#",
-                    "-",
-                    "E",
-                    "\u2030",
-                    "\u221e",
-                    "NaN",
-                }
-            },
-            { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "field.month", "m\u00ecos" },
             { "osma.NumberElements", metaValue_brah_NumberElements },
             { "roc.Eras", metaValue_java_time_roc_Eras },
-            { "field.second", "diog" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "\u00a4#,##0.00",
-                    "#,##0%",
-                }
-            },
-            { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
-            { "calendarname.islamic", "Am M\u00ecosachan Ioslamach" },
             { "gonm.NumberElements", metaValue_brah_NumberElements },
-            { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
+            { "guru.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "knda.NumberElements",
                 new String[] {
                     ".",
@@ -500,66 +736,30 @@ public class FormatData_gd extends ListResourceBundle {
             },
             { "java.time.roc.narrow.Eras", metaValue_java_time_roc_Eras },
             { "japanese.narrow.AmPmMarkers", metaValue_AmPmMarkers },
-            { "buddhist.TimePatterns", metaValue_TimePatterns },
-            { "brah.NumberElements", metaValue_brah_NumberElements },
-            { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "sora.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "long.CompactNumberPatterns",
                 new String[] {
                     "",
                     "",
                     "",
-                    "0 mh\u00ecle",
-                    "00 mh\u00ecle",
-                    "000 mh\u00ecle",
-                    "0 mhillean",
-                    "00 mhillean",
-                    "000 mhillean",
-                    "0 bhillean",
-                    "00 bhillean",
-                    "000 bhillean",
-                    "0 trillean",
-                    "00 trillean",
-                    "000 trillean",
+                    "{one:0' 'mh\u00ecle two:0' 'mh\u00ecle few:0' 'm\u00ecltean other:0' 'm\u00ecle}",
+                    "{one:00' 'mh\u00ecle two:00' 'mh\u00ecle few:00' 'm\u00ecltean other:00' 'm\u00ecle}",
+                    "{one:000' 'mh\u00ecle two:000' 'mh\u00ecle few:000' 'm\u00ecltean other:000' 'm\u00ecle}",
+                    "{one:0' 'mhillean two:0' 'mhillean few:0' 'milleanan other:0' 'millean}",
+                    "{one:00' 'mhillean two:00' 'mhillean few:00' 'milleanan other:00' 'millean}",
+                    "{one:000' 'mhillean two:000' 'mhillean few:000' 'milleanan other:000' 'millean}",
+                    "{one:0' 'bhillean two:0' 'bhillean few:0' 'billeanan other:0' 'billean}",
+                    "{one:00' 'bhillean two:00' 'bhillean few:00' 'billeanan other:00' 'billean}",
+                    "{one:000' 'bhillean two:000' 'bhillean few:000' 'billeanan other:000' 'billean}",
+                    "{one:0' 'trillean two:0' 'thrillean few:0' 'trilleanan other:0' 'trillean}",
+                    "{one:00' 'trillean two:00' 'thrillean few:00' 'trilleanan other:00' 'trillean}",
+                    "{one:000' 'trillean two:000' 'thrillean few:000' 'trilleanan other:000' 'trillean}",
                 }
             },
+            { "buddhist.QuarterNarrows", metaValue_QuarterNarrows },
             { "roc.narrow.AmPmMarkers", metaValue_AmPmMarkers },
-            { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "standalone.QuarterNames", metaValue_QuarterNames },
-            { "olck.NumberElements",
-                new String[] {
-                    ".",
-                    ",",
-                    ";",
-                    "%",
-                    "\u1c50",
-                    "#",
-                    "-",
-                    "E",
-                    "\u2030",
-                    "\u221e",
-                    "NaN",
-                }
-            },
-            { "japanese.MonthNarrows", metaValue_MonthNarrows },
-            { "islamic.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "roc.DayAbbreviations", metaValue_DayAbbreviations },
             { "standalone.DayNarrows", metaValue_DayNarrows },
-            { "mymrshan.NumberElements",
-                new String[] {
-                    ".",
-                    ",",
-                    ";",
-                    "%",
-                    "\u1090",
-                    "#",
-                    "-",
-                    "E",
-                    "\u2030",
-                    "\u221e",
-                    "NaN",
-                }
-            },
-            { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
             { "mlym.NumberElements",
                 new String[] {
                     ".",
@@ -575,22 +775,6 @@ public class FormatData_gd extends ListResourceBundle {
                     "NaN",
                 }
             },
-            { "java.NumberElements",
-                new String[] {
-                    ".",
-                    ",",
-                    ";",
-                    "%",
-                    "\ua9d0",
-                    "#",
-                    "-",
-                    "E",
-                    "\u2030",
-                    "\u221e",
-                    "NaN",
-                }
-            },
-            { "TimePatterns", metaValue_TimePatterns },
             { "lepc.NumberElements",
                 new String[] {
                     ".",
@@ -606,6 +790,7 @@ public class FormatData_gd extends ListResourceBundle {
                     "NaN",
                 }
             },
+            { "gujr.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "fullwide.NumberElements",
                 new String[] {
                     ".",
@@ -621,7 +806,7 @@ public class FormatData_gd extends ListResourceBundle {
                     "NaN",
                 }
             },
-            { "islamic.DayNarrows", metaValue_DayNarrows },
+            { "limb.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "java.time.roc.Eras", metaValue_java_time_roc_Eras },
             { "khmr.NumberElements",
                 new String[] {
@@ -640,7 +825,6 @@ public class FormatData_gd extends ListResourceBundle {
             },
             { "field.zone", "roinn-t\u00ecde" },
             { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "roc.narrow.Eras", metaValue_java_time_roc_Eras },
             { "roc.DateTimePatterns",
                 new String[] {
                     "{1} 'aig' {0}",
@@ -649,34 +833,12 @@ public class FormatData_gd extends ListResourceBundle {
                     "{1} {0}",
                 }
             },
-            { "laoo.NumberElements",
+            { "arab.NumberPatterns",
                 new String[] {
-                    ".",
-                    ",",
-                    ";",
-                    "%",
-                    "\u0ed0",
-                    "#",
-                    "-",
-                    "E",
-                    "\u2030",
-                    "\u221e",
-                    "NaN",
-                }
-            },
-            { "sund.NumberElements",
-                new String[] {
-                    ".",
-                    ",",
-                    ";",
-                    "%",
-                    "\u1bb0",
-                    "#",
-                    "-",
-                    "E",
-                    "\u2030",
-                    "\u221e",
-                    "NaN",
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "#,##0%",
+                    "",
                 }
             },
             { "thai.NumberElements",
@@ -694,7 +856,6 @@ public class FormatData_gd extends ListResourceBundle {
                     "NaN",
                 }
             },
-            { "buddhist.narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "buddhist.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "Eras",
                 new String[] {
@@ -702,24 +863,11 @@ public class FormatData_gd extends ListResourceBundle {
                     "AD",
                 }
             },
-            { "kali.NumberElements",
-                new String[] {
-                    ".",
-                    ",",
-                    ";",
-                    "%",
-                    "\ua900",
-                    "#",
-                    "-",
-                    "E",
-                    "\u2030",
-                    "\u221e",
-                    "NaN",
-                }
-            },
-            { "roc.DayNames", metaValue_DayNames },
+            { "lepc.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "islamic.QuarterNames", metaValue_QuarterNames },
+            { "mymrshan.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "islamic.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
+            { "nkoo.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "mong.NumberElements",
                 new String[] {
                     ".",
@@ -738,10 +886,11 @@ public class FormatData_gd extends ListResourceBundle {
             { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "field.weekday", "latha na seachdaine" },
             { "islamic.DateTimePatterns", metaValue_japanese_DateTimePatterns },
-            { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
-            { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
+            { "brah.NumberPatterns", metaValue_arabext_NumberPatterns },
+            { "java.NumberPatterns", metaValue_arabext_NumberPatterns },
+            { "thai.NumberPatterns", metaValue_arabext_NumberPatterns },
+            { "fullwide.NumberPatterns", metaValue_fullwide_NumberPatterns },
             { "japanese.QuarterNames", metaValue_QuarterNames },
-            { "buddhist.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "telu.NumberElements",
                 new String[] {
                     ".",
@@ -757,40 +906,10 @@ public class FormatData_gd extends ListResourceBundle {
                     "NaN",
                 }
             },
-            { "nkoo.NumberElements",
-                new String[] {
-                    ".",
-                    ",",
-                    ";",
-                    "%",
-                    "\u07c0",
-                    "#",
-                    "-",
-                    "E",
-                    "\u2030",
-                    "\u221e",
-                    "NaN",
-                }
-            },
-            { "cakm.NumberElements", metaValue_brah_NumberElements },
-            { "tibt.NumberElements",
-                new String[] {
-                    ".",
-                    ",",
-                    ";",
-                    "%",
-                    "\u0f20",
-                    "#",
-                    "-",
-                    "E",
-                    "\u2030",
-                    "\u221e",
-                    "NaN",
-                }
-            },
+            { "olck.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "japanese.DayNames", metaValue_DayNames },
+            { "knda.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "japanese.DayAbbreviations", metaValue_DayAbbreviations },
-            { "DayNames", metaValue_DayNames },
             { "lanatham.NumberElements",
                 new String[] {
                     ".",
@@ -806,44 +925,11 @@ public class FormatData_gd extends ListResourceBundle {
                     "NaN",
                 }
             },
-            { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
-            { "roc.MonthNames", metaValue_MonthNames },
-            { "sora.NumberElements", metaValue_brah_NumberElements },
+            { "laoo.NumberPatterns", metaValue_arabext_NumberPatterns },
+            { "talu.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "field.week", "seachdain" },
-            { "gujr.NumberElements",
-                new String[] {
-                    ".",
-                    ",",
-                    ";",
-                    "%",
-                    "\u0ae6",
-                    "#",
-                    "-",
-                    "E",
-                    "\u2030",
-                    "\u221e",
-                    "NaN",
-                }
-            },
-            { "buddhist.MonthNarrows", metaValue_MonthNarrows },
             { "buddhist.QuarterNames", metaValue_QuarterNames },
-            { "islamic.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
-            { "limb.NumberElements",
-                new String[] {
-                    ".",
-                    ",",
-                    ";",
-                    "%",
-                    "\u1946",
-                    "#",
-                    "-",
-                    "E",
-                    "\u2030",
-                    "\u221e",
-                    "NaN",
-                }
-            },
-            { "roc.DayNarrows", metaValue_DayNarrows },
+            { "islamic.QuarterNarrows", metaValue_QuarterNarrows },
             { "orya.NumberElements",
                 new String[] {
                     ".",
@@ -861,58 +947,32 @@ public class FormatData_gd extends ListResourceBundle {
             },
             { "roc.AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
-            { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
+            { "rohg.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "short.CompactNumberPatterns",
                 new String[] {
                     "",
                     "",
                     "",
-                    "0K",
-                    "00K",
-                    "000K",
-                    "0M",
-                    "00M",
-                    "000M",
-                    "0B",
-                    "00B",
-                    "000B",
-                    "0T",
-                    "00T",
-                    "000T",
-                }
-            },
-            { "calendarname.gregorian", metaValue_calendarname_gregorian },
-            { "timezone.regionFormat.daylight", "T\u00ecde samhraidh: {0}" },
-            { "DatePatterns",
-                new String[] {
-                    "EEEE, d'mh' MMMM y",
-                    "d'mh' MMMM y",
-                    "d MMM y",
-                    "dd/MM/y",
+                    "{one:0K two:0K few:0K other:0K}",
+                    "{one:00K two:00K few:00K other:00K}",
+                    "{one:000K two:000K few:000K other:000K}",
+                    "{one:0M two:0M few:0M other:0M}",
+                    "{one:00M two:00M few:00M other:00M}",
+                    "{one:000M two:000M few:000M other:000M}",
+                    "{one:0B two:0B few:0B other:0B}",
+                    "{one:00B two:00B few:00B other:00B}",
+                    "{one:000B two:000B few:000B other:000B}",
+                    "{one:0T two:0T few:0T other:0T}",
+                    "{one:00T two:00T few:00T other:00T}",
+                    "{one:000T two:000T few:000T other:000T}",
                 }
             },
             { "buddhist.DayAbbreviations", metaValue_DayAbbreviations },
-            { "islamic.TimePatterns", metaValue_TimePatterns },
-            { "japanese.DateTimePatterns", metaValue_japanese_DateTimePatterns },
-            { "MonthAbbreviations", metaValue_MonthAbbreviations },
-            { "standalone.DayNames", metaValue_DayNames },
+            { "cham.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "field.hour", "uair a th\u00ecde" },
-            { "vaii.NumberElements",
-                new String[] {
-                    ".",
-                    ",",
-                    ";",
-                    "%",
-                    "\ua620",
-                    "#",
-                    "-",
-                    "E",
-                    "\u2030",
-                    "\u221e",
-                    "NaN",
-                }
-            },
             { "calendarname.buddhist", "Am M\u00ecosachan Budach" },
+            { "kali.NumberPatterns", metaValue_arabext_NumberPatterns },
+            { "latn.NumberPatterns", metaValue_fullwide_NumberPatterns },
             { "standalone.MonthNames",
                 new String[] {
                     "Am Faoilleach",
@@ -934,9 +994,8 @@ public class FormatData_gd extends ListResourceBundle {
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
             { "roc.TimePatterns", metaValue_TimePatterns },
-            { "QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "deva.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "roc.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
-            { "calendarname.gregory", metaValue_calendarname_gregorian },
         };
         return data;
     }
