@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -154,6 +154,12 @@ public class FormatData_gl extends ListResourceBundle {
                "T3",
                "T4",
             };
+        final String[] metaValue_QuarterNarrows = new String[] {
+               "1",
+               "2",
+               "3",
+               "4",
+            };
         final String[] metaValue_AmPmMarkers = new String[] {
                "a.m.",
                "p.m.",
@@ -168,14 +174,8 @@ public class FormatData_gl extends ListResourceBundle {
                "HH:mm:ss",
                "HH:mm",
             };
-        final String[] metaValue_buddhist_QuarterNarrows = new String[] {
-               "1",
-               "2",
-               "3",
-               "4",
-            };
         final String[] metaValue_java_time_buddhist_DatePatterns = new String[] {
-               "cccc, d 'de' MMMM 'de' Y G",
+               "EEEE, d 'de' MMMM 'de' Y G",
                "d 'de' MMMM 'de' y G",
                "d 'de' MMM 'de' y G",
                "dd/MM/y GGGGG",
@@ -223,6 +223,7 @@ public class FormatData_gl extends ListResourceBundle {
                     "despois de Cristo",
                 }
             },
+            { "roc.QuarterNarrows", metaValue_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -274,6 +275,7 @@ public class FormatData_gl extends ListResourceBundle {
                     "",
                 }
             },
+            { "japanese.QuarterNarrows", metaValue_QuarterNarrows },
             { "calendarname.roc", "calendario Minguo" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
@@ -281,13 +283,6 @@ public class FormatData_gl extends ListResourceBundle {
             { "field.second", "segundo" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "#,##0.00\u00a0\u00a4",
-                    "#,##0\u00a0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "calendario isl\u00e1mico" },
             { "japanese.narrow.AmPmMarkers", metaValue_AmPmMarkers },
@@ -315,22 +310,22 @@ public class FormatData_gl extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0",
-                    "0",
-                    "0",
-                    "0 mill\u00f3n",
-                    "00 mill\u00f3ns",
-                    "000 mill\u00f3ns",
-                    "0",
-                    "0",
-                    "0",
-                    "0 bill\u00f3n",
-                    "00 bill\u00f3ns",
-                    "000 bill\u00f3ns",
+                    "{one:0 other:0}",
+                    "{one:0 other:0}",
+                    "{one:0 other:0}",
+                    "{one:0' 'mill\u00f3n other:0' 'mill\u00f3ns}",
+                    "{one:00' 'mill\u00f3ns other:00' 'mill\u00f3ns}",
+                    "{one:000' 'mill\u00f3ns other:000' 'mill\u00f3ns}",
+                    "{one:0 other:0}",
+                    "{one:0 other:0}",
+                    "{one:0 other:0}",
+                    "{one:0' 'bill\u00f3n other:0' 'bill\u00f3ns}",
+                    "{one:00' 'bill\u00f3ns other:00' 'bill\u00f3ns}",
+                    "{one:000' 'bill\u00f3ns other:000' 'bill\u00f3ns}",
                 }
             },
+            { "buddhist.QuarterNarrows", metaValue_QuarterNarrows },
             { "roc.narrow.AmPmMarkers", metaValue_AmPmMarkers },
-            { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "standalone.QuarterNames", metaValue_QuarterNames },
             { "japanese.MonthNarrows", metaValue_MonthNarrows },
             { "islamic.QuarterAbbreviations", metaValue_QuarterAbbreviations },
@@ -356,6 +351,7 @@ public class FormatData_gl extends ListResourceBundle {
             { "Eras", metaValue_Eras },
             { "roc.DayNames", metaValue_DayNames },
             { "islamic.QuarterNames", metaValue_QuarterNames },
+            { "QuarterNarrows", metaValue_QuarterNarrows },
             { "islamic.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "field.weekday", "d\u00eda da semana" },
@@ -371,7 +367,7 @@ public class FormatData_gl extends ListResourceBundle {
             { "field.week", "semana" },
             { "buddhist.MonthNarrows", metaValue_MonthNarrows },
             { "buddhist.QuarterNames", metaValue_QuarterNames },
-            { "islamic.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
+            { "islamic.QuarterNarrows", metaValue_QuarterNarrows },
             { "roc.DayNarrows", metaValue_DayNarrows },
             { "roc.AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
@@ -381,18 +377,18 @@ public class FormatData_gl extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0",
-                    "0",
-                    "0",
-                    "0\u00a0M",
-                    "00\u00a0M",
-                    "000\u00a0M",
-                    "0",
-                    "0",
-                    "0",
-                    "0\u00a0B",
-                    "00\u00a0B",
-                    "000\u00a0B",
+                    "{one:0 other:0}",
+                    "{one:0 other:0}",
+                    "{one:0 other:0}",
+                    "{one:0\u00a0M other:0\u00a0M}",
+                    "{one:00\u00a0M other:00\u00a0M}",
+                    "{one:000\u00a0M other:000\u00a0M}",
+                    "{one:0 other:0}",
+                    "{one:0 other:0}",
+                    "{one:0 other:0}",
+                    "{one:0\u00a0B other:0\u00a0B}",
+                    "{one:00\u00a0B other:00\u00a0B}",
+                    "{one:000\u00a0B other:000\u00a0B}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -438,6 +434,14 @@ public class FormatData_gl extends ListResourceBundle {
                     "",
                 }
             },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "#,##0\u00a0%",
+                    "#,##0.00\u00a0\u00a4",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
