@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -71,18 +71,18 @@ public class FormatData_mn extends ListResourceBundle {
     @Override
     protected final Object[][] getContents() {
         final String[] metaValue_MonthNames = new String[] {
-               "\u041d\u044d\u0433\u0434\u04af\u0433\u044d\u044d\u0440 \u0441\u0430\u0440",
-               "\u0425\u043e\u0451\u0440\u0434\u0443\u0433\u0430\u0430\u0440 \u0441\u0430\u0440",
-               "\u0413\u0443\u0440\u0430\u0432\u0434\u0443\u0433\u0430\u0430\u0440 \u0441\u0430\u0440",
-               "\u0414\u04e9\u0440\u04e9\u0432\u0434\u04af\u0433\u044d\u044d\u0440 \u0441\u0430\u0440",
-               "\u0422\u0430\u0432\u0434\u0443\u0433\u0430\u0430\u0440 \u0441\u0430\u0440",
-               "\u0417\u0443\u0440\u0433\u0430\u0430\u0434\u0443\u0433\u0430\u0430\u0440 \u0441\u0430\u0440",
-               "\u0414\u043e\u043b\u0434\u0443\u0433\u0430\u0430\u0440 \u0441\u0430\u0440",
-               "\u041d\u0430\u0439\u043c\u0434\u0443\u0433\u0430\u0430\u0440 \u0441\u0430\u0440",
-               "\u0415\u0441\u0434\u04af\u0433\u044d\u044d\u0440 \u0441\u0430\u0440",
-               "\u0410\u0440\u0430\u0432\u0434\u0443\u0433\u0430\u0430\u0440 \u0441\u0430\u0440",
-               "\u0410\u0440\u0432\u0430\u043d \u043d\u044d\u0433\u0434\u04af\u0433\u044d\u044d\u0440 \u0441\u0430\u0440",
-               "\u0410\u0440\u0432\u0430\u043d \u0445\u043e\u0451\u0440\u0434\u0443\u0433\u0430\u0430\u0440 \u0441\u0430\u0440",
+               "\u043d\u044d\u0433\u0434\u04af\u0433\u044d\u044d\u0440 \u0441\u0430\u0440",
+               "\u0445\u043e\u0451\u0440\u0434\u0443\u0433\u0430\u0430\u0440 \u0441\u0430\u0440",
+               "\u0433\u0443\u0440\u0430\u0432\u0434\u0443\u0433\u0430\u0430\u0440 \u0441\u0430\u0440",
+               "\u0434\u04e9\u0440\u04e9\u0432\u0434\u04af\u0433\u044d\u044d\u0440 \u0441\u0430\u0440",
+               "\u0442\u0430\u0432\u0434\u0443\u0433\u0430\u0430\u0440 \u0441\u0430\u0440",
+               "\u0437\u0443\u0440\u0433\u0430\u0430\u0434\u0443\u0433\u0430\u0430\u0440 \u0441\u0430\u0440",
+               "\u0434\u043e\u043b\u043e\u043e\u0434\u0443\u0433\u0430\u0430\u0440 \u0441\u0430\u0440",
+               "\u043d\u0430\u0439\u043c\u0434\u0443\u0433\u0430\u0430\u0440 \u0441\u0430\u0440",
+               "\u0435\u0441\u0434\u04af\u0433\u044d\u044d\u0440 \u0441\u0430\u0440",
+               "\u0430\u0440\u0430\u0432\u0434\u0443\u0433\u0430\u0430\u0440 \u0441\u0430\u0440",
+               "\u0430\u0440\u0432\u0430\u043d \u043d\u044d\u0433\u0434\u04af\u0433\u044d\u044d\u0440 \u0441\u0430\u0440",
+               "\u0430\u0440\u0432\u0430\u043d \u0445\u043e\u0451\u0440\u0434\u0443\u0433\u0430\u0430\u0440 \u0441\u0430\u0440",
                "",
             };
         final String[] metaValue_MonthAbbreviations = new String[] {
@@ -145,23 +145,15 @@ public class FormatData_mn extends ListResourceBundle {
                "III \u0443\u043b\u0438\u0440\u0430\u043b",
                "IV \u0443\u043b\u0438\u0440\u0430\u043b",
             };
-        final String[] metaValue_standalone_QuarterAbbreviations = new String[] {
+        final String[] metaValue_QuarterNarrows = new String[] {
                "I",
                "II",
                "III",
                "IV",
             };
         final String[] metaValue_AmPmMarkers = new String[] {
-               "\u04af.\u04e9",
-               "\u04af.\u0445",
-            };
-        final String[] metaValue_narrow_AmPmMarkers = new String[] {
-               "\u04af\u04e9",
-               "\u04af\u0445",
-            };
-        final String[] metaValue_abbreviated_AmPmMarkers = new String[] {
-               "\u04ae\u04e8",
-               "\u04ae\u0425",
+               "\u04af.\u04e9.",
+               "\u04af.\u0445.",
             };
         final String[] metaValue_Eras = new String[] {
                "\u041c\u042d\u04e8",
@@ -173,28 +165,35 @@ public class FormatData_mn extends ListResourceBundle {
                "HH:mm:ss",
                "HH:mm",
             };
-        final String[] metaValue_buddhist_DatePatterns = new String[] {
-               "EEEE, y '\u043e\u043d\u044b' MM '\u0441\u0430\u0440\u044b\u043d' dd",
-               "y '\u043e\u043d\u044b' MM '\u0441\u0430\u0440\u044b\u043d' dd",
-               "y MM d",
-               "y-MM-dd",
+        final String[] metaValue_java_time_buddhist_DatePatterns = new String[] {
+               "G y '\u043e\u043d\u044b' MMMM'\u044b\u043d' d. cccc '\u0433\u0430\u0440\u0430\u0433'",
+               "G y '\u043e\u043d\u044b' MM '\u0441\u0430\u0440\u044b\u043d' dd",
+               "G y '\u043e\u043d\u044b' MMM'\u044b\u043d' d",
+               "GGGGG y.MM.dd",
             };
-        final String metaValue_calendarname_gregorian = "\u0433\u0440\u0435\u0433\u043e\u0440\u0438\u0439\u043d \u0445\u0443\u0430\u043d\u043b\u0438";
+        final String[] metaValue_buddhist_DatePatterns = new String[] {
+               "GGGG y '\u043e\u043d\u044b' MMMM'\u044b\u043d' d. EEEE '\u0433\u0430\u0440\u0430\u0433'",
+               "GGGG y '\u043e\u043d\u044b' MM '\u0441\u0430\u0440\u044b\u043d' dd",
+               "GGGG y '\u043e\u043d\u044b' MMM'\u044b\u043d' d",
+               "G y.MM.dd",
+            };
+        final String metaValue_calendarname_gregorian = "\u0433\u0440\u0435\u0433\u043e\u0440\u0438\u0439\u043d \u0446\u0430\u0433\u043b\u0430\u0432\u0430\u0440";
         final Object[][] data = new Object[][] {
             { "MonthNames", metaValue_MonthNames },
             { "field.year", "\u0436\u0438\u043b" },
             { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
             { "AmPmMarkers", metaValue_AmPmMarkers },
-            { "standalone.QuarterAbbreviations", metaValue_standalone_QuarterAbbreviations },
+            { "java.time.japanese.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
+            { "standalone.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.QuarterNames", metaValue_QuarterNames },
             { "roc.MonthNarrows", metaValue_MonthNarrows },
-            { "islamic.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
+            { "islamic.narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "japanese.TimePatterns", metaValue_TimePatterns },
             { "narrow.Eras", metaValue_Eras },
-            { "abbreviated.AmPmMarkers", metaValue_abbreviated_AmPmMarkers },
-            { "timezone.regionFormat.standard", "{0} \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0446\u0430\u0433" },
-            { "japanese.abbreviated.AmPmMarkers", metaValue_abbreviated_AmPmMarkers },
-            { "calendarname.japanese", "\u044f\u043f\u043e\u043d \u0445\u0443\u0430\u043d\u043b\u0438" },
+            { "abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
+            { "timezone.regionFormat.standard", "{0}-\u043d \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0446\u0430\u0433" },
+            { "japanese.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
+            { "calendarname.japanese", "\u044f\u043f\u043e\u043d \u0446\u0430\u0433\u043b\u0430\u0432\u0430\u0440" },
             { "japanese.MonthNames", metaValue_MonthNames },
             { "standalone.DayAbbreviations", metaValue_DayAbbreviations },
             { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
@@ -204,7 +203,7 @@ public class FormatData_mn extends ListResourceBundle {
                     "\u043c\u0430\u043d\u0430\u0439 \u044d\u0440\u0438\u043d\u0438\u0439",
                 }
             },
-            { "roc.QuarterNarrows", metaValue_standalone_QuarterAbbreviations },
+            { "roc.QuarterNarrows", metaValue_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -216,7 +215,7 @@ public class FormatData_mn extends ListResourceBundle {
                     "{1} {0}",
                 }
             },
-            { "narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
+            { "narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "latn.NumberElements",
                 new String[] {
                     ".",
@@ -240,48 +239,41 @@ public class FormatData_mn extends ListResourceBundle {
             { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
             { "field.dayperiod", "\u04af.\u04e9./\u04af.\u0445." },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
-            { "japanese.QuarterNarrows", metaValue_standalone_QuarterAbbreviations },
-            { "calendarname.roc", "\u043c\u0438\u043d\u0433\u043e \u0445\u0443\u0430\u043d\u043b\u0438" },
+            { "japanese.QuarterNarrows", metaValue_QuarterNarrows },
+            { "calendarname.roc", "\u043c\u0438\u043d\u0433\u043e \u0446\u0430\u0433\u043b\u0430\u0432\u0430\u0440" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "field.month", "\u0441\u0430\u0440" },
             { "field.second", "\u0441\u0435\u043a\u0443\u043d\u0434" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayAbbreviations },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "\u00a4\u00a0#,##0.00",
-                    "#,##0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
-            { "calendarname.islamic", "\u0438\u0441\u043b\u0430\u043c\u044b\u043d \u0445\u0443\u0430\u043d\u043b\u0438" },
-            { "japanese.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
+            { "calendarname.islamic", "\u0438\u0441\u043b\u0430\u043c\u044b\u043d \u0446\u0430\u0433\u043b\u0430\u0432\u0430\u0440" },
+            { "japanese.narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
-            { "timezone.regionFormat", "{0} \u0446\u0430\u0433" },
+            { "timezone.regionFormat", "{0}-\u043d \u0446\u0430\u0433" },
             { "long.CompactNumberPatterns",
                 new String[] {
                     "",
                     "",
                     "",
-                    "0 \u043c\u044f\u043d\u0433\u0430",
-                    "00 \u043c\u044f\u043d\u0433\u0430",
-                    "000 \u043c\u044f\u043d\u0433\u0430",
-                    "0 \u0441\u0430\u044f",
-                    "00 \u0441\u0430\u044f",
-                    "000 \u0441\u0430\u044f",
-                    "0 \u0442\u044d\u0440\u0431\u0443\u043c",
-                    "00 \u0442\u044d\u0440\u0431\u0443\u043c",
-                    "000 \u0442\u044d\u0440\u0431\u0443\u043c",
-                    "0 \u0438\u0445 \u043d\u0430\u044f\u0434",
-                    "00 \u0438\u0445 \u043d\u0430\u044f\u0434",
-                    "000 \u0438\u0445 \u043d\u0430\u044f\u0434",
+                    "{one:0' '\u043c\u044f\u043d\u0433\u0430 other:0' '\u043c\u044f\u043d\u0433\u0430}",
+                    "{one:00' '\u043c\u044f\u043d\u0433\u0430 other:00' '\u043c\u044f\u043d\u0433\u0430}",
+                    "{one:000' '\u043c\u044f\u043d\u0433\u0430 other:000' '\u043c\u044f\u043d\u0433\u0430}",
+                    "{one:0' '\u0441\u0430\u044f other:0' '\u0441\u0430\u044f}",
+                    "{one:00' '\u0441\u0430\u044f other:00' '\u0441\u0430\u044f}",
+                    "{one:000' '\u0441\u0430\u044f other:000' '\u0441\u0430\u044f}",
+                    "{one:0' '\u0442\u044d\u0440\u0431\u0443\u043c other:0' '\u0442\u044d\u0440\u0431\u0443\u043c}",
+                    "{one:00' '\u0442\u044d\u0440\u0431\u0443\u043c other:00' '\u0442\u044d\u0440\u0431\u0443\u043c}",
+                    "{one:000' '\u0442\u044d\u0440\u0431\u0443\u043c other:000' '\u0442\u044d\u0440\u0431\u0443\u043c}",
+                    "{one:0' '\u0438\u0445' '\u043d\u0430\u044f\u0434 other:0' '\u0438\u0445' '\u043d\u0430\u044f\u0434}",
+                    "{one:00' '\u0438\u0445' '\u043d\u0430\u044f\u0434 other:00' '\u0438\u0445' '\u043d\u0430\u044f\u0434}",
+                    "{one:000' '\u0438\u0445' '\u043d\u0430\u044f\u0434 other:000' '\u0438\u0445' '\u043d\u0430\u044f\u0434}",
                 }
             },
-            { "buddhist.QuarterNarrows", metaValue_standalone_QuarterAbbreviations },
-            { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
+            { "buddhist.QuarterNarrows", metaValue_QuarterNarrows },
+            { "roc.narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "standalone.QuarterNames", metaValue_QuarterNames },
             { "japanese.MonthNarrows", metaValue_MonthNarrows },
             { "islamic.QuarterAbbreviations", metaValue_QuarterAbbreviations },
@@ -292,14 +284,15 @@ public class FormatData_mn extends ListResourceBundle {
             { "islamic.DayNarrows", metaValue_DayAbbreviations },
             { "field.zone", "\u0446\u0430\u0433\u0438\u0439\u043d \u0431\u04af\u0441" },
             { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "buddhist.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
-            { "buddhist.abbreviated.AmPmMarkers", metaValue_abbreviated_AmPmMarkers },
+            { "buddhist.narrow.AmPmMarkers", metaValue_AmPmMarkers },
+            { "buddhist.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "Eras", metaValue_Eras },
             { "roc.DayNames", metaValue_DayNames },
             { "islamic.QuarterNames", metaValue_QuarterNames },
-            { "QuarterNarrows", metaValue_standalone_QuarterAbbreviations },
-            { "islamic.abbreviated.AmPmMarkers", metaValue_abbreviated_AmPmMarkers },
-            { "standalone.QuarterNarrows", metaValue_standalone_QuarterAbbreviations },
+            { "QuarterNarrows", metaValue_QuarterNarrows },
+            { "islamic.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
+            { "standalone.QuarterNarrows", metaValue_QuarterNarrows },
+            { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "field.weekday", "\u0433\u0430\u0440\u0430\u0433" },
             { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
@@ -313,51 +306,87 @@ public class FormatData_mn extends ListResourceBundle {
             { "field.week", "\u0434\u043e\u043b\u043e\u043e \u0445\u043e\u043d\u043e\u0433" },
             { "buddhist.MonthNarrows", metaValue_MonthNarrows },
             { "buddhist.QuarterNames", metaValue_QuarterNames },
-            { "islamic.QuarterNarrows", metaValue_standalone_QuarterAbbreviations },
+            { "islamic.QuarterNarrows", metaValue_QuarterNarrows },
             { "roc.DayNarrows", metaValue_DayAbbreviations },
             { "roc.AmPmMarkers", metaValue_AmPmMarkers },
+            { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
+            { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "short.CompactNumberPatterns",
                 new String[] {
                     "",
                     "",
                     "",
-                    "0\u043c\u044f\u043d\u0433\u0430",
-                    "00\u043c\u044f\u043d\u0433\u0430",
-                    "000\u043c\u044f\u043d\u0433\u0430",
-                    "0\u0441\u0430\u044f",
-                    "00\u0441\u0430\u044f",
-                    "000\u0441\u0430\u044f",
-                    "0\u0442\u044d\u0440\u0431\u0443\u043c",
-                    "00\u0442\u044d\u0440\u0431\u0443\u043c",
-                    "000\u0422",
-                    "0\u0418\u041d",
-                    "00\u0418\u041d",
-                    "000\u0418\u041d",
+                    "{one:0\u00a0\u043c\u044f\u043d\u0433\u0430 other:0\u00a0\u043c\u044f\u043d\u0433\u0430}",
+                    "{one:00\u00a0\u043c\u044f\u043d\u0433\u0430 other:00\u00a0\u043c\u044f\u043d\u0433\u0430}",
+                    "{one:000\u00a0\u043c\u044f\u043d\u0433\u0430 other:000\u00a0\u043c\u044f\u043d\u0433\u0430}",
+                    "{one:0\u00a0\u0441\u0430\u044f other:0\u00a0\u0441\u0430\u044f}",
+                    "{one:00\u00a0\u0441\u0430\u044f other:00\u00a0\u0441\u0430\u044f}",
+                    "{one:000\u00a0\u0441\u0430\u044f other:000\u00a0\u0441\u0430\u044f}",
+                    "{one:0\u00a0\u0442\u044d\u0440\u0431\u0443\u043c other:0\u00a0\u0442\u044d\u0440\u0431\u0443\u043c}",
+                    "{one:00\u00a0\u0442\u044d\u0440\u0431\u0443\u043c other:00\u00a0\u0442\u044d\u0440\u0431\u0443\u043c}",
+                    "{one:000\u0422 other:000\u0422}",
+                    "{one:0\u0418\u041d other:0\u0418\u041d}",
+                    "{one:00\u0418\u041d other:00\u0418\u041d}",
+                    "{one:000\u0418\u041d other:000\u0418\u041d}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
-            { "timezone.regionFormat.daylight", "{0} \u0437\u0443\u043d\u044b \u0446\u0430\u0433" },
+            { "timezone.regionFormat.daylight", "{0}-\u043d \u0437\u0443\u043d\u044b \u0446\u0430\u0433" },
             { "DatePatterns",
                 new String[] {
-                    "y.MM.dd, EEEE",
-                    "y.MM.dd",
-                    "y.MM.dd",
+                    "y '\u043e\u043d\u044b' MMMM'\u044b\u043d' d, EEEE '\u0433\u0430\u0440\u0430\u0433'",
+                    "y '\u043e\u043d\u044b' MMMM'\u044b\u043d' d",
+                    "y '\u043e\u043d\u044b' MMM'\u044b\u043d' d",
                     "y.MM.dd",
                 }
             },
             { "buddhist.DayAbbreviations", metaValue_DayAbbreviations },
             { "islamic.TimePatterns", metaValue_TimePatterns },
             { "MonthAbbreviations", metaValue_MonthAbbreviations },
-            { "standalone.DayNames", metaValue_DayNames },
+            { "standalone.DayNames",
+                new String[] {
+                    "\u041d\u044f\u043c",
+                    "\u0414\u0430\u0432\u0430\u0430",
+                    "\u041c\u044f\u0433\u043c\u0430\u0440",
+                    "\u041b\u0445\u0430\u0433\u0432\u0430",
+                    "\u041f\u04af\u0440\u044d\u0432",
+                    "\u0411\u0430\u0430\u0441\u0430\u043d",
+                    "\u0411\u044f\u043c\u0431\u0430",
+                }
+            },
             { "field.hour", "\u0446\u0430\u0433" },
-            { "calendarname.buddhist", "\u0431\u0443\u0434\u0434\u044b\u043d \u0445\u0443\u0430\u043d\u043b\u0438" },
-            { "standalone.MonthNames", metaValue_MonthNames },
+            { "calendarname.buddhist", "\u0431\u0443\u0434\u0434\u044b\u043d \u0446\u0430\u0433\u043b\u0430\u0432\u0430\u0440" },
+            { "standalone.MonthNames",
+                new String[] {
+                    "\u041d\u044d\u0433\u0434\u04af\u0433\u044d\u044d\u0440 \u0441\u0430\u0440",
+                    "\u0425\u043e\u0451\u0440\u0434\u0443\u0433\u0430\u0430\u0440 \u0441\u0430\u0440",
+                    "\u0413\u0443\u0440\u0430\u0432\u0434\u0443\u0433\u0430\u0430\u0440 \u0441\u0430\u0440",
+                    "\u0414\u04e9\u0440\u04e9\u0432\u0434\u04af\u0433\u044d\u044d\u0440 \u0441\u0430\u0440",
+                    "\u0422\u0430\u0432\u0434\u0443\u0433\u0430\u0430\u0440 \u0441\u0430\u0440",
+                    "\u0417\u0443\u0440\u0433\u0430\u0430\u0434\u0443\u0433\u0430\u0430\u0440 \u0441\u0430\u0440",
+                    "\u0414\u043e\u043b\u043e\u043e\u0434\u0443\u0433\u0430\u0430\u0440 \u0441\u0430\u0440",
+                    "\u041d\u0430\u0439\u043c\u0434\u0443\u0433\u0430\u0430\u0440 \u0441\u0430\u0440",
+                    "\u0415\u0441\u0434\u04af\u0433\u044d\u044d\u0440 \u0441\u0430\u0440",
+                    "\u0410\u0440\u0430\u0432\u0434\u0443\u0433\u0430\u0430\u0440 \u0441\u0430\u0440",
+                    "\u0410\u0440\u0432\u0430\u043d \u043d\u044d\u0433\u0434\u04af\u0433\u044d\u044d\u0440 \u0441\u0430\u0440",
+                    "\u0410\u0440\u0432\u0430\u043d \u0445\u043e\u0451\u0440\u0434\u0443\u0433\u0430\u0430\u0440 \u0441\u0430\u0440",
+                    "",
+                }
+            },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "\u00a4\u00a0#,##0.00",
+                    "#,##0%",
+                    "\u00a4\u00a0#,##0.00",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayAbbreviations },
             { "japanese.DayNarrows", metaValue_DayAbbreviations },
             { "QuarterNames", metaValue_QuarterNames },
             { "roc.TimePatterns", metaValue_TimePatterns },
             { "QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "roc.abbreviated.AmPmMarkers", metaValue_abbreviated_AmPmMarkers },
+            { "roc.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "calendarname.gregory", metaValue_calendarname_gregorian },
         };
         return data;
