@@ -142,12 +142,18 @@ public class FormatData_se extends ListResourceBundle {
                "B",
                "L",
             };
-        final String[] metaValue_standalone_QuarterAbbreviations = new String[] {
+        final String[] metaValue_standalone_QuarterNames = new String[] {
                "Q1",
                "Q2",
                "Q3",
                "Q4",
             };
+        final String[] metaValue_QuarterNarrows = new String[] {
+               "1",
+               "2",
+               "3",
+               "4",
+            };
         final String[] metaValue_AmPmMarkers = new String[] {
                "i\u0111itbeaivet",
                "eahketbeaivet",
@@ -166,29 +172,24 @@ public class FormatData_se extends ListResourceBundle {
                "HH:mm:ss",
                "HH:mm",
             };
-        final String[] metaValue_buddhist_QuarterNarrows = new String[] {
-               "1",
-               "2",
-               "3",
-               "4",
-            };
         final String metaValue_calendarname_gregorian = "gregoria kaleander";
         final Object[][] data = new Object[][] {
             { "MonthNames", metaValue_MonthNames },
             { "field.year", "j\u00e1hki" },
-            { "islamic.QuarterAbbreviations", metaValue_standalone_QuarterAbbreviations },
+            { "islamic.QuarterAbbreviations", metaValue_standalone_QuarterNames },
             { "roc.DayAbbreviations", metaValue_DayAbbreviations },
             { "standalone.DayNarrows", metaValue_DayNarrows },
             { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
             { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
             { "AmPmMarkers", metaValue_AmPmMarkers },
             { "timezone.gmtFormat", "UTC{0}" },
-            { "standalone.QuarterAbbreviations", metaValue_standalone_QuarterAbbreviations },
+            { "standalone.QuarterAbbreviations", metaValue_standalone_QuarterNames },
+            { "roc.QuarterNames", metaValue_standalone_QuarterNames },
             { "TimePatterns", metaValue_TimePatterns },
             { "islamic.DayNarrows", metaValue_DayNarrows },
             { "field.zone", "\u00e1igeav\u00e1dat" },
             { "roc.MonthNarrows", metaValue_MonthNarrows },
-            { "japanese.QuarterAbbreviations", metaValue_standalone_QuarterAbbreviations },
+            { "japanese.QuarterAbbreviations", metaValue_standalone_QuarterNames },
             { "islamic.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "japanese.TimePatterns", metaValue_TimePatterns },
             { "narrow.Eras", metaValue_Eras },
@@ -202,6 +203,8 @@ public class FormatData_se extends ListResourceBundle {
             { "roc.DayNames", metaValue_DayNames },
             { "standalone.DayAbbreviations", metaValue_DayAbbreviations },
             { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "islamic.QuarterNames", metaValue_standalone_QuarterNames },
+            { "QuarterNarrows", metaValue_QuarterNarrows },
             { "islamic.abbreviated.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "long.Eras",
                 new String[] {
@@ -209,6 +212,7 @@ public class FormatData_se extends ListResourceBundle {
                     "ma\u014b\u014bel Kristtusa",
                 }
             },
+            { "roc.QuarterNarrows", metaValue_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "field.weekday", "v\u00e1hkkubeaivi" },
@@ -246,9 +250,11 @@ public class FormatData_se extends ListResourceBundle {
             { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
             { "field.dayperiod", "beaivi r\u00e1idod\u00e1ssi" },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
-            { "buddhist.QuarterAbbreviations", metaValue_standalone_QuarterAbbreviations },
+            { "japanese.QuarterNames", metaValue_standalone_QuarterNames },
+            { "buddhist.QuarterAbbreviations", metaValue_standalone_QuarterNames },
+            { "japanese.QuarterNarrows", metaValue_QuarterNarrows },
             { "timezone.hourFormat", "+HH:mm;\u2212HH:mm" },
-            { "roc.QuarterAbbreviations", metaValue_standalone_QuarterAbbreviations },
+            { "roc.QuarterAbbreviations", metaValue_standalone_QuarterNames },
             { "japanese.DayNames", metaValue_DayNames },
             { "japanese.DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNames", metaValue_DayNames },
@@ -258,15 +264,9 @@ public class FormatData_se extends ListResourceBundle {
             { "field.week", "v\u00e1hkku" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "#,##0.00\u00a0\u00a4",
-                    "#,##0\u00a0%",
-                }
-            },
             { "buddhist.MonthNarrows", metaValue_MonthNarrows },
-            { "islamic.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
+            { "buddhist.QuarterNames", metaValue_standalone_QuarterNames },
+            { "islamic.QuarterNarrows", metaValue_QuarterNarrows },
             { "roc.DayNarrows", metaValue_DayNarrows },
             { "roc.AmPmMarkers", metaValue_AmPmMarkers },
             { "short.CompactNumberPatterns",
@@ -274,18 +274,18 @@ public class FormatData_se extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u00a0dt",
-                    "00\u00a0dt",
-                    "000\u00a0dt",
-                    "0\u00a0mn",
-                    "00\u00a0mn",
-                    "000\u00a0mn",
-                    "0\u00a0md",
-                    "00\u00a0md",
-                    "000\u00a0md",
-                    "0\u00a0bn",
-                    "00\u00a0bn",
-                    "000\u00a0bn",
+                    "{one:0\u00a0dt two:0\u00a0dt other:0\u00a0dt}",
+                    "{one:00\u00a0dt two:00\u00a0dt other:00\u00a0dt}",
+                    "{one:000\u00a0dt two:000\u00a0dt other:000\u00a0dt}",
+                    "{one:0\u00a0mn two:0\u00a0mn other:0\u00a0mn}",
+                    "{one:00\u00a0mn two:00\u00a0mn other:00\u00a0mn}",
+                    "{one:000\u00a0mn two:000\u00a0mn other:000\u00a0mn}",
+                    "{one:0\u00a0md two:0\u00a0md other:0\u00a0md}",
+                    "{one:00\u00a0md two:00\u00a0md other:00\u00a0md}",
+                    "{one:000\u00a0md two:000\u00a0md other:000\u00a0md}",
+                    "{one:0\u00a0bn two:0\u00a0bn other:0\u00a0bn}",
+                    "{one:00\u00a0bn two:00\u00a0bn other:00\u00a0bn}",
+                    "{one:000\u00a0bn two:000\u00a0bn other:000\u00a0bn}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -308,30 +308,40 @@ public class FormatData_se extends ListResourceBundle {
             { "standalone.MonthNames", metaValue_MonthNames },
             { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "timezone.regionFormat", "{0} \u00e1igi" },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "#,##0\u00a0%",
+                    "#,##0.00\u00a0\u00a4",
+                }
+            },
             { "long.CompactNumberPatterns",
                 new String[] {
                     "",
                     "",
                     "",
-                    "0 duh\u00e1t",
-                    "00 duh\u00e1t",
-                    "000 duh\u00e1t",
-                    "0 miljona",
-                    "00 miljona",
-                    "000 miljona",
-                    "0 miljardi",
-                    "00 miljardi",
-                    "000 miljardi",
-                    "0 biljona",
-                    "00 biljona",
-                    "000 biljona",
+                    "{one:0' 'duh\u00e1t two:0' 'duh\u00e1hat other:0' 'duh\u00e1hat}",
+                    "{one:00' 'duh\u00e1t two:00' 'duh\u00e1hat other:00' 'duh\u00e1hat}",
+                    "{one:000' 'duh\u00e1t two:000' 'duh\u00e1hat other:000' 'duh\u00e1hat}",
+                    "{one:0' 'miljona two:0' 'miljonat other:0' 'miljonat}",
+                    "{one:00' 'miljona two:00' 'miljonat other:00' 'miljonat}",
+                    "{one:000' 'miljona two:000' 'miljonat other:000' 'miljonat}",
+                    "{one:0' 'miljardi two:0' 'miljardit other:0' 'miljardit}",
+                    "{one:00' 'miljardi two:00' 'miljardit other:00' 'miljardit}",
+                    "{one:000' 'miljardi two:000' 'miljardit other:000' 'miljardit}",
+                    "{one:0' 'biljona two:0' 'biljonat other:0' 'biljonat}",
+                    "{one:00' 'biljona two:00' 'biljonat other:00' 'biljonat}",
+                    "{one:000' 'biljona two:000' 'biljonat other:000' 'biljonat}",
                 }
             },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
+            { "buddhist.QuarterNarrows", metaValue_QuarterNarrows },
             { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
-            { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "roc.TimePatterns", metaValue_TimePatterns },
+            { "QuarterAbbreviations", metaValue_standalone_QuarterNames },
+            { "standalone.QuarterNames", metaValue_standalone_QuarterNames },
             { "japanese.MonthNarrows", metaValue_MonthNarrows },
             { "roc.abbreviated.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "calendarname.gregory", metaValue_calendarname_gregorian },
