@@ -154,16 +154,22 @@ public class FormatData_uk extends ListResourceBundle {
                "3-\u0439 \u043a\u0432.",
                "4-\u0439 \u043a\u0432.",
             };
-        final String[] metaValue_AmPmMarkers = new String[] {
-               "\u0434\u043f",
-               "\u043f\u043f",
-            };
-        final String[] metaValue_buddhist_QuarterNarrows = new String[] {
+        final String[] metaValue_QuarterNarrows = new String[] {
                "1",
                "2",
                "3",
                "4",
             };
+        final String[] metaValue_AmPmMarkers = new String[] {
+               "\u0434\u043f",
+               "\u043f\u043f",
+            };
+        final String[] metaValue_TimePatterns = new String[] {
+               "HH:mm:ss zzzz",
+               "HH:mm:ss z",
+               "HH:mm:ss",
+               "HH:mm",
+            };
         final String[] metaValue_java_time_buddhist_long_Eras = new String[] {
                "BC",
                "\u0431. \u0435.",
@@ -200,6 +206,10 @@ public class FormatData_uk extends ListResourceBundle {
                "\u0425\u0435\u0439\u0441\u0435\u0439",
                "\u0420\u0435\u0439\u0432\u0430",
             };
+        final String[] metaValue_java_time_islamic_long_Eras = new String[] {
+               "",
+               "AH",
+            };
         final String metaValue_calendarname_gregorian = "\u0433\u0440\u0438\u0433\u043e\u0440\u0456\u0430\u043d\u0441\u044c\u043a\u0438\u0439 \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440";
         final Object[][] data = new Object[][] {
             { "MonthNames", metaValue_MonthNames },
@@ -214,6 +224,7 @@ public class FormatData_uk extends ListResourceBundle {
             { "roc.MonthNarrows", metaValue_MonthNarrows },
             { "calendarname.islamic-civil", "\u043c\u0443\u0441\u0443\u043b\u044c\u043c\u0430\u043d\u0441\u044c\u043a\u0438\u0439 \u0441\u0432\u0456\u0442\u0441\u044c\u043a\u0438\u0439 \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440" },
             { "islamic.narrow.AmPmMarkers", metaValue_AmPmMarkers },
+            { "japanese.TimePatterns", metaValue_TimePatterns },
             { "narrow.Eras",
                 new String[] {
                     "\u0434\u043e \u043d.\u0435.",
@@ -227,12 +238,14 @@ public class FormatData_uk extends ListResourceBundle {
             { "japanese.MonthNames", metaValue_MonthNames },
             { "standalone.DayAbbreviations", metaValue_DayAbbreviations },
             { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "java.time.islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "long.Eras",
                 new String[] {
                     "\u0434\u043e \u043d\u0430\u0448\u043e\u0457 \u0435\u0440\u0438",
                     "\u043d\u0430\u0448\u043e\u0457 \u0435\u0440\u0438",
                 }
             },
+            { "roc.QuarterNarrows", metaValue_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -302,24 +315,37 @@ public class FormatData_uk extends ListResourceBundle {
                     "",
                 }
             },
+            { "japanese.QuarterNarrows", metaValue_QuarterNarrows },
             { "calendarname.roc", "\u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440 \u041a\u0438\u0442\u0430\u0439\u0441\u044c\u043a\u043e\u0457 \u0420\u0435\u0441\u043f\u0443\u0431\u043b\u0456\u043a\u0438" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "islamic.Eras", metaValue_java_time_islamic_long_Eras },
             { "field.month", "\u043c\u0456\u0441\u044f\u0446\u044c" },
             { "java.time.japanese.long.Eras", metaValue_java_time_japanese_long_Eras },
             { "field.second", "\u0441\u0435\u043a\u0443\u043d\u0434\u0430" },
-            { "DayAbbreviations", metaValue_DayAbbreviations },
-            { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
+            { "islamic.MonthNarrows",
                 new String[] {
-                    "#,##0.###",
-                    "#,##0.00\u00a0\u00a4",
-                    "#,##0%",
+                    "1",
+                    "2",
+                    "3",
+                    "4",
+                    "5",
+                    "6",
+                    "7",
+                    "8",
+                    "9",
+                    "10",
+                    "11",
+                    "12",
+                    "",
                 }
             },
+            { "DayAbbreviations", metaValue_DayAbbreviations },
+            { "DayNarrows", metaValue_DayNarrows },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "\u0456\u0441\u043b\u0430\u043c\u0441\u044c\u043a\u0438\u0439 \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440" },
             { "japanese.narrow.AmPmMarkers", metaValue_AmPmMarkers },
+            { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "standalone.MonthAbbreviations",
                 new String[] {
                     "\u0441\u0456\u0447",
@@ -343,22 +369,22 @@ public class FormatData_uk extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 \u0442\u0438\u0441\u044f\u0447\u0430",
-                    "00 \u0442\u0438\u0441\u044f\u0447\u0430",
-                    "000 \u0442\u0438\u0441\u044f\u0447\u0430",
-                    "0 \u043c\u0456\u043b\u044c\u0439\u043e\u043d",
-                    "00 \u043c\u0456\u043b\u044c\u0439\u043e\u043d",
-                    "000 \u043c\u0456\u043b\u044c\u0439\u043e\u043d",
-                    "0 \u043c\u0456\u043b\u044c\u044f\u0440\u0434",
-                    "00 \u043c\u0456\u043b\u044c\u044f\u0440\u0434",
-                    "000 \u043c\u0456\u043b\u044c\u044f\u0440\u0434",
-                    "0 \u0442\u0440\u0438\u043b\u044c\u0439\u043e\u043d",
-                    "00 \u0442\u0440\u0438\u043b\u044c\u0439\u043e\u043d",
-                    "000 \u0442\u0440\u0438\u043b\u044c\u0439\u043e\u043d",
+                    "{one:0' '\u0442\u0438\u0441\u044f\u0447\u0430 few:0' '\u0442\u0438\u0441\u044f\u0447\u0456 many:0' '\u0442\u0438\u0441\u044f\u0447 other:0' '\u0442\u0438\u0441\u044f\u0447\u0456}",
+                    "{one:00' '\u0442\u0438\u0441\u044f\u0447\u0430 few:00' '\u0442\u0438\u0441\u044f\u0447\u0456 many:00' '\u0442\u0438\u0441\u044f\u0447 other:00' '\u0442\u0438\u0441\u044f\u0447\u0456}",
+                    "{one:000' '\u0442\u0438\u0441\u044f\u0447\u0430 few:000' '\u0442\u0438\u0441\u044f\u0447\u0456 many:000' '\u0442\u0438\u0441\u044f\u0447 other:000' '\u0442\u0438\u0441\u044f\u0447\u0456}",
+                    "{one:0' '\u043c\u0456\u043b\u044c\u0439\u043e\u043d few:0' '\u043c\u0456\u043b\u044c\u0439\u043e\u043d\u0438 many:0' '\u043c\u0456\u043b\u044c\u0439\u043e\u043d\u0456\u0432 other:0' '\u043c\u0456\u043b\u044c\u0439\u043e\u043d\u0430}",
+                    "{one:00' '\u043c\u0456\u043b\u044c\u0439\u043e\u043d few:00' '\u043c\u0456\u043b\u044c\u0439\u043e\u043d\u0438 many:00' '\u043c\u0456\u043b\u044c\u0439\u043e\u043d\u0456\u0432 other:00' '\u043c\u0456\u043b\u044c\u0439\u043e\u043d\u0430}",
+                    "{one:000' '\u043c\u0456\u043b\u044c\u0439\u043e\u043d few:000' '\u043c\u0456\u043b\u044c\u0439\u043e\u043d\u0438 many:000' '\u043c\u0456\u043b\u044c\u0439\u043e\u043d\u0456\u0432 other:000' '\u043c\u0456\u043b\u044c\u0439\u043e\u043d\u0430}",
+                    "{one:0' '\u043c\u0456\u043b\u044c\u044f\u0440\u0434 few:0' '\u043c\u0456\u043b\u044c\u044f\u0440\u0434\u0438 many:0' '\u043c\u0456\u043b\u044c\u044f\u0440\u0434\u0456\u0432 other:0' '\u043c\u0456\u043b\u044c\u044f\u0440\u0434\u0430}",
+                    "{one:00' '\u043c\u0456\u043b\u044c\u044f\u0440\u0434 few:00' '\u043c\u0456\u043b\u044c\u044f\u0440\u0434\u0438 many:00' '\u043c\u0456\u043b\u044c\u044f\u0440\u0434\u0456\u0432 other:00' '\u043c\u0456\u043b\u044c\u044f\u0440\u0434\u0430}",
+                    "{one:000' '\u043c\u0456\u043b\u044c\u044f\u0440\u0434 few:000' '\u043c\u0456\u043b\u044c\u044f\u0440\u0434\u0438 many:000' '\u043c\u0456\u043b\u044c\u044f\u0440\u0434\u0456\u0432 other:000' '\u043c\u0456\u043b\u044c\u044f\u0440\u0434\u0430}",
+                    "{one:0' '\u0442\u0440\u0438\u043b\u044c\u0439\u043e\u043d few:0' '\u0442\u0440\u0438\u043b\u044c\u0439\u043e\u043d\u0438 many:0' '\u0442\u0440\u0438\u043b\u044c\u0439\u043e\u043d\u0456\u0432 other:0' '\u0442\u0440\u0438\u043b\u044c\u0439\u043e\u043d\u0430}",
+                    "{one:00' '\u0442\u0440\u0438\u043b\u044c\u0439\u043e\u043d few:00' '\u0442\u0440\u0438\u043b\u044c\u0439\u043e\u043d\u0438 many:00' '\u0442\u0440\u0438\u043b\u044c\u0439\u043e\u043d\u0456\u0432 other:00' '\u0442\u0440\u0438\u043b\u044c\u0439\u043e\u043d\u0430}",
+                    "{one:000' '\u0442\u0440\u0438\u043b\u044c\u0439\u043e\u043d few:000' '\u0442\u0440\u0438\u043b\u044c\u0439\u043e\u043d\u0438 many:000' '\u0442\u0440\u0438\u043b\u044c\u0439\u043e\u043d\u0456\u0432 other:000' '\u0442\u0440\u0438\u043b\u044c\u0439\u043e\u043d\u0430}",
                 }
             },
+            { "buddhist.QuarterNarrows", metaValue_QuarterNarrows },
             { "roc.narrow.AmPmMarkers", metaValue_AmPmMarkers },
-            { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "standalone.QuarterNames", metaValue_QuarterNames },
             { "japanese.MonthNarrows", metaValue_MonthNarrows },
             { "islamic.QuarterAbbreviations", metaValue_QuarterAbbreviations },
@@ -367,6 +393,7 @@ public class FormatData_uk extends ListResourceBundle {
             { "java.time.buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
             { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
             { "buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
+            { "TimePatterns", metaValue_TimePatterns },
             { "islamic.DayNarrows", metaValue_DayNarrows },
             { "field.zone", "\u0447\u0430\u0441\u043e\u0432\u0438\u0439 \u043f\u043e\u044f\u0441" },
             { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
@@ -380,11 +407,14 @@ public class FormatData_uk extends ListResourceBundle {
             },
             { "roc.DayNames", metaValue_DayNames },
             { "islamic.QuarterNames", metaValue_QuarterNames },
+            { "QuarterNarrows", metaValue_QuarterNarrows },
             { "islamic.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "field.weekday", "\u0434\u0435\u043d\u044c \u0442\u0438\u0436\u043d\u044f" },
             { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
+            { "islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
+            { "java.time.islamic.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.QuarterNames", metaValue_QuarterNames },
             { "buddhist.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "java.time.buddhist.Eras", metaValue_java_time_buddhist_long_Eras },
@@ -398,7 +428,7 @@ public class FormatData_uk extends ListResourceBundle {
             { "field.week", "\u0442\u0438\u0436\u0434\u0435\u043d\u044c" },
             { "buddhist.MonthNarrows", metaValue_MonthNarrows },
             { "buddhist.QuarterNames", metaValue_QuarterNames },
-            { "islamic.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
+            { "islamic.QuarterNarrows", metaValue_QuarterNarrows },
             { "roc.DayNarrows", metaValue_DayNarrows },
             { "roc.AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
@@ -408,18 +438,18 @@ public class FormatData_uk extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u00a0\u0442\u0438\u0441'.'",
-                    "00\u00a0\u0442\u0438\u0441'.'",
-                    "000\u00a0\u0442\u0438\u0441'.'",
-                    "0\u00a0\u043c\u043b\u043d",
-                    "00\u00a0\u043c\u043b\u043d",
-                    "000\u00a0\u043c\u043b\u043d",
-                    "0\u00a0\u043c\u043b\u0440\u0434",
-                    "00\u00a0\u043c\u043b\u0440\u0434",
-                    "000\u00a0\u043c\u043b\u0440\u0434",
-                    "0\u00a0\u0442\u0440\u043b\u043d",
-                    "00\u00a0\u0442\u0440\u043b\u043d",
-                    "000\u00a0\u0442\u0440\u043b\u043d",
+                    "{one:0\u00a0\u0442\u0438\u0441'.' few:0\u00a0\u0442\u0438\u0441'.' many:0\u00a0\u0442\u0438\u0441'.' other:0\u00a0\u0442\u0438\u0441'.'}",
+                    "{one:00\u00a0\u0442\u0438\u0441'.' few:00\u00a0\u0442\u0438\u0441'.' many:00\u00a0\u0442\u0438\u0441'.' other:00\u00a0\u0442\u0438\u0441'.'}",
+                    "{one:000\u00a0\u0442\u0438\u0441'.' few:000\u00a0\u0442\u0438\u0441'.' many:000\u00a0\u0442\u0438\u0441'.' other:000\u00a0\u0442\u0438\u0441'.'}",
+                    "{one:0\u00a0\u043c\u043b\u043d few:0\u00a0\u043c\u043b\u043d many:0\u00a0\u043c\u043b\u043d other:0\u00a0\u043c\u043b\u043d}",
+                    "{one:00\u00a0\u043c\u043b\u043d few:00\u00a0\u043c\u043b\u043d many:00\u00a0\u043c\u043b\u043d other:00\u00a0\u043c\u043b\u043d}",
+                    "{one:000\u00a0\u043c\u043b\u043d few:000\u00a0\u043c\u043b\u043d many:000\u00a0\u043c\u043b\u043d other:000\u00a0\u043c\u043b\u043d}",
+                    "{one:0\u00a0\u043c\u043b\u0440\u0434 few:0\u00a0\u043c\u043b\u0440\u0434 many:0\u00a0\u043c\u043b\u0440\u0434 other:0\u00a0\u043c\u043b\u0440\u0434}",
+                    "{one:00\u00a0\u043c\u043b\u0440\u0434 few:00\u00a0\u043c\u043b\u0440\u0434 many:00\u00a0\u043c\u043b\u0440\u0434 other:00\u00a0\u043c\u043b\u0440\u0434}",
+                    "{one:000\u00a0\u043c\u043b\u0440\u0434 few:000\u00a0\u043c\u043b\u0440\u0434 many:000\u00a0\u043c\u043b\u0440\u0434 other:000\u00a0\u043c\u043b\u0440\u0434}",
+                    "{one:0\u00a0\u0442\u0440\u043b\u043d few:0\u00a0\u0442\u0440\u043b\u043d many:0\u00a0\u0442\u0440\u043b\u043d other:0\u00a0\u0442\u0440\u043b\u043d}",
+                    "{one:00\u00a0\u0442\u0440\u043b\u043d few:00\u00a0\u0442\u0440\u043b\u043d many:00\u00a0\u0442\u0440\u043b\u043d other:00\u00a0\u0442\u0440\u043b\u043d}",
+                    "{one:000\u00a0\u0442\u0440\u043b\u043d few:000\u00a0\u0442\u0440\u043b\u043d many:000\u00a0\u0442\u0440\u043b\u043d other:000\u00a0\u0442\u0440\u043b\u043d}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -434,6 +464,7 @@ public class FormatData_uk extends ListResourceBundle {
                 }
             },
             { "buddhist.DayAbbreviations", metaValue_DayAbbreviations },
+            { "islamic.TimePatterns", metaValue_TimePatterns },
             { "MonthAbbreviations", metaValue_MonthAbbreviations },
             { "standalone.DayNames", metaValue_DayNames },
             { "field.hour", "\u0433\u043e\u0434\u0438\u043d\u0430" },
@@ -454,6 +485,7 @@ public class FormatData_uk extends ListResourceBundle {
                     "",
                 }
             },
+            { "islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "calendarname.buddhist", "\u0431\u0443\u0434\u0434\u0456\u0439\u0441\u044c\u043a\u0438\u0439 \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440" },
             { "standalone.MonthNames",
                 new String[] {
@@ -472,9 +504,19 @@ public class FormatData_uk extends ListResourceBundle {
                     "",
                 }
             },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "#,##0%",
+                    "#,##0.00\u00a0\u00a4",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
+            { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
+            { "roc.TimePatterns", metaValue_TimePatterns },
             { "QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "japanese.Eras", metaValue_java_time_japanese_Eras },
             { "roc.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
