@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -100,6 +100,21 @@ public class FormatData_vi extends ListResourceBundle {
                "thg 12",
                "",
             };
+        final String[] metaValue_MonthNarrows = new String[] {
+               "1",
+               "2",
+               "3",
+               "4",
+               "5",
+               "6",
+               "7",
+               "8",
+               "9",
+               "10",
+               "11",
+               "12",
+               "",
+            };
         final String[] metaValue_DayNames = new String[] {
                "Ch\u1ee7 Nh\u1eadt",
                "Th\u1ee9 Hai",
@@ -133,12 +148,18 @@ public class FormatData_vi extends ListResourceBundle {
                "Qu\u00fd 3",
                "Qu\u00fd 4",
             };
-        final String[] metaValue_standalone_QuarterAbbreviations = new String[] {
+        final String[] metaValue_QuarterAbbreviations = new String[] {
                "Q1",
                "Q2",
                "Q3",
                "Q4",
             };
+        final String[] metaValue_QuarterNarrows = new String[] {
+               "1",
+               "2",
+               "3",
+               "4",
+            };
         final String[] metaValue_AmPmMarkers = new String[] {
                "SA",
                "CH",
@@ -157,28 +178,7 @@ public class FormatData_vi extends ListResourceBundle {
                "HH:mm:ss",
                "HH:mm",
             };
-        final String[] metaValue_buddhist_MonthNarrows = new String[] {
-               "1",
-               "2",
-               "3",
-               "4",
-               "5",
-               "6",
-               "7",
-               "8",
-               "9",
-               "10",
-               "11",
-               "12",
-               "",
-            };
-        final String[] metaValue_buddhist_QuarterNarrows = new String[] {
-               "1",
-               "2",
-               "3",
-               "4",
-            };
-        final String[] metaValue_buddhist_long_Eras = new String[] {
+        final String[] metaValue_java_time_buddhist_long_Eras = new String[] {
                "BC",
                "BE",
             };
@@ -194,11 +194,11 @@ public class FormatData_vi extends ListResourceBundle {
                "dd-MM-y GGGG",
                "dd/MM/y G",
             };
-        final String[] metaValue_roc_long_Eras = new String[] {
+        final String[] metaValue_java_time_roc_long_Eras = new String[] {
                "Tr\u01b0\u1edbc R.O.C",
-               "R.O.C.",
+               "",
             };
-        final String[] metaValue_islamic_long_Eras = new String[] {
+        final String[] metaValue_java_time_islamic_long_Eras = new String[] {
                "",
                "AH",
             };
@@ -208,7 +208,7 @@ public class FormatData_vi extends ListResourceBundle {
             { "field.year", "N\u0103m" },
             { "calendarname.islamic-umalqura", "L\u1ecbch H\u1ed3i Gi\u00e1o - Umm al-Qura" },
             { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
-            { "buddhist.narrow.Eras", metaValue_buddhist_long_Eras },
+            { "buddhist.narrow.Eras", metaValue_java_time_buddhist_long_Eras },
             { "AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.japanese.DatePatterns",
                 new String[] {
@@ -218,13 +218,13 @@ public class FormatData_vi extends ListResourceBundle {
                     "dd/MM/y G",
                 }
             },
-            { "standalone.QuarterAbbreviations", metaValue_standalone_QuarterAbbreviations },
+            { "standalone.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.QuarterNames", metaValue_QuarterNames },
-            { "roc.MonthNarrows", metaValue_buddhist_MonthNarrows },
+            { "roc.MonthNarrows", metaValue_MonthNarrows },
             { "calendarname.islamic-civil", "L\u1ecbch Islamic-Civil" },
             { "islamic.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "japanese.TimePatterns", metaValue_TimePatterns },
-            { "roc.long.Eras", metaValue_roc_long_Eras },
+            { "roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "narrow.Eras",
                 new String[] {
                     "tr. CN",
@@ -238,7 +238,9 @@ public class FormatData_vi extends ListResourceBundle {
             { "japanese.MonthNames", metaValue_MonthNames },
             { "standalone.DayAbbreviations", metaValue_DayAbbreviations },
             { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "java.time.islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "long.Eras", metaValue_long_Eras },
+            { "roc.QuarterNarrows", metaValue_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -266,6 +268,7 @@ public class FormatData_vi extends ListResourceBundle {
                     "NaN",
                 }
             },
+            { "MonthNarrows", metaValue_MonthNarrows },
             { "japanese.DatePatterns",
                 new String[] {
                     "EEEE, 'ng\u00e0y' dd MMMM 'n\u0103m' y GGGG",
@@ -279,6 +282,7 @@ public class FormatData_vi extends ListResourceBundle {
             { "field.era", "th\u1eddi \u0111\u1ea1i" },
             { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
             { "field.dayperiod", "SA/CH" },
+            { "japanese.QuarterNarrows", metaValue_QuarterNarrows },
             { "calendarname.roc", "L\u1ecbch Trung Hoa D\u00e2n Qu\u1ed1c" },
             { "islamic.DatePatterns",
                 new String[] {
@@ -288,22 +292,17 @@ public class FormatData_vi extends ListResourceBundle {
                     "dd/MM/y G",
                 }
             },
-            { "roc.QuarterAbbreviations", metaValue_standalone_QuarterAbbreviations },
-            { "islamic.Eras", metaValue_islamic_long_Eras },
+            { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "islamic.Eras", metaValue_java_time_islamic_long_Eras },
             { "field.month", "Th\u00e1ng" },
-            { "roc.Eras", metaValue_roc_long_Eras },
+            { "roc.Eras", metaValue_java_time_roc_long_Eras },
             { "field.second", "Gi\u00e2y" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "#,##0.00\u00a0\u00a4",
-                    "#,##0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "L\u1ecbch H\u1ed3i Gi\u00e1o" },
+            { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
+            { "java.time.roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
             { "japanese.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "standalone.MonthAbbreviations",
@@ -324,8 +323,27 @@ public class FormatData_vi extends ListResourceBundle {
                 }
             },
             { "timezone.regionFormat", "Gi\u1edd {0}" },
+            { "long.CompactNumberPatterns",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "{other:0' 'ngh\u00ecn}",
+                    "{other:00' 'ngh\u00ecn}",
+                    "{other:000' 'ngh\u00ecn}",
+                    "{other:0' 'tri\u1ec7u}",
+                    "{other:00' 'tri\u1ec7u}",
+                    "{other:000' 'tri\u1ec7u}",
+                    "{other:0' 't\u1ef7}",
+                    "{other:00' 't\u1ef7}",
+                    "{other:000' 't\u1ef7}",
+                    "{other:0' 'ngh\u00ecn' 't\u1ef7}",
+                    "{other:00' 'ngh\u00ecn' 't\u1ef7}",
+                    "{other:000' 'ngh\u00ecn' 't\u1ef7}",
+                }
+            },
+            { "buddhist.QuarterNarrows", metaValue_QuarterNarrows },
             { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
-            { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "standalone.QuarterNames",
                 new String[] {
                     "qu\u00fd 1",
@@ -334,22 +352,25 @@ public class FormatData_vi extends ListResourceBundle {
                     "qu\u00fd 4",
                 }
             },
-            { "japanese.MonthNarrows", metaValue_buddhist_MonthNarrows },
-            { "islamic.QuarterAbbreviations", metaValue_standalone_QuarterAbbreviations },
+            { "japanese.MonthNarrows", metaValue_MonthNarrows },
+            { "islamic.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.DayAbbreviations", metaValue_DayAbbreviations },
             { "standalone.DayNarrows", metaValue_DayNarrows },
+            { "java.time.buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
             { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
-            { "buddhist.long.Eras", metaValue_buddhist_long_Eras },
+            { "buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
             { "TimePatterns", metaValue_TimePatterns },
             { "islamic.DayNarrows", metaValue_DayNarrows },
+            { "java.time.roc.Eras", metaValue_java_time_roc_long_Eras },
             { "field.zone", "M\u00fai gi\u1edd" },
-            { "japanese.QuarterAbbreviations", metaValue_standalone_QuarterAbbreviations },
-            { "roc.narrow.Eras", metaValue_roc_long_Eras },
+            { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
             { "buddhist.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "buddhist.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "Eras", metaValue_long_Eras },
             { "roc.DayNames", metaValue_DayNames },
             { "islamic.QuarterNames", metaValue_QuarterNames },
+            { "QuarterNarrows", metaValue_QuarterNarrows },
             { "islamic.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.islamic.DatePatterns",
                 new String[] {
@@ -362,24 +383,46 @@ public class FormatData_vi extends ListResourceBundle {
             { "field.weekday", "ng\u00e0y trong tu\u1ea7n" },
             { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
-            { "islamic.long.Eras", metaValue_islamic_long_Eras },
+            { "islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
+            { "java.time.islamic.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.QuarterNames", metaValue_QuarterNames },
-            { "buddhist.QuarterAbbreviations", metaValue_standalone_QuarterAbbreviations },
+            { "buddhist.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "java.time.buddhist.Eras", metaValue_java_time_buddhist_long_Eras },
             { "japanese.DayNames", metaValue_DayNames },
             { "japanese.DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNames", metaValue_DayNames },
             { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.MonthNames", metaValue_MonthNames },
-            { "buddhist.Eras", metaValue_buddhist_long_Eras },
+            { "buddhist.Eras", metaValue_java_time_buddhist_long_Eras },
             { "field.week", "Tu\u1ea7n" },
+            { "buddhist.MonthNarrows", metaValue_MonthNarrows },
             { "buddhist.QuarterNames", metaValue_QuarterNames },
-            { "buddhist.MonthNarrows", metaValue_buddhist_MonthNarrows },
-            { "islamic.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
+            { "islamic.QuarterNarrows", metaValue_QuarterNarrows },
             { "roc.DayNarrows", metaValue_DayNarrows },
             { "roc.AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
+            { "short.CompactNumberPatterns",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "{other:0\u00a0N}",
+                    "{other:00\u00a0N}",
+                    "{other:000\u00a0N}",
+                    "{other:0\u00a0Tr}",
+                    "{other:00\u00a0Tr}",
+                    "{other:000\u00a0Tr}",
+                    "{other:0\u00a0T}",
+                    "{other:00\u00a0T}",
+                    "{other:000\u00a0T}",
+                    "{other:0\u00a0NT}",
+                    "{other:00\u00a0NT}",
+                    "{other:000\u00a0NT}",
+                }
+            },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
+            { "java.time.buddhist.narrow.Eras", metaValue_java_time_buddhist_long_Eras },
             { "timezone.regionFormat.daylight", "Gi\u1edd m\u00f9a h\u00e8 {0}" },
             { "DatePatterns",
                 new String[] {
@@ -394,7 +437,7 @@ public class FormatData_vi extends ListResourceBundle {
             { "MonthAbbreviations", metaValue_MonthAbbreviations },
             { "standalone.DayNames", metaValue_DayNames },
             { "field.hour", "Gi\u1edd" },
-            { "islamic.narrow.Eras", metaValue_islamic_long_Eras },
+            { "islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "calendarname.buddhist", "L\u1ecbch Ph\u1eadt Gi\u00e1o" },
             { "standalone.MonthNames",
                 new String[] {
@@ -413,10 +456,20 @@ public class FormatData_vi extends ListResourceBundle {
                     "",
                 }
             },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "#,##0%",
+                    "#,##0.00\u00a0\u00a4",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
+            { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
             { "roc.TimePatterns", metaValue_TimePatterns },
+            { "QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "calendarname.gregory", metaValue_calendarname_gregorian },
         };
