@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -84,8 +84,6 @@ public class CurrencyNames_pl extends OpenListResourceBundle {
             { "BAM", "BAM" },
             { "BBD", "BBD" },
             { "BDT", "BDT" },
-            { "BGL", "BGL" },
-            { "BGM", "BGM" },
             { "BGN", "BGN" },
             { "BHD", "BHD" },
             { "BIF", "BIF" },
@@ -96,7 +94,6 @@ public class CurrencyNames_pl extends OpenListResourceBundle {
             { "BTN", "BTN" },
             { "BWP", "BWP" },
             { "BYN", "BYN" },
-            { "BYR", "BYR" },
             { "BZD", "BZD" },
             { "CAD", "CAD" },
             { "CDF", "CDF" },
@@ -154,8 +151,6 @@ public class CurrencyNames_pl extends OpenListResourceBundle {
             { "LBP", "LBP" },
             { "LKR", "LKR" },
             { "LRD", "LRD" },
-            { "LTL", "LTL" },
-            { "LVL", "LVL" },
             { "LYD", "LYD" },
             { "MAD", "MAD" },
             { "MDL", "MDL" },
@@ -164,7 +159,7 @@ public class CurrencyNames_pl extends OpenListResourceBundle {
             { "MMK", "MMK" },
             { "MNT", "MNT" },
             { "MOP", "MOP" },
-            { "MRO", "MRO" },
+            { "MRU", "MRU" },
             { "MUR", "MUR" },
             { "MVR", "MVR" },
             { "MWK", "MWK" },
@@ -202,7 +197,6 @@ public class CurrencyNames_pl extends OpenListResourceBundle {
             { "SOS", "SOS" },
             { "SRD", "SRD" },
             { "SSP", "SSP" },
-            { "STD", "STD" },
             { "STN", "STN" },
             { "SYP", "SYP" },
             { "SZL", "SZL" },
@@ -220,7 +214,7 @@ public class CurrencyNames_pl extends OpenListResourceBundle {
             { "USD", "USD" },
             { "UYU", "UYU" },
             { "UZS", "UZS" },
-            { "VEF", "VEF" },
+            { "VES", "VES" },
             { "VND", "VND" },
             { "VUV", "VUV" },
             { "WST", "WST" },
@@ -228,13 +222,13 @@ public class CurrencyNames_pl extends OpenListResourceBundle {
             { "ZAR", "ZAR" },
             { "ZMW", "ZMW" },
             { "adp", "peseta andorska" },
-            { "aed", "dirham arabski" },
+            { "aed", "dirham ZEA" },
             { "afa", "afgani (1927\u20132002)" },
-            { "afn", "afgani" },
+            { "afn", "afgani afga\u0144skie" },
             { "all", "lek alba\u0144ski" },
             { "amd", "dram arme\u0144ski" },
             { "ang", "gulden antylski" },
-            { "aoa", "kwanza angola\u0144ska" },
+            { "aoa", "kwanza angolska" },
             { "aok", "kwanza angola\u0144ska (1977\u20131990)" },
             { "aon", "nowa kwanza angola\u0144ska (1990\u20132000)" },
             { "aor", "kwanza angola\u0144ska Reajustado (1995\u20131999)" },
@@ -261,7 +255,7 @@ public class CurrencyNames_pl extends OpenListResourceBundle {
             { "bif", "frank burundyjski" },
             { "bmd", "dolar bermudzki" },
             { "bnd", "dolar brunejski" },
-            { "bob", "boliviano" },
+            { "bob", "boliviano boliwijskie" },
             { "bop", "peso boliwijskie" },
             { "bov", "mvdol boliwijski" },
             { "brb", "cruzeiro novo brazylijskie (1967\u20131986)" },
@@ -316,7 +310,7 @@ public class CurrencyNames_pl extends OpenListResourceBundle {
             { "gek", "kupon gruzi\u0144ski larit" },
             { "gel", "lari gruzi\u0144skie" },
             { "ghc", "cedi gha\u0144skie (1979\u20132007)" },
-            { "ghs", "cedi gha\u0144ski" },
+            { "ghs", "cedi gha\u0144skie" },
             { "gip", "funt gibraltarski" },
             { "gmd", "dalasi gambijskie" },
             { "gnf", "frank gwinejski" },
@@ -331,7 +325,7 @@ public class CurrencyNames_pl extends OpenListResourceBundle {
             { "hnl", "lempira honduraska" },
             { "hrd", "dinar chorwacki" },
             { "hrk", "kuna chorwacka" },
-            { "htg", "gourde haita\u0144skie" },
+            { "htg", "gourde haita\u0144ski" },
             { "huf", "forint w\u0119gierski" },
             { "idr", "rupia indonezyjska" },
             { "iep", "funt irlandzki" },
@@ -376,7 +370,7 @@ public class CurrencyNames_pl extends OpenListResourceBundle {
             { "mnt", "tugrik mongolski" },
             { "mop", "pataca Makau" },
             { "mro", "ouguiya maureta\u0144ska (1973\u20132017)" },
-            { "mru", "ouguiya maureta\u0144ska" },
+            { "mru", "ugija maureta\u0144ska" },
             { "mtl", "lira malta\u0144ska" },
             { "mtp", "funt malta\u0144ski" },
             { "mur", "rupia maurytyjska" },
@@ -401,7 +395,7 @@ public class CurrencyNames_pl extends OpenListResourceBundle {
             { "pei", "inti peruwia\u0144ski" },
             { "pen", "sol peruwia\u0144ski" },
             { "pes", "sol peruwia\u0144ski (1863\u20131965)" },
-            { "pgk", "kina Papua Nowa Gwinea" },
+            { "pgk", "kina papua\u0144ska" },
             { "php", "peso filipi\u0144skie" },
             { "pkr", "rupia pakista\u0144ska" },
             { "pln", "z\u0142oty polski" },
@@ -424,7 +418,7 @@ public class CurrencyNames_pl extends OpenListResourceBundle {
             { "sdp", "funt suda\u0144ski (1957\u20131998)" },
             { "sek", "korona szwedzka" },
             { "sgd", "dolar singapurski" },
-            { "shp", "funt Wyspy \u015awi\u0119tej Heleny" },
+            { "shp", "funt \u015awi\u0119tej Heleny" },
             { "sit", "tolar s\u0142owe\u0144ski" },
             { "skk", "korona s\u0142owacka" },
             { "sll", "leone sierraleo\u0144ski" },
@@ -460,7 +454,8 @@ public class CurrencyNames_pl extends OpenListResourceBundle {
             { "uyu", "peso urugwajskie" },
             { "uzs", "som uzbecki" },
             { "veb", "boliwar wenezuelski (1871\u20132008)" },
-            { "vef", "boliwar wenezuelski" },
+            { "vef", "boliwar wenezuelski (2008\u20132018)" },
+            { "ves", "boliwar wenezuelski" },
             { "vnd", "dong wietnamski" },
             { "vuv", "vatu wanuackie" },
             { "wst", "tala samoa\u0144skie" },
