@@ -144,7 +144,7 @@ public class LocaleNames_ca extends OpenListResourceBundle {
             { "type.ca.ethiopic", "calendari et\u00edop" },
             { "glk", "gilaki" },
             { "AI", "Anguilla" },
-            { "key.tz", "Zona hor\u00e0ria" },
+            { "key.tz", "zona hor\u00e0ria" },
             { "AL", "Alb\u00e0nia" },
             { "AM", "Arm\u00e8nia" },
             { "Teng", "tengwar" },
@@ -164,7 +164,7 @@ public class LocaleNames_ca extends OpenListResourceBundle {
             { "BA", "B\u00f2snia i Hercegovina" },
             { "BB", "Barbados" },
             { "ceb", "cebu\u00e0" },
-            { "BD", "Bangla Desh" },
+            { "BD", "Bangladesh" },
             { "kum", "k\u00famik" },
             { "BE", "B\u00e8lgica" },
             { "gmh", "alt alemany mitj\u00e0" },
@@ -198,7 +198,7 @@ public class LocaleNames_ca extends OpenListResourceBundle {
             { "CF", "Rep\u00fablica Centreafricana" },
             { "CG", "Congo - Brazzaville" },
             { "CH", "Su\u00efssa" },
-            { "CI", "Costa d\u2019Ivori" },
+            { "CI", "C\u00f4te d\u2019Ivoire" },
             { "CK", "Illes Cook" },
             { "CL", "Xile" },
             { "Kthi", "kaithi" },
@@ -277,7 +277,7 @@ public class LocaleNames_ca extends OpenListResourceBundle {
             { "FJ", "Fiji" },
             { "FK", "Illes Malvines" },
             { "FM", "Micron\u00e8sia" },
-            { "key.va", "Variant local" },
+            { "key.va", "variant local" },
             { "FO", "Illes F\u00e8roe" },
             { "Taml", metaValue_ta },
             { "FR", "Fran\u00e7a" },
@@ -302,7 +302,7 @@ public class LocaleNames_ca extends OpenListResourceBundle {
             { "Tale", "tai le" },
             { "GI", "Gibraltar" },
             { "afh", "afrihili" },
-            { "GL", "Grenl\u00e0ndia" },
+            { "GL", "Groenl\u00e0ndia" },
             { "enm", "angl\u00e8s mitj\u00e0" },
             { "GM", "G\u00e0mbia" },
             { "GN", "Guinea" },
@@ -510,7 +510,7 @@ public class LocaleNames_ca extends OpenListResourceBundle {
             { "PN", "Illes Pitcairn" },
             { "PR", "Puerto Rico" },
             { "Bali", metaValue_ban },
-            { "PS", "territoris palestins" },
+            { "PS", "Territoris palestins" },
             { "PT", "Portugal" },
             { "PW", "Palau" },
             { "nia", "nias" },
@@ -593,7 +593,7 @@ public class LocaleNames_ca extends OpenListResourceBundle {
             { "arw", "arauac" },
             { "arz", "\u00e0rab egipci" },
             { "yap", "yape\u00e0" },
-            { "TA", "Trist\u00e3o da Cunha" },
+            { "TA", "Tristan da Cunha" },
             { "asa", "pare" },
             { "type.ms.ussystem", "sistema d\u2019unitats dels EUA" },
             { "021", "Am\u00e8rica septentrional" },
@@ -679,9 +679,9 @@ public class LocaleNames_ca extends OpenListResourceBundle {
             { "type.nu.mtei", "d\u00edgits meitei mayek" },
             { "wal", "wolaita" },
             { "was", "washo" },
-            { "XA", "Pseudo-Accents" },
+            { "XA", "pseudoaccents" },
             { "war", "waray" },
-            { "XB", "Pseudo-Bidi" },
+            { "XB", "pseudobidi" },
             { "awa", "awadhi" },
             { "061", "Polin\u00e8sia" },
             { "XK", "Kosovo" },
@@ -711,7 +711,7 @@ public class LocaleNames_ca extends OpenListResourceBundle {
             { "ZM", "Z\u00e0mbia" },
             { "%%PINYIN", "romanitzaci\u00f3 Pinyin" },
             { "ZW", "Zimb\u00e0bue" },
-            { "ZZ", "Regi\u00f3 desconeguda" },
+            { "ZZ", "regi\u00f3 desconeguda" },
             { "Runr", "r\u00fanic" },
             { "type.ms.metric", "sistema m\u00e8tric" },
             { "type.ca.iso8601", "calendari ISO-8601" },
