@@ -199,7 +199,7 @@ public class LocaleNames_fa extends OpenListResourceBundle {
             { "CX", "\u062c\u0632\u06cc\u0631\u0647\u0654 \u06a9\u0631\u06cc\u0633\u0645\u0633" },
             { "CY", "\u0642\u0628\u0631\u0633" },
             { "type.nu.bali", "\u0627\u0631\u0642\u0627\u0645 \u0628\u0627\u0644\u06cc\u0627\u06cc\u06cc" },
-            { "CZ", "\u062c\u0645\u0647\u0648\u0631\u06cc \u0686\u06a9" },
+            { "CZ", "\u0686\u06a9" },
             { "eka", "\u0627\u06a9\u0627\u062c\u0648\u06a9" },
             { "DE", "\u0622\u0644\u0645\u0627\u0646" },
             { "goh", "\u0622\u0644\u0645\u0627\u0646\u06cc \u0639\u0644\u06cc\u0627\u06cc \u0628\u0627\u0633\u062a\u0627\u0646" },
@@ -241,6 +241,7 @@ public class LocaleNames_fa extends OpenListResourceBundle {
             { "chm", "\u0645\u0627\u0631\u06cc\u0627\u06cc\u06cc" },
             { "chp", "\u0686\u06cc\u067e\u0647\u200c\u0648\u06cc\u0647\u200c\u0627\u06cc" },
             { "cho", "\u0686\u0648\u06a9\u062a\u0648\u06cc\u06cc" },
+            { "type.nu.mathbold", "\u0627\u0631\u0642\u0627\u0645 \u0631\u06cc\u0627\u0636\u06cc \u0633\u06cc\u0627\u0647" },
             { "chr", metaValue_chr },
             { "ER", "\u0627\u0631\u06cc\u062a\u0631\u0647" },
             { "ES", "\u0627\u0633\u067e\u0627\u0646\u06cc\u0627" },
@@ -248,7 +249,7 @@ public class LocaleNames_fa extends OpenListResourceBundle {
             { "EU", "\u0627\u062a\u062d\u0627\u062f\u06cc\u0647\u0654 \u0627\u0631\u0648\u067e\u0627" },
             { "elx", "\u0639\u06cc\u0644\u0627\u0645\u06cc" },
             { "type.ca.gregorian", "\u062a\u0642\u0648\u06cc\u0645 \u0645\u06cc\u0644\u0627\u062f\u06cc" },
-            { "EZ", "\u0645\u0646\u0637\u0642\u0647 \u06cc\u0648\u0631\u0648" },
+            { "EZ", "\u0645\u0646\u0637\u0642\u0647\u0654 \u06cc\u0648\u0631\u0648" },
             { "chy", "\u0634\u0627\u06cc\u0627\u0646\u06cc" },
             { "type.nu.gujr", "\u0627\u0631\u0642\u0627\u0645 \u06af\u062c\u0631\u0627\u062a\u06cc" },
             { "Inds", "\u0627\u06cc\u0646\u062f\u0648\u0633" },
@@ -284,7 +285,7 @@ public class LocaleNames_fa extends OpenListResourceBundle {
             { "GP", "\u06af\u0648\u0627\u062f\u0644\u0648\u067e" },
             { "GQ", "\u06af\u06cc\u0646\u0647\u0654 \u0627\u0633\u062a\u0648\u0627\u06cc\u06cc" },
             { "GR", "\u06cc\u0648\u0646\u0627\u0646" },
-            { "GS", "\u062c\u0632\u0627\u06cc\u0631 \u062c\u0648\u0631\u062c\u06cc\u0627\u06cc \u062c\u0646\u0648\u0628\u06cc \u0648 \u0633\u0627\u0646\u062f\u0648\u06cc\u0686 \u062c\u0646\u0648\u0628\u06cc" },
+            { "GS", "\u062c\u0648\u0631\u062c\u06cc\u0627\u06cc \u062c\u0646\u0648\u0628\u06cc \u0648 \u062c\u0632\u0627\u06cc\u0631 \u0633\u0627\u0646\u062f\u0648\u06cc\u0686 \u062c\u0646\u0648\u0628\u06cc" },
             { "GT", "\u06af\u0648\u0627\u062a\u0645\u0627\u0644\u0627" },
             { "GU", "\u06af\u0648\u0627\u0645" },
             { "pdc", "\u0622\u0644\u0645\u0627\u0646\u06cc \u067e\u0646\u0633\u06cc\u0644\u0648\u0627\u0646\u06cc\u0627\u06cc\u06cc" },
@@ -296,8 +297,8 @@ public class LocaleNames_fa extends OpenListResourceBundle {
             { "zxx", "\u0628\u062f\u0648\u0646 \u0645\u062d\u062a\u0648\u0627\u06cc \u0632\u0628\u0627\u0646\u06cc" },
             { "de_AT", "\u0622\u0644\u0645\u0627\u0646\u06cc \u0627\u062a\u0631\u06cc\u0634" },
             { "Vaii", metaValue_vai },
-            { "HK", "\u0647\u0646\u06af\u200c\u06a9\u0646\u06af\u060c \u0645\u0646\u0637\u0642\u06c0 \u0648\u06cc\u0698\u06c0 \u0627\u062f\u0627\u0631\u06cc \u0686\u06cc\u0646" },
-            { "HM", "\u062c\u0632\u06cc\u0631\u0647\u0654 \u0647\u0631\u062f \u0648 \u062c\u0632\u0627\u06cc\u0631 \u0645\u06a9\u200c\u062f\u0648\u0646\u0627\u0644\u062f" },
+            { "HK", "\u0647\u0646\u06af\u200c\u06a9\u0646\u06af\u060c \u0645\u0646\u0637\u0642\u0647\u0654 \u0648\u06cc\u0698\u0647\u0654 \u0627\u062f\u0627\u0631\u06cc \u0686\u06cc\u0646" },
+            { "HM", "\u0647\u0631\u062f \u0648 \u062c\u0632\u0627\u06cc\u0631 \u0645\u06a9\u200c\u062f\u0648\u0646\u0627\u0644\u062f" },
             { "HN", "\u0647\u0646\u062f\u0648\u0631\u0627\u0633" },
             { "HR", "\u06a9\u0631\u0648\u0627\u0633\u06cc" },
             { "agq", "\u0622\u06af\u06cc\u0645" },
@@ -400,7 +401,7 @@ public class LocaleNames_fa extends OpenListResourceBundle {
             { "MM", "\u0645\u06cc\u0627\u0646\u0645\u0627\u0631 (\u0628\u0631\u0645\u0647)" },
             { "MN", "\u0645\u063a\u0648\u0644\u0633\u062a\u0627\u0646" },
             { "new", "\u0646\u0648\u0627\u0631\u06cc\u0627\u06cc\u06cc" },
-            { "MO", "\u0645\u0627\u06a9\u0627\u0626\u0648\u060c \u0645\u0646\u0637\u0642\u06c0 \u0648\u06cc\u0698\u06c0 \u0627\u062f\u0627\u0631\u06cc \u0686\u06cc\u0646" },
+            { "MO", "\u0645\u0627\u06a9\u0627\u0626\u0648\u060c \u0645\u0646\u0637\u0642\u0647\u0654 \u0648\u06cc\u0698\u0647\u0654 \u0627\u062f\u0627\u0631\u06cc \u0686\u06cc\u0646" },
             { "MP", "\u062c\u0632\u0627\u06cc\u0631 \u0645\u0627\u0631\u06cc\u0627\u0646\u0627\u06cc \u0634\u0645\u0627\u0644\u06cc" },
             { "MQ", "\u0645\u0627\u0631\u062a\u06cc\u0646\u06cc\u06a9" },
             { "MR", "\u0645\u0648\u0631\u06cc\u062a\u0627\u0646\u06cc" },
@@ -417,7 +418,7 @@ public class LocaleNames_fa extends OpenListResourceBundle {
             { "MZ", "\u0645\u0648\u0632\u0627\u0645\u0628\u06cc\u06a9" },
             { "Phli", "\u067e\u0647\u0644\u0648\u06cc \u06a9\u062a\u06cc\u0628\u0647\u200c\u0627\u06cc" },
             { "NA", "\u0646\u0627\u0645\u06cc\u0628\u06cc\u0627" },
-            { "202", "\u0627\u0641\u0631\u06cc\u0642\u0627\u06cc \u0633\u06cc\u0627\u0647" },
+            { "202", "\u0627\u0641\u0631\u06cc\u0642\u0627\u06cc \u062c\u0646\u0648\u0628 \u0635\u062d\u0631\u0627" },
             { "type.ca.hebrew", "\u062a\u0642\u0648\u06cc\u0645 \u0639\u0628\u0631\u06cc" },
             { "type.co.dictionary", "\u062a\u0631\u062a\u06cc\u0628 \u0641\u0631\u0647\u0646\u06af \u0644\u063a\u062a" },
             { "NC", "\u06a9\u0627\u0644\u062f\u0648\u0646\u06cc\u0627\u06cc \u062c\u062f\u06cc\u062f" },
@@ -436,6 +437,7 @@ public class LocaleNames_fa extends OpenListResourceBundle {
             { "rof", "\u0631\u0648\u0645\u0628\u0648\u06cc\u06cc" },
             { "tsi", "\u062a\u0633\u06cc\u0645\u200c\u0634\u06cc\u0627\u0646\u06cc" },
             { "NZ", "\u0646\u06cc\u0648\u0632\u06cc\u0644\u0646\u062f" },
+            { "%%COLB1945", "\u06a9\u0646\u0648\u0627\u0646\u0633\u06cc\u0648\u0646 \u0631\u0633\u0645\u200c\u0627\u0644\u062e\u0637 \u067e\u0631\u062a\u063a\u0627\u0644 \u0648 \u0628\u0631\u0632\u06cc\u0644 \u062f\u0631 \u06f1\u06f9\u06f4\u06f5" },
             { "rom", "\u0631\u0648\u0645\u0627\u0646\u0648\u06cc\u06cc" },
             { "Mero", "\u0645\u0631\u0648\u06cc\u06cc\u062a\u06cc" },
             { "crh", "\u062a\u0631\u06a9\u06cc \u06a9\u0631\u06cc\u0645\u0647" },
@@ -503,11 +505,11 @@ public class LocaleNames_fa extends OpenListResourceBundle {
             { "015", "\u0634\u0645\u0627\u0644 \u0627\u0641\u0631\u06cc\u0642\u0627" },
             { "SG", "\u0633\u0646\u06af\u0627\u067e\u0648\u0631" },
             { "SH", "\u0633\u0646\u062a \u0647\u0644\u0646" },
-            { "type.lb.strict", "\u0634\u06cc\u0648\u0647\u0654 \u0642\u0648\u06cc \u0627\u0639\u0645\u0627\u0644 \u0633\u0631\u062e\u0637" },
+            { "type.lb.strict", "\u0634\u06cc\u0648\u0647\u0654 \u0633\u0637\u0631\u0634\u06a9\u0646\u06cc \u0633\u062e\u062a\u200c\u06af\u06cc\u0631\u0627\u0646\u0647" },
             { "017", "\u0645\u0631\u06a9\u0632 \u0627\u0641\u0631\u06cc\u0642\u0627" },
             { "SI", "\u0627\u0633\u0644\u0648\u0648\u0646\u06cc" },
             { "018", "\u062c\u0646\u0648\u0628 \u0627\u0641\u0631\u06cc\u0642\u0627" },
-            { "SJ", "\u0627\u0633\u0648\u0627\u0644\u0628\u0627\u0631\u062f \u0648 \u062c\u0627\u0646\u200c\u0645\u0627\u06cc\u0646" },
+            { "SJ", "\u0633\u0648\u0627\u0644\u0628\u0627\u0631\u062f \u0648 \u06cc\u0627\u0646 \u0645\u0627\u06cc\u0646" },
             { "SK", metaValue_SK },
             { "019", "\u0627\u0645\u0631\u06cc\u06a9\u0627" },
             { "SL", "\u0633\u06cc\u0631\u0627\u0644\u0626\u0648\u0646" },
@@ -580,7 +582,7 @@ public class LocaleNames_fa extends OpenListResourceBundle {
             { "UZ", "\u0627\u0632\u0628\u06a9\u0633\u062a\u0627\u0646" },
             { "tzm", "\u0622\u0645\u0627\u0632\u06cc\u063a\u06cc \u0627\u0637\u0644\u0633 \u0645\u0631\u06a9\u0632\u06cc" },
             { "type.co.stroke", "\u062a\u0631\u062a\u06cc\u0628 \u062d\u0631\u06a9\u062a\u06cc" },
-            { "nnh", "\u0627\u0646\u06af\u06cc\u0645\u0628\u0648\u0646\u06cc" },
+            { "nnh", "\u0646\u06cc\u0627\u0645\u0628\u0648\u0646" },
             { "VA", "\u0648\u0627\u062a\u06cc\u06a9\u0627\u0646" },
             { "pro", "\u067e\u0631\u0648\u0648\u0627\u0646\u0633\u06cc \u0628\u0627\u0633\u062a\u0627\u0646" },
             { "VC", "\u0633\u0646\u062a \u0648\u06cc\u0646\u0633\u0646\u062a \u0648 \u06af\u0631\u0646\u0627\u062f\u06cc\u0646" },
@@ -607,9 +609,12 @@ public class LocaleNames_fa extends OpenListResourceBundle {
             { "wal", "\u0648\u0627\u0644\u0627\u0645\u0648" },
             { "was", "\u0648\u0627\u0634\u0648\u06cc\u06cc" },
             { "war", "\u0648\u0627\u0631\u0627\u06cc\u06cc" },
+            { "XB", "\u0645\u062c\u0627\u0632\u06cc - \u062f\u0648\u062c\u0647\u062a\u0647" },
             { "awa", "\u0627\u0648\u062f\u0647\u06cc" },
             { "061", "\u067e\u0644\u06cc\u200c\u0646\u0632\u06cc" },
+            { "%%KSCOR", "\u0631\u0633\u0645\u200c\u0627\u0644\u062e\u0637 \u0627\u0633\u062a\u0627\u0646\u062f\u0627\u0631\u062f" },
             { "XK", "\u06a9\u0648\u0632\u0648\u0648" },
+            { "type.nu.brah", "\u0627\u0631\u0642\u0627\u0645 \u0628\u0631\u0647\u0645\u0627\u06cc\u06cc" },
             { "Gujr", metaValue_gu },
             { "Zxxx", "\u0646\u0627\u0646\u0648\u0634\u062a\u0647" },
             { "wbp", "\u0648\u0627\u0631\u0644\u067e\u06cc\u0631\u06cc" },
@@ -623,9 +628,10 @@ public class LocaleNames_fa extends OpenListResourceBundle {
             { "fat", "\u0641\u0627\u0646\u062a\u06cc\u0627\u06cc\u06cc" },
             { "YT", "\u0645\u0627\u06cc\u0648\u062a" },
             { "ZA", "\u0627\u0641\u0631\u06cc\u0642\u0627\u06cc \u062c\u0646\u0648\u0628\u06cc" },
-            { "type.lb.loose", "\u0634\u06cc\u0648\u0647\u0654 \u0636\u0639\u06cc\u0641 \u0627\u0639\u0645\u0627\u0644 \u0633\u0631\u062e\u0637" },
+            { "type.lb.loose", "\u0634\u06cc\u0648\u0647\u0654 \u0633\u0637\u0631\u0634\u06a9\u0646\u06cc \u0633\u0647\u0644\u200c\u06af\u06cc\u0631\u0627\u0646\u0647" },
             { "Deva", "\u062f\u0648\u0646\u0627\u06af\u0631\u06cc" },
             { "type.nu.geor", "\u0627\u0639\u062f\u0627\u062f \u06af\u0631\u062c\u06cc" },
+            { "type.co.zhuyin", "\u062a\u0631\u062a\u06cc\u0628 \u0698\u0648\u06cc\u06cc\u0646" },
             { "Hira", "\u0647\u06cc\u0631\u0627\u06af\u0627\u0646\u0627" },
             { "ZM", "\u0632\u0627\u0645\u0628\u06cc\u0627" },
             { "ZW", "\u0632\u06cc\u0645\u0628\u0627\u0628\u0648\u0647" },
@@ -765,7 +771,7 @@ public class LocaleNames_fa extends OpenListResourceBundle {
             { "dje", "\u0632\u0631\u0645\u0627" },
             { "type.nu.grek", "\u0627\u0639\u062f\u0627\u062f \u06cc\u0648\u0646\u0627\u0646\u06cc" },
             { "ee", "\u0627\u0648\u0647\u200c\u0627\u06cc" },
-            { "type.lb.normal", "\u0634\u06cc\u0648\u0647\u0654 \u0639\u0627\u062f\u06cc \u0627\u0639\u0645\u0627\u0644 \u0633\u0631\u062e\u0637" },
+            { "type.lb.normal", "\u0634\u06cc\u0648\u0647\u0654 \u0633\u0637\u0631\u0634\u06a9\u0646\u06cc \u0639\u0627\u062f\u06cc" },
             { "ro_MD", "\u0645\u0648\u0644\u062f\u0627\u0648\u06cc\u0627\u06cc\u06cc" },
             { "el", metaValue_el },
             { "en", "\u0627\u0646\u06af\u0644\u06cc\u0633\u06cc" },
@@ -773,7 +779,7 @@ public class LocaleNames_fa extends OpenListResourceBundle {
             { "type.co.big5han", "\u062a\u0631\u062a\u06cc\u0628 \u0686\u06cc\u0646\u06cc \u0633\u0646\u062a\u06cc - Big5" },
             { "es", "\u0627\u0633\u067e\u0627\u0646\u06cc\u0627\u06cc\u06cc" },
             { "et", "\u0627\u0633\u062a\u0648\u0646\u06cc\u0627\u06cc\u06cc" },
-            { "Hanb", "\u0647\u0627\u0646\u0628\u06cc" },
+            { "Hanb", "\u0647\u0627\u0646 \u0628\u0627 \u0628\u0648\u0645\u0648\u067e\u0648\u0641\u0648" },
             { "eu", "\u0628\u0627\u0633\u06a9\u06cc" },
             { "Buhd", "\u0628\u0648\u0647\u06cc\u062f" },
             { "Hang", "\u0647\u0627\u0646\u06af\u0648\u0644" },
@@ -1042,6 +1048,7 @@ public class LocaleNames_fa extends OpenListResourceBundle {
             { "ty", "\u062a\u0627\u0647\u06cc\u062a\u06cc\u0627\u06cc\u06cc" },
             { "150", "\u0627\u0631\u0648\u067e\u0627" },
             { "151", "\u0634\u0631\u0642 \u0627\u0631\u0648\u067e\u0627" },
+            { "type.nu.mathsanb", "\u0627\u0631\u0642\u0627\u0645 \u0631\u06cc\u0627\u0636\u06cc \u0633\u06cc\u0627\u0647 \u0628\u06cc\u200c\u0633\u0631\u06cc\u0641" },
             { "154", "\u0634\u0645\u0627\u0644 \u0627\u0631\u0648\u067e\u0627" },
             { "dzg", "\u062f\u0627\u0632\u0627\u06af\u0627\u06cc\u06cc" },
             { "155", "\u063a\u0631\u0628 \u0627\u0631\u0648\u067e\u0627" },
@@ -1068,6 +1075,7 @@ public class LocaleNames_fa extends OpenListResourceBundle {
             { "vo", "\u0648\u0644\u0627\u067e\u0648\u06a9" },
             { "khw", "\u06a9\u0647\u0648\u0627\u0631" },
             { "syc", "\u0633\u0631\u06cc\u0627\u0646\u06cc \u06a9\u0644\u0627\u0633\u06cc\u06a9" },
+            { "type.nu.mathsans", "\u0627\u0631\u0642\u0627\u0645 \u0631\u06cc\u0627\u0636\u06cc \u0628\u06cc\u200c\u0633\u0631\u06cc\u0641" },
             { "quc", "\u06a9\u06cc\u0686\u0647\u200c" },
             { "gaa", "\u06af\u0627\u06cc\u06cc" },
             { "wa", "\u0648\u0627\u0644\u0648\u0646\u06cc" },
@@ -1118,7 +1126,7 @@ public class LocaleNames_fa extends OpenListResourceBundle {
             { "zh", "\u0686\u06cc\u0646\u06cc" },
             { "Bopo", "\u0628\u0648\u067e\u0648\u0645\u0648\u0641\u0648" },
             { "Perm", "\u067e\u0631\u0645\u06cc \u0628\u0627\u0633\u062a\u0627\u0646" },
-            { "key.lb", "\u0634\u06cc\u0648\u0647\u0654 \u0627\u0639\u0645\u0627\u0644 \u0633\u0631\u062e\u0637" },
+            { "key.lb", "\u0634\u06cc\u0648\u0647\u0654 \u0633\u0637\u0631\u0634\u06a9\u0646\u06cc" },
             { "zu", "\u0632\u0648\u0644\u0648\u06cc\u06cc" },
             { "type.co.phonebook", "\u062a\u0631\u062a\u06cc\u0628 \u062f\u0641\u062a\u0631 \u062a\u0644\u0641\u0646" },
             { "Geor", metaValue_ka },
@@ -1161,6 +1169,7 @@ public class LocaleNames_fa extends OpenListResourceBundle {
             { "inh", "\u0627\u06cc\u0646\u06af\u0648\u0634\u06cc" },
             { "fa_AF", "\u062f\u0631\u06cc" },
             { "krl", "\u06a9\u0627\u0631\u06cc\u0644\u06cc\u0627\u0646\u06cc" },
+            { "%%OXENDICT", "\u0627\u0645\u0644\u0627\u06cc \u0641\u0631\u0647\u0646\u06af \u0627\u0646\u06af\u0644\u06cc\u0633\u06cc \u0622\u06a9\u0633\u0641\u0648\u0631\u062f" },
             { "efi", "\u0627\u0641\u06cc\u06a9\u06cc" },
             { "key.nu", "\u0627\u0639\u062f\u0627\u062f" },
             { "kru", "\u06a9\u0648\u0631\u0648\u062e\u06cc" },
