@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -72,7 +72,7 @@ public class LocaleNames_ga extends OpenListResourceBundle {
     protected final Object[][] getContents() {
         final Object[][] data = new Object[][] {
             { "001", "an Domhan" },
-            { "002", "An Afraic" },
+            { "002", "an Afraic" },
             { "003", "Meirice\u00e1 Thuaidh" },
             { "005", "Meirice\u00e1 Theas" },
             { "009", "an Aig\u00e9ine" },
@@ -80,7 +80,7 @@ public class LocaleNames_ga extends OpenListResourceBundle {
             { "013", "Meirice\u00e1 L\u00e1ir" },
             { "014", "Oirthear na hAfraice" },
             { "015", "Tuaisceart na hAfraice" },
-            { "017", "An Afraic L\u00e1ir" },
+            { "017", "an Afraic L\u00e1ir" },
             { "018", "Deisceart na hAfraice" },
             { "019", "Cr\u00edocha Mheirice\u00e1" },
             { "021", "Tuaisceart Mheirice\u00e1" },
@@ -159,7 +159,7 @@ public class LocaleNames_ga extends OpenListResourceBundle {
             { "CW", "Cura\u00e7ao" },
             { "CX", "Oile\u00e1n na Nollag" },
             { "CY", "an Chipir" },
-            { "CZ", "An tSeicia" },
+            { "CZ", "an tSeicia" },
             { "DE", "an Ghearm\u00e1in" },
             { "DG", "Diego Garcia" },
             { "DJ", "Djibouti" },
@@ -252,7 +252,7 @@ public class LocaleNames_ga extends OpenListResourceBundle {
             { "MF", "Saint-Martin" },
             { "MG", "Madagascar" },
             { "MH", "Oile\u00e1in Marshall" },
-            { "MK", "an Mhacad\u00f3in" },
+            { "MK", "an Mhacad\u00f3in Thuaidh" },
             { "ML", "Mail\u00ed" },
             { "MM", "Maenmar (Burma)" },
             { "MN", "an Mhong\u00f3il" },
@@ -322,7 +322,7 @@ public class LocaleNames_ga extends OpenListResourceBundle {
             { "SV", "an tSalvad\u00f3ir" },
             { "SX", "Sint Maarten" },
             { "SY", "an tSiria" },
-            { "SZ", "an tSuasalainn" },
+            { "SZ", "eSuait\u00edn\u00ed" },
             { "TA", "Tristan da Cunha" },
             { "TC", "Oile\u00e1in na dTurcach agus Caicos" },
             { "TD", "Sead" },
@@ -343,7 +343,7 @@ public class LocaleNames_ga extends OpenListResourceBundle {
             { "UA", "an \u00dacr\u00e1in" },
             { "UG", "Uganda" },
             { "UM", "Oile\u00e1in Imeallacha S.A.M." },
-            { "UN", "na N\u00e1isi\u00fain Aontaiteh" },
+            { "UN", "na N\u00e1isi\u00fain Aontaithe" },
             { "US", "St\u00e1it Aontaithe Mheirice\u00e1" },
             { "UY", "Uragua" },
             { "UZ", "an \u00daisb\u00e9iceast\u00e1in" },
@@ -356,6 +356,8 @@ public class LocaleNames_ga extends OpenListResourceBundle {
             { "VU", "Vanuat\u00fa" },
             { "WF", "Vail\u00eds agus Fut\u00fana" },
             { "WS", "Sam\u00f3" },
+            { "XA", "Br\u00e9agdhiaicritic\u00ed" },
+            { "XB", "Br\u00e9ag-Bidi" },
             { "XK", "an Chosaiv" },
             { "YE", "\u00c9imin" },
             { "YT", "Mayotte" },
@@ -634,23 +636,23 @@ public class LocaleNames_ga extends OpenListResourceBundle {
             { "ilo", "ilo" },
             { "inh", "Iong\u00fais" },
             { "jbo", "Lojban" },
-            { "jgo", "jgo" },
-            { "jmc", "jmc" },
+            { "jgo", "Ngomba" },
+            { "jmc", "Machame" },
             { "jut", "I\u00fatlainnis" },
             { "kaa", "Cara-Chalp\u00e1is" },
-            { "kab", "kab" },
+            { "kab", "Caib\u00edlis" },
             { "kac", "kac" },
             { "kaj", "kaj" },
-            { "kam", "kam" },
+            { "kam", "Cambais" },
             { "kbd", "kbd" },
             { "kcg", "kcg" },
-            { "kde", "kde" },
+            { "kde", "Makonde" },
             { "kea", "Kabuverdianu" },
             { "kfo", "kfo" },
             { "kha", "kha" },
-            { "khq", "khq" },
-            { "kkj", "kkj" },
-            { "kln", "kln" },
+            { "khq", "Koyra Chiini" },
+            { "kkj", "Kako" },
+            { "kln", "Kalenjin" },
             { "kmb", "kmb" },
             { "kok", "Conc\u00e1inis" },
             { "kpe", "kpe" },
@@ -662,60 +664,60 @@ public class LocaleNames_ga extends OpenListResourceBundle {
             { "ksh", "ksh" },
             { "kum", "kum" },
             { "lad", "Laid\u00ednis" },
-            { "lag", "lag" },
+            { "lag", "Langi" },
             { "lah", "Puinse\u00e1ibis Iartharach" },
             { "lez", "lez" },
             { "lij", "Liog\u00fairis" },
             { "liv", "Liov\u00f3inis" },
-            { "lkt", "lkt" },
+            { "lkt", "Lakota" },
             { "lmo", "Lombairdis" },
             { "loz", "loz" },
-            { "lrc", "lrc" },
+            { "lrc", "Luri Thuaidh" },
             { "lua", "lua" },
             { "lun", "lun" },
-            { "luo", "luo" },
+            { "luo", "L\u00fa\u00f3is" },
             { "lus", "lus" },
-            { "luy", "luy" },
+            { "luy", "Luyia" },
             { "mad", "mad" },
             { "mag", "mag" },
             { "mai", "mai" },
             { "mak", "mak" },
-            { "mas", "mas" },
+            { "mas", "M\u00e1sais" },
             { "mdf", "mdf" },
             { "men", "Meindis" },
-            { "mer", "mer" },
-            { "mfe", "mfe" },
+            { "mer", "Meru" },
+            { "mfe", "Morisyen" },
             { "mga", "Me\u00e1n-Ghaeilge" },
-            { "mgh", "mgh" },
-            { "mgo", "mgo" },
+            { "mgh", "Makhuwa-Meetto" },
+            { "mgo", "Meta\u02bc" },
             { "mic", "mic" },
             { "min", "min" },
             { "mni", "Manap\u00fairis" },
             { "moh", "M\u00f3h\u00e1icis" },
             { "mos", "mos" },
             { "mrj", "Mairis Iartharach" },
-            { "mua", "mua" },
+            { "mua", "Mundang" },
             { "mul", "Ilteangacha" },
             { "mus", "mus" },
             { "mwl", "Mioraind\u00e9is" },
             { "mwr", "Marmhairis" },
             { "myv", "myv" },
-            { "mzn", "mzn" },
+            { "mzn", "Mazanderani" },
             { "nan", "S\u00ednis Min Nan" },
             { "nap", "Nap\u00f3ilis" },
-            { "naq", "naq" },
+            { "naq", "Nama" },
             { "nds", "Gearm\u00e1inis \u00cdochtarach" },
             { "new", "new" },
             { "nia", "nia" },
             { "niu", "N\u00edobhais" },
-            { "nmg", "nmg" },
-            { "nnh", "nnh" },
+            { "nmg", "Kwasio" },
+            { "nnh", "Ngiemboon" },
             { "nog", "nog" },
             { "non", "Sean-Lochlainnis" },
             { "nqo", "nqo" },
             { "nso", "S\u00fat\u00fais an Tuaiscirt" },
-            { "nus", "nus" },
-            { "nyn", "nyn" },
+            { "nus", "Nuer" },
+            { "nyn", "Nianc\u00f3ilis" },
             { "pag", "pag" },
             { "pam", "pam" },
             { "pap", "pap" },
@@ -740,7 +742,7 @@ public class LocaleNames_ga extends OpenListResourceBundle {
             { "scn", "Sicilis" },
             { "sco", "Albainis" },
             { "seh", "seh" },
-            { "ses", "ses" },
+            { "ses", "Koyraboro Senni" },
             { "sga", "Sean-Ghaeilge" },
             { "shi", "Tachelhit" },
             { "shn", "shn" },
