@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -95,6 +95,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
         final String metaValue_si = "Sinhala";
         final String metaValue_te = "Telugu";
         final String metaValue_tl = "Tagalog";
+        final String metaValue_ccp = "Chakma";
         final String metaValue_chr = "Cherokee";
         final String metaValue_cop = "Coptais";
         final String metaValue_gez = "Ge\u2019ez";
@@ -121,6 +122,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "Tagb", "Tagbanwa" },
             { "Zsye", "Emoji" },
             { "%%NJIVA", "Dual-chainnt Gniva/Njiva" },
+            { "ccp", metaValue_ccp },
             { "egy", "\u00c8ipheitis \u00c0rsaidh" },
             { "raj", "Rajasthani" },
             { "Phag", "Phags-pa" },
@@ -418,6 +420,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "LK", "Sri Lanca" },
             { "akk", "Acadais" },
             { "cop", metaValue_cop },
+            { "Hmnp", "Nyiakeng Puachue Hmong" },
             { "LR", "Lib\u00e8ir" },
             { "esu", "Yupik Mheadhanach" },
             { "LS", "Leasoto" },
@@ -505,6 +508,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "%%PETR1708", "Litreachadh Pheadair 1708" },
             { "anp", "Angika" },
             { "crs", "Seiseallais" },
+            { "type.nu.hmnp", "\u00c0ireamhan Nyiakeng Puachue" },
             { "Xpeo", metaValue_peo },
             { "type.nu.hmng", "\u00c0ireamhan Pahawh Hmong" },
             { "PA", "Panama" },
@@ -556,6 +560,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "jbo", "Lojban" },
             { "Rjng", "Rejang" },
             { "009", "Roinn a\u2019 Chuain S\u00e8imh" },
+            { "Elym", "Elymaidheach" },
             { "%%SURSILV", "Sursilvan" },
             { "RO", "Rom\u00e0inia" },
             { "RS", "An t-S\u00e8irb" },
@@ -609,7 +614,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "SX", "Sint Maarten" },
             { "SY", "Siridhea" },
             { "yao", "Yao" },
-            { "SZ", "D\u00f9thaich nan Suasaidh" },
+            { "SZ", "eSwatini" },
             { "arw", "Arawak" },
             { "arz", "Arabais \u00c8ipheiteach" },
             { "ary", "Arabais Mhorocach" },
@@ -621,6 +626,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "TC", "Na h-Eileanan Turcach is Caiceo" },
             { "yav", "Yangben" },
             { "TD", "An t-Se\u00e0d" },
+            { "Qaag", "Qaag" },
             { "TF", "Ranntairean a Deas na Frainge" },
             { "ase", "Cainnt-shanais na h-Aimeireaga" },
             { "TG", "Togo" },
@@ -707,7 +713,9 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "type.nu.mtei", "\u00c0ireamhan Meetei Mayek" },
             { "wal", "Wolaytta" },
             { "was", "Washo" },
+            { "XA", "Sr\u00e0can fuadain" },
             { "war", "Waray" },
+            { "XB", "D\u00e0-chomhaireach fuadain" },
             { "awa", "Awadhi" },
             { "061", "Poilin\u00e8is" },
             { "%%KSCOR", "Litreachadh stannardach" },
@@ -946,6 +954,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "sid", "Sidamo" },
             { "fy", "Fr\u00ecoslannais Shiarach" },
             { "ga", "Gaeilge" },
+            { "Wcho", "Wancho" },
             { "gd", "G\u00e0idhlig" },
             { "Gong", "Gunjala Gondi" },
             { "gl", "Gail\u00ecsis" },
@@ -963,7 +972,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "hi", "Hindis" },
             { "hup", "Hupa" },
             { "bik", "Bikol" },
-            { "bin", "Bini" },
+            { "bin", "Edo" },
             { "ho", "Hiri Motu" },
             { "hr", "Cr\u00f2thaisis" },
             { "ht", "Cr\u00ectheol Haidhti" },
@@ -1199,6 +1208,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "%%NEDIS", "Dual-chainnt Natisone" },
             { "sv", "Suainis" },
             { "sw", "Kiswahili" },
+            { "type.nu.wcho", "\u00c0ireamhan Wancho" },
             { "type.nu.hantfin", "\u00c0ireamhan ionmhasail na S\u00ecnise Thradaiseanta" },
             { "ibb", "Ibibio" },
             { "iba", "Iban" },
@@ -1223,9 +1233,9 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "dyo", "Jola-Fonyi" },
             { "type.nu.jpan", "\u00c0ireamhan na Seapanaise" },
             { "tr", "Turcais" },
+            { "Cakm", metaValue_ccp },
             { "ts", "Tsonga" },
             { "swb", "Comorais" },
-            { "Cakm", "Chakma" },
             { "tt", "Tatarais" },
             { "%%XSISTEMO", "XSISTEMO" },
             { "dyu", "Dyula" },
@@ -1297,6 +1307,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "mni", "Manipuri" },
             { "Latn", metaValue_la },
             { "Latg", "Laideann Gh\u00e0idhealach" },
+            { "Nand", "Nandinagari" },
             { "type.nu.hans", "\u00c0ireamhan na S\u00ecnise Shimplichte" },
             { "type.nu.hant", "\u00c0ireamhan na S\u00ecnise Thradaiseanta" },
             { "xh", "Xhosa" },
