@@ -438,7 +438,7 @@ public class LocaleNames_hr extends OpenListResourceBundle {
             { "PK", "Pakistan" },
             { "PL", "Poljska" },
             { "ewo", "ewondo" },
-            { "PM", "Sveti Petar i Mikelon" },
+            { "PM", "Saint-Pierre-et-Miquelon" },
             { "PN", "Otoci Pitcairn" },
             { "PR", "Portoriko" },
             { "PS", "Palestinsko podru\u010dje" },
@@ -515,7 +515,7 @@ public class LocaleNames_hr extends OpenListResourceBundle {
             { "SX", "Sint Maarten" },
             { "SY", "Sirija" },
             { "yao", "yao" },
-            { "SZ", "Svazi" },
+            { "SZ", "Esvatini" },
             { "arw", "arava\u010dki" },
             { "yap", "japski" },
             { "TA", "Tristan da Cunha" },
