@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -87,13 +87,13 @@ public class LocaleNames_it extends OpenListResourceBundle {
         final String metaValue_ml = "malayalam";
         final String metaValue_mn = "mongolo";
         final String metaValue_my = "birmano";
-        final String metaValue_or = "oriya";
         final String metaValue_si = "singalese";
         final String metaValue_su = "sundanese";
         final String metaValue_ta = "tamil";
         final String metaValue_te = "telugu";
         final String metaValue_tl = "tagalog";
         final String metaValue_ban = "balinese";
+        final String metaValue_ccp = "chakma";
         final String metaValue_chr = "cherokee";
         final String metaValue_cop = "copto";
         final String metaValue_got = "gotico";
@@ -119,6 +119,7 @@ public class LocaleNames_it extends OpenListResourceBundle {
             { "Zsye", "emoji" },
             { "%%NJIVA", "dialetto Gniva/Njiva" },
             { "xmf", "mengrelio" },
+            { "ccp", metaValue_ccp },
             { "egy", "egiziano antico" },
             { "raj", "rajasthani" },
             { "Phag", "phags-pa" },
@@ -345,7 +346,6 @@ public class LocaleNames_it extends OpenListResourceBundle {
             { "Nbat", "nabateo" },
             { "IM", "Isola di Man" },
             { "IN", "India" },
-            { "type.co.eor", "eor" },
             { "IO", "Territorio britannico dell\u2019Oceano Indiano" },
             { "IQ", "Iraq" },
             { "IR", "Iran" },
@@ -433,7 +433,7 @@ public class LocaleNames_it extends OpenListResourceBundle {
             { "ale", "aleuto" },
             { "Thai", "thailandese" },
             { "type.nu.vaii", "Cifre Vai" },
-            { "MK", "Repubblica di Macedonia" },
+            { "MK", "Macedonia del Nord" },
             { "ML", "Mali" },
             { "MM", "Myanmar (Birmania)" },
             { "MN", "Mongolia" },
@@ -585,7 +585,7 @@ public class LocaleNames_it extends OpenListResourceBundle {
             { "ST", "S\u00e3o Tom\u00e9 e Pr\u00edncipe" },
             { "arq", "arabo algerino" },
             { "SV", "El Salvador" },
-            { "ars", "arabo, najd" },
+            { "ars", "arabo najd" },
             { "SX", "Sint Maarten" },
             { "SY", "Siria" },
             { "yao", "yao (bantu)" },
@@ -686,7 +686,9 @@ public class LocaleNames_it extends OpenListResourceBundle {
             { "type.nu.mtei", "Cifre Meetei Mayek" },
             { "wal", "walamo" },
             { "was", "washo" },
+            { "XA", "Pseudo-accenti" },
             { "war", "waray" },
+            { "XB", "Pseudo-bidi" },
             { "awa", "awadhi" },
             { "061", "Polinesia" },
             { "%%KSCOR", "ortografia standard" },
@@ -842,7 +844,7 @@ public class LocaleNames_it extends OpenListResourceBundle {
             { "ch", "chamorro" },
             { "%%REVISED", "ortografia revisionata" },
             { "co", "corso" },
-            { "Orya", metaValue_or },
+            { "Orya", "oriya" },
             { "cr", "cree" },
             { "cs", "ceco" },
             { "cu", "slavo della Chiesa" },
@@ -998,7 +1000,7 @@ public class LocaleNames_it extends OpenListResourceBundle {
             { "ku", "curdo" },
             { "kv", "komi" },
             { "kw", "cornico" },
-            { "ky", "chirghiso" },
+            { "ky", "kirghiso" },
             { "snk", "soninke" },
             { "la", metaValue_la },
             { "lb", "lussemburghese" },
@@ -1061,7 +1063,7 @@ public class LocaleNames_it extends OpenListResourceBundle {
             { "om", "oromo" },
             { "kaw", "kawi" },
             { "dtp", "dusun centrale" },
-            { "or", metaValue_or },
+            { "or", "odia" },
             { "os", "ossetico" },
             { "%%ALALC97", "romanizzazione di ALA-LC, versione 1997" },
             { "bpy", "bishnupriya" },
@@ -1174,9 +1176,9 @@ public class LocaleNames_it extends OpenListResourceBundle {
             { "dyo", "jola-fony" },
             { "type.nu.jpan", "Numeri giapponesi" },
             { "tr", "turco" },
+            { "Cakm", metaValue_ccp },
             { "ts", "tsonga" },
             { "swb", "comoriano" },
-            { "Cakm", "chakma" },
             { "tt", "tataro" },
             { "dyu", "diula" },
             { "tw", "ci" },
