@@ -73,7 +73,6 @@ public class LocaleNames_iw extends OpenListResourceBundle {
         final String metaValue_TK = "\u05d8\u05d5\u05e7\u05dc\u05d0\u05d5";
         final String metaValue_TV = "\u05d8\u05d5\u05d1\u05d0\u05dc\u05d5";
         final String metaValue_ml = "\u05de\u05dc\u05d9\u05d0\u05dc\u05d0\u05dd";
-        final String metaValue_or = "\u05d0\u05d5\u05e8\u05d9\u05d9\u05d4";
         final String metaValue_si = "\u05e1\u05d9\u05e0\u05d4\u05dc\u05d4";
         final String metaValue_te = "\u05d8\u05dc\u05d5\u05d2\u05d5";
         final Object[][] data = new Object[][] {
@@ -252,7 +251,7 @@ public class LocaleNames_iw extends OpenListResourceBundle {
             { "GU", "\u05d2\u05d5\u05d0\u05dd" },
             { "GW", "\u05d2\u05d9\u05e0\u05d0\u05d4-\u05d1\u05d9\u05e1\u05d0\u05d5" },
             { "tli", "\u05d8\u05dc\u05d9\u05e0\u05d2\u05d9\u05d8" },
-            { "tlh", "\u05e7\u05dc\u05d9\u05e0\u05d2\u05d5\u05df" },
+            { "tlh", "\u05e7\u05dc\u05d9\u05e0\u05d2\u05d5\u05e0\u05d9\u05ea" },
             { "GY", "\u05d2\u05d9\u05d0\u05e0\u05d4" },
             { "ckb", "\u05db\u05d5\u05e8\u05d3\u05d9\u05ea \u05e1\u05d5\u05e8\u05d0\u05e0\u05d9\u05ea" },
             { "zxx", "\u05dc\u05dc\u05d0 \u05ea\u05d5\u05db\u05df \u05dc\u05e9\u05d5\u05e0\u05d9" },
@@ -261,7 +260,7 @@ public class LocaleNames_iw extends OpenListResourceBundle {
             { "HN", "\u05d4\u05d5\u05e0\u05d3\u05d5\u05e8\u05e1" },
             { "HR", "\u05e7\u05e8\u05d5\u05d0\u05d8\u05d9\u05d4" },
             { "agq", "\u05d0\u05e2\u05f3\u05dd" },
-            { "gsw", "\u05d2\u05e8\u05de\u05e0\u05d9\u05ea \u05e9\u05d5\u05d5\u05d9\u05e6\u05e8\u05d9\u05ea" },
+            { "gsw", "\u05d2\u05e8\u05de\u05e0\u05d9\u05ea (\u05d1\u05e9\u05d5\u05d5\u05d9\u05e5)" },
             { "type.ca.islamic-umalqura", "\u05dc\u05d5\u05d7 \u05d4\u05e9\u05e0\u05d4 \u05d4\u05de\u05d5\u05e1\u05dc\u05de\u05d9 \u05d0\u05d5\u05dd \u05d0\u05dc-\u05e7\u05d5\u05e8\u05d0" },
             { "HT", "\u05d4\u05d0\u05d9\u05d8\u05d9" },
             { "HU", "\u05d4\u05d5\u05e0\u05d2\u05e8\u05d9\u05d4" },
@@ -553,7 +552,9 @@ public class LocaleNames_iw extends OpenListResourceBundle {
             { "WS", "\u05e1\u05de\u05d5\u05d0\u05d4" },
             { "wal", "\u05d5\u05d5\u05dc\u05d9\u05d0\u05d8\u05d4" },
             { "was", "\u05d5\u05d5\u05d0\u05e9\u05d5" },
+            { "XA", "\u05de\u05d1\u05d8\u05d0\u05d9\u05dd \u05d7\u05dc\u05e7\u05d9\u05d9\u05dd" },
             { "war", "\u05d5\u05d5\u05e8\u05d0\u05d9" },
+            { "XB", "\u05d3\u05d5-\u05db\u05d9\u05d5\u05d5\u05e0\u05d9 \u05d7\u05dc\u05e7\u05d9" },
             { "awa", "\u05d0\u05d5\u05d5\u05d0\u05d3\u05d9\u05ea" },
             { "061", "\u05e4\u05d5\u05dc\u05d9\u05e0\u05d6\u05d9\u05d4" },
             { "XK", "\u05e7\u05d5\u05e1\u05d5\u05d1\u05d5" },
@@ -675,7 +676,7 @@ public class LocaleNames_iw extends OpenListResourceBundle {
             { "ce", "\u05e6\u05f3\u05e6\u05f3\u05e0\u05d9\u05ea" },
             { "ch", "\u05e6\u05f3\u05de\u05d5\u05e8\u05d5" },
             { "co", "\u05e7\u05d5\u05e8\u05e1\u05d9\u05e7\u05e0\u05d9\u05ea" },
-            { "Orya", metaValue_or },
+            { "Orya", "\u05d0\u05d5\u05d3\u05d9\u05d9\u05d4" },
             { "cr", "\u05e7\u05e8\u05d9" },
             { "cs", "\u05e6\u05f3\u05db\u05d9\u05ea" },
             { "cu", "\u05e1\u05dc\u05d0\u05d1\u05d9\u05ea \u05db\u05e0\u05e1\u05d9\u05d9\u05ea\u05d9\u05ea \u05e2\u05ea\u05d9\u05e7\u05d4" },
@@ -706,11 +707,11 @@ public class LocaleNames_iw extends OpenListResourceBundle {
             { "type.co.big5han", "\u05de\u05d9\u05d5\u05df \u05e1\u05d9\u05e0\u05d9\u05ea \u05de\u05e1\u05d5\u05e8\u05ea\u05d9\u05ea" },
             { "es", "\u05e1\u05e4\u05e8\u05d3\u05d9\u05ea" },
             { "et", "\u05d0\u05e1\u05d8\u05d5\u05e0\u05d9\u05ea" },
-            { "Hanb", "\u05d4\u05d0\u05e0\u05d1" },
+            { "Hanb", "\u05d4\u05d0\u05df \u05e2\u05dd \u05d1\u05d5\u05e4\u05d5\u05de\u05d5\u05e4\u05d5" },
             { "eu", "\u05d1\u05e1\u05e7\u05d9\u05ea" },
             { "Hang", "\u05d4\u05d0\u05e0\u05d2\u05d5\u05dc" },
             { "shi", "\u05e9\u05d9\u05dc\u05d4" },
-            { "hsb", "\u05e1\u05d5\u05e8\u05d1\u05d9\u05ea \u05d2\u05d1\u05d5\u05d4\u05d4" },
+            { "hsb", "\u05e1\u05d5\u05e8\u05d1\u05d9\u05ea \u05e2\u05d9\u05dc\u05d9\u05ea" },
             { "Hani", "\u05d4\u05d0\u05df" },
             { "shn", "\u05e9\u05d0\u05df" },
             { "fa", "\u05e4\u05e8\u05e1\u05d9\u05ea" },
@@ -859,7 +860,7 @@ public class LocaleNames_iw extends OpenListResourceBundle {
             { "type.nu.armn", "\u05e1\u05e4\u05e8\u05d5\u05ea \u05d0\u05e8\u05de\u05e0\u05d9\u05d5\u05ea" },
             { "om", "\u05d0\u05d5\u05e8\u05d5\u05de\u05d5" },
             { "kaw", "\u05e7\u05d0\u05d5\u05d5\u05d9" },
-            { "or", metaValue_or },
+            { "or", "\u05d0\u05d5\u05e8\u05d9\u05d9\u05d4" },
             { "os", "\u05d0\u05d5\u05e1\u05d8\u05d9\u05ea" },
             { "kbd", "\u05e7\u05d1\u05e8\u05d3\u05d9\u05ea" },
             { "mfe", "\u05e7\u05e8\u05d9\u05d0\u05d5\u05dc\u05d9\u05ea \u05de\u05d0\u05d5\u05e8\u05d9\u05e6\u05d9\u05d0\u05e0\u05d9\u05ea" },
@@ -881,7 +882,7 @@ public class LocaleNames_iw extends OpenListResourceBundle {
             { "key.cf", "\u05ea\u05d1\u05e0\u05d9\u05ea \u05de\u05d8\u05d1\u05e2" },
             { "bra", "\u05d1\u05e8\u05d0\u05d2\u05f3" },
             { "key.ca", "\u05dc\u05d5\u05d7 \u05e9\u05e0\u05d4" },
-            { "Laoo", "\u05dc\u05d0\u05d9\u05ea" },
+            { "Laoo", "\u05dc\u05d0\u05d9" },
             { "mgo", "\u05de\u05d8\u05d0" },
             { "type.hc.h23", "\u05de\u05e2\u05e8\u05db\u05ea \u05e9\u05dc 24 \u05e9\u05e2\u05d5\u05ea (0\u200e\u201323)" },
             { "type.hc.h24", "\u05de\u05e2\u05e8\u05db\u05ea \u05e9\u05dc 24 \u05e9\u05e2\u05d5\u05ea (1\u200e\u201324)" },
@@ -979,8 +980,8 @@ public class LocaleNames_iw extends OpenListResourceBundle {
             { "kha", "\u05e7\u05d4\u05d0\u05e1\u05d9" },
             { "nds_NL", "\u05e1\u05e7\u05e1\u05d5\u05e0\u05d9\u05ea \u05ea\u05d7\u05ea\u05d9\u05ea" },
             { "ve", "\u05d5\u05d5\u05e0\u05d3\u05d4" },
-            { "type.ca.roc", "\u05dc\u05d5\u05d7 \u05d4\u05e9\u05e0\u05d4 \u05d4\u05d8\u05d0\u05d9\u05d5\u05d5\u05e0\u05d9" },
-            { "vi", "\u05d5\u05d9\u05d0\u05d8\u05e0\u05de\u05d9\u05ea" },
+            { "type.ca.roc", "\u05dc\u05d5\u05d7 \u05d4\u05e9\u05e0\u05d4 \u05d4\u05d8\u05d9\u05d9\u05d5\u05d5\u05d0\u05e0\u05d9" },
+            { "vi", "\u05d5\u05d9\u05d9\u05d8\u05e0\u05d0\u05de\u05d9\u05ea" },
             { "kho", "\u05e7\u05d5\u05d8\u05d0\u05e0\u05d6\u05d9\u05ea" },
             { "khq", "\u05e7\u05d5\u05d9\u05e8\u05d4 \u05e6\u05f3\u05d9\u05e0\u05d9" },
             { "key.hc", "\u05de\u05d7\u05d6\u05d5\u05e8 \u05d4\u05e9\u05e2\u05d5\u05ea (12 \u05d0\u05d5 24)" },
