@@ -97,6 +97,7 @@ public class LocaleNames_ka extends OpenListResourceBundle {
         final String metaValue_ta = "\u10e2\u10d0\u10db\u10d8\u10da\u10e3\u10e0\u10d8";
         final String metaValue_te = "\u10e2\u10d4\u10da\u10e3\u10d2\u10e3";
         final String metaValue_th = "\u10e2\u10d0\u10d8";
+        final String metaValue_ccp = "\u10e9\u10d0\u10d9\u10db\u10d0";
         final String metaValue_chr = "\u10e9\u10d4\u10e0\u10dd\u10d9\u10d8";
         final String metaValue_cop = "\u10d9\u10dd\u10de\u10e2\u10e3\u10e0\u10d8";
         final String metaValue_got = "\u10d2\u10dd\u10d7\u10e3\u10e0\u10d8";
@@ -120,6 +121,7 @@ public class LocaleNames_ka extends OpenListResourceBundle {
             { "mwr", "\u10db\u10d0\u10e0\u10d5\u10d0\u10e0\u10d8" },
             { "Tagb", "\u10e2\u10d0\u10d2\u10d1\u10d0\u10dc\u10d5\u10d0" },
             { "Zsye", "Emoji" },
+            { "ccp", metaValue_ccp },
             { "egy", "\u10eb\u10d5\u10d4\u10da\u10d4\u10d2\u10d5\u10d8\u10de\u10e2\u10e3\u10e0\u10d8" },
             { "raj", "\u10e0\u10d0\u10ef\u10d0\u10e1\u10d7\u10d0\u10dc\u10d8" },
             { "Phag", "\u10e4\u10d0\u10d2\u10e1\u10de\u10d0" },
@@ -387,7 +389,7 @@ public class LocaleNames_ka extends OpenListResourceBundle {
             { "Thai", metaValue_th },
             { "MH", "\u10db\u10d0\u10e0\u10e8\u10d0\u10da\u10d8\u10e1 \u10d9\u10e3\u10dc\u10eb\u10e3\u10da\u10d4\u10d1\u10d8" },
             { "ale", "\u10d0\u10da\u10d4\u10e3\u10e2\u10e3\u10e0\u10d8" },
-            { "MK", "\u10db\u10d0\u10d9\u10d4\u10d3\u10dd\u10dc\u10d8\u10d0" },
+            { "MK", "\u10e9\u10e0\u10d3\u10d8\u10da\u10dd\u10d4\u10d7 \u10db\u10d0\u10d9\u10d4\u10d3\u10dd\u10dc\u10d8\u10d0" },
             { "ML", "\u10db\u10d0\u10da\u10d8" },
             { "MM", "\u10db\u10d8\u10d0\u10dc\u10db\u10d0\u10e0\u10d8 (\u10d1\u10d8\u10e0\u10db\u10d0)" },
             { "MN", "\u10db\u10dd\u10dc\u10e6\u10dd\u10da\u10d4\u10d7\u10d8" },
@@ -590,7 +592,9 @@ public class LocaleNames_ka extends OpenListResourceBundle {
             { "WS", metaValue_WS },
             { "Bass", "\u10d1\u10d0\u10e1\u10d0 \u10d5\u10d0\u10f0\u10d8" },
             { "wal", "\u10d5\u10d4\u10da\u10d0\u10d8\u10d7\u10d0" },
+            { "XA", "\u10e4\u10e1\u10d4\u10d5\u10d3\u10dd-\u10d0\u10e5\u10ea\u10d4\u10dc\u10e2\u10d4\u10d1\u10d8" },
             { "war", "\u10d5\u10d0\u10e0\u10d0\u10d8" },
+            { "XB", "\u10e4\u10e1\u10d4\u10d5\u10d3\u10dd-\u10dd\u10e0\u10db\u10d8\u10db\u10d0\u10e0\u10d7\u10e3\u10da\u10d4\u10d1\u10d8\u10d0\u10dc\u10d8" },
             { "awa", "\u10d0\u10d5\u10d0\u10d3\u10d8" },
             { "061", "\u10de\u10dd\u10da\u10d8\u10dc\u10d4\u10d6\u10d8\u10d0" },
             { "XK", "\u10d9\u10dd\u10e1\u10dd\u10d5\u10dd" },
@@ -986,9 +990,9 @@ public class LocaleNames_ka extends OpenListResourceBundle {
             { "dyo", "\u10d3\u10d8\u10dd\u10da\u10d0" },
             { "type.nu.jpan", "\u10d8\u10d0\u10de\u10dd\u10dc\u10e3\u10e0\u10d8 \u10e0\u10d8\u10ea\u10ee\u10d5\u10d4\u10d1\u10d8" },
             { "tr", "\u10d7\u10e3\u10e0\u10e5\u10e3\u10da\u10d8" },
+            { "Cakm", metaValue_ccp },
             { "ts", "\u10e2\u10e1\u10dd\u10dc\u10d2\u10d0" },
             { "swb", "\u10d9\u10dd\u10db\u10dd\u10e0\u10e3\u10da\u10d8" },
-            { "Cakm", "\u10e9\u10d0\u10d9\u10db\u10d0" },
             { "tt", "\u10d7\u10d0\u10d7\u10e0\u10e3\u10da\u10d8" },
             { "dyu", "\u10d3\u10d8\u10e3\u10da\u10d0" },
             { "tw", "\u10d7\u10e3\u10d8" },
