@@ -322,7 +322,7 @@ public class LocaleNames_sl extends OpenListResourceBundle {
             { "SV", "Salvador" },
             { "SX", "Sint Maarten" },
             { "SY", "Sirija" },
-            { "SZ", "Svazi" },
+            { "SZ", "Esvatini" },
             { "TA", "Tristan da Cunha" },
             { "TC", "Otoki Turks in Caicos" },
             { "TD", "\u010cad" },
