@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -318,14 +318,6 @@ public class TimeZoneNames_ast extends TimeZoneNamesBundle {
                "Hora de les Islles Falkland",
                "",
             };
-        final String[] Bhutan = new String[] {
-               "Hora de But\u00e1n",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Apia = new String[] {
                "Hora est\u00e1ndar d\u2019Apia",
                "",
@@ -334,6 +326,14 @@ public class TimeZoneNames_ast extends TimeZoneNamesBundle {
                "Hora d\u2019Apia",
                "",
             };
+        final String[] Bhutan = new String[] {
+               "Hora de But\u00e1n",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Nauru = new String[] {
                "Hora de Nauru",
                "",
@@ -574,12 +574,12 @@ public class TimeZoneNames_ast extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Colombia = new String[] {
-               "Hora est\u00e1ndar de Colombia",
+        final String[] Australia_Eastern = new String[] {
+               "Hora est\u00e1ndar d\u2019Australia del este",
                "",
-               "Hora braniega de Colombia",
+               "Hora braniega d\u2019Australia del este",
                "",
-               "Hora de Colombia",
+               "Hora d\u2019Australia del este",
                "",
             };
         final String[] French_Guiana = new String[] {
@@ -590,12 +590,12 @@ public class TimeZoneNames_ast extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Australia_Eastern = new String[] {
-               "Hora est\u00e1ndar d\u2019Australia del este",
+        final String[] Colombia = new String[] {
+               "Hora est\u00e1ndar de Colombia",
                "",
-               "Hora braniega d\u2019Australia del este",
+               "Hora braniega de Colombia",
                "",
-               "Hora d\u2019Australia del este",
+               "Hora de Colombia",
                "",
             };
         final String[] Chile = new String[] {
@@ -710,14 +710,6 @@ public class TimeZoneNames_ast extends TimeZoneNamesBundle {
                "Hora del Paragu\u00e1i",
                "",
             };
-        final String[] Casey = new String[] {
-               "Hora de Casey",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Malaysia = new String[] {
                "Hora de Malasia",
                "",
@@ -1062,12 +1054,12 @@ public class TimeZoneNames_ast extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Mexico_Northwest = new String[] {
-               "Hora est\u00e1ndar del noroeste de M\u00e9xicu",
+        final String[] Volgograd = new String[] {
+               "Hora est\u00e1ndar de Volgogr\u00e1u",
                "",
-               "Hora braniega del noroeste de M\u00e9xicu",
+               "Hora braniega de Volgogr\u00e1u",
                "",
-               "Hora del noroeste de M\u00e9xicu",
+               "Hora de Volgogr\u00e1u",
                "",
             };
         final String[] Easter = new String[] {
@@ -1078,6 +1070,14 @@ public class TimeZoneNames_ast extends TimeZoneNamesBundle {
                "Hora de la Islla de Pascua",
                "",
             };
+        final String[] Mexico_Northwest = new String[] {
+               "Hora est\u00e1ndar del noroeste de M\u00e9xicu",
+               "",
+               "Hora braniega del noroeste de M\u00e9xicu",
+               "",
+               "Hora del noroeste de M\u00e9xicu",
+               "",
+            };
         final String[] DumontDUrville = new String[] {
                "Hora de Dumont-d\u2019Urville",
                "",
@@ -1230,14 +1230,6 @@ public class TimeZoneNames_ast extends TimeZoneNamesBundle {
                "Hora de Samara",
                "",
             };
-        final String[] Pyongyang = new String[] {
-               "hora de Pyongyang",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] India = new String[] {
                "Hora est\u00e1ndar de la India",
                "",
@@ -1277,7 +1269,16 @@ public class TimeZoneNames_ast extends TimeZoneNamesBundle {
             { "America/St_Johns", Newfoundland },
             { "Europe/Paris", Europe_Central },
             { "GMT", GMT },
-            { "Africa/Casablanca", Europe_Western },
+            { "Africa/Casablanca",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                }
+            },
             { "Asia/Jerusalem", Israel },
             { "Asia/Tokyo", Japan },
             { "Europe/Bucharest", Europe_Eastern },
@@ -1361,16 +1362,6 @@ public class TimeZoneNames_ast extends TimeZoneNamesBundle {
             { "Antarctica/McMurdo", New_Zealand },
             { "timezone.excity.America/Nome", "Nome" },
             { "Pacific/Tahiti", Tahiti },
-            { "HST",
-                new String[] {
-                    "Hora est\u00e1ndar de Hawaii-Aleutianes",
-                    "HST",
-                    "Hora braniega de Hawaii-Aleutianes",
-                    "HDT",
-                    "Hora de Hawaii-Aleutianes",
-                    "HST",
-                }
-            },
             { "timezone.excity.America/Vancouver", "Vancouver" },
             { "timezone.excity.America/Matamoros", "Matamoros" },
             { "Africa/Asmera", Africa_Eastern },
@@ -1478,12 +1469,12 @@ public class TimeZoneNames_ast extends TimeZoneNamesBundle {
             { "timezone.excity.America/Sao_Paulo", "Sao Paulo" },
             { "Pacific/Gambier", Gambier },
             { "Africa/Gaborone", Africa_Central },
-            { "Asia/Pyongyang", Pyongyang },
+            { "Asia/Pyongyang", Korea },
             { "timezone.excity.America/New_York", "Nueva York" },
             { "Asia/Gaza", Europe_Eastern },
             { "timezone.excity.Africa/Accra", "Accra" },
             { "timezone.excity.Etc/Unknown", "Ciud\u00e1 desconocida" },
-            { "Asia/Qyzylorda", Kazakhstan_Eastern },
+            { "Asia/Qyzylorda", Kazakhstan_Western },
             { "timezone.excity.America/Thule", "Thule" },
             { "timezone.excity.America/Grand_Turk", "Grand Turk" },
             { "America/Yakutat", Alaska },
@@ -1543,8 +1534,17 @@ public class TimeZoneNames_ast extends TimeZoneNamesBundle {
             { "Asia/Vladivostok", Vladivostok },
             { "timezone.excity.Atlantic/St_Helena", "Santa Lena" },
             { "Africa/Maputo", Africa_Central },
-            { "Africa/El_Aaiun", Europe_Western },
             { "Africa/Ouagadougou", GMT },
+            { "Africa/El_Aaiun",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                }
+            },
             { "timezone.excity.Pacific/Rarotonga", "Rarotonga" },
             { "timezone.excity.Europe/Luxembourg", "Luxemburgu" },
             { "America/Cayman", America_Eastern },
@@ -1700,7 +1700,6 @@ public class TimeZoneNames_ast extends TimeZoneNamesBundle {
             { "timezone.excity.America/Goose_Bay", "Goose Bay" },
             { "timezone.excity.America/Los_Angeles", "Los Angeles" },
             { "timezone.excity.America/Eirunepe", "Eirunepe" },
-            { "MST", America_Mountain },
             { "America/Whitehorse", America_Pacific },
             { "timezone.excity.America/Cuiaba", "Cuiaba" },
             { "Pacific/Noumea", New_Caledonia },
@@ -1908,7 +1907,7 @@ public class TimeZoneNames_ast extends TimeZoneNamesBundle {
                     "",
                 }
             },
-            { "Africa/Sao_Tome", Africa_Western },
+            { "Africa/Sao_Tome", GMT },
             { "Indian/Chagos", Indian_Ocean },
             { "timezone.excity.America/Metlakatla", "Metlakatla" },
             { "Asia/Yakutsk", Yakutsk },
@@ -1932,7 +1931,7 @@ public class TimeZoneNames_ast extends TimeZoneNamesBundle {
             { "America/Metlakatla", Alaska },
             { "timezone.excity.Europe/Athens", "Atenes" },
             { "Africa/Djibouti", Africa_Eastern },
-            { "EST", America_Eastern },
+            { "Asia/Qostanay", Kazakhstan_Eastern },
             { "Europe/Simferopol", Moscow },
             { "Europe/Sofia", Europe_Eastern },
             { "Africa/Nouakchott", GMT },
@@ -1954,7 +1953,7 @@ public class TimeZoneNames_ast extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Jerusalem", "Xerusal\u00e9n" },
             { "Atlantic/Faeroe", Europe_Western },
             { "timezone.excity.Asia/Riyadh", "Riyad" },
-            { "Antarctica/Casey", Casey },
+            { "Antarctica/Casey", Australia_Western },
             { "Europe/Copenhagen", Europe_Central },
             { "timezone.excity.Africa/Bangui", "Bangui" },
             { "timezone.excity.Africa/Lusaka", "Lusaka" },
@@ -2123,7 +2122,7 @@ public class TimeZoneNames_ast extends TimeZoneNamesBundle {
             { "Australia/Brisbane", Australia_Eastern },
             { "Indian/Mayotte", Africa_Eastern },
             { "timezone.excity.Europe/Busingen", "Busingen" },
-            { "Europe/Volgograd", Moscow },
+            { "Europe/Volgograd", Volgograd },
             { "America/Lower_Princes", Atlantic },
             { "timezone.excity.Europe/Istanbul", "Istanbul" },
             { "America/Rio_Branco", Acre },
