@@ -1447,7 +1447,7 @@ public class TimeZoneNames_bs extends TimeZoneNamesBundle {
             { "Australia/Adelaide", Australia_Central },
             { "timezone.excity.America/Lima", "Lima" },
             { "timezone.excity.America/North_Dakota/New_Salem", "New Salem, Sjeverna Dakota" },
-            { "timezone.excity.Asia/Atyrau", "Atyrau" },
+            { "timezone.excity.Asia/Atyrau", "Atiraj" },
             { "America/Paramaribo", Suriname },
             { "timezone.excity.Asia/Bishkek", "Bi\u0161kek" },
             { "America/Indiana/Vincennes", America_Eastern },
@@ -1730,6 +1730,7 @@ public class TimeZoneNames_bs extends TimeZoneNamesBundle {
             { "America/Caracas", Venezuela },
             { "Asia/Hebron", Europe_Eastern },
             { "SystemV/PST8PDT", America_Pacific },
+            { "timezone.excity.Asia/Qostanay", "Kostanaj" },
             { "Africa/Monrovia", GMT },
             { "Asia/Ust-Nera", Vladivostok },
             { "timezone.excity.America/Louisville", "Louisville" },
