@@ -1741,7 +1741,7 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
             { "Asia/Amman", Europe_Eastern },
             { "Etc/UTC",
                 new String[] {
-                    "Ordu Unibertsal Koordinatua",
+                    "ordu unibertsal koordinatua",
                     "UTC",
                     "",
                     "",
