@@ -1464,7 +1464,7 @@ public class TimeZoneNames_in extends TimeZoneNamesBundle {
             { "timezone.excity.America/New_York", "New York" },
             { "Asia/Gaza", Europe_Eastern },
             { "timezone.excity.Africa/Accra", "Accra" },
-            { "timezone.excity.Etc/Unknown", "Tidak Dikenal" },
+            { "timezone.excity.Etc/Unknown", "Kota Tidak Dikenal" },
             { "Asia/Qyzylorda", Kazakhstan_Western },
             { "timezone.excity.America/Thule", "Thule" },
             { "timezone.excity.America/Grand_Turk", "Grand Turk" },
@@ -1519,6 +1519,7 @@ public class TimeZoneNames_in extends TimeZoneNamesBundle {
             { "America/Jamaica", America_Eastern },
             { "Asia/Bishkek", Kyrgystan },
             { "Atlantic/Stanley", Falkland },
+            { "timezone.excity.Europe/Saratov", "Saratov" },
             { "SystemV/CST6", America_Central },
             { "timezone.excity.Pacific/Efate", "Efate" },
             { "timezone.excity.Asia/Aqtobe", "Aktobe" },
@@ -1727,6 +1728,7 @@ public class TimeZoneNames_in extends TimeZoneNamesBundle {
             { "America/Caracas", Venezuela },
             { "Asia/Hebron", Europe_Eastern },
             { "SystemV/PST8PDT", America_Pacific },
+            { "timezone.excity.Asia/Qostanay", "Kostanay" },
             { "Africa/Monrovia", GMT },
             { "Asia/Ust-Nera", Vladivostok },
             { "timezone.excity.America/Louisville", "Louisville" },
