@@ -847,7 +847,7 @@ public class TimeZoneNames_jv extends TimeZoneNamesBundle {
                "",
             };
         final String[] Singapore = new String[] {
-               "Wektu Standar Singapura",
+               "Wektu Singapura",
                "",
                "",
                "",
@@ -1159,7 +1159,7 @@ public class TimeZoneNames_jv extends TimeZoneNamesBundle {
                "",
             };
         final String[] Chamorro = new String[] {
-               "Wektu Standar Chamorro",
+               "Wektu Chamorro",
                "",
                "",
                "",
@@ -1491,7 +1491,7 @@ public class TimeZoneNames_jv extends TimeZoneNamesBundle {
             { "timezone.excity.Pacific/Efate", "Efate" },
             { "timezone.excity.Asia/Aqtobe", "Aqtobe" },
             { "Asia/Vladivostok", Vladivostok },
-            { "timezone.excity.Atlantic/St_Helena", "Saint Helena" },
+            { "timezone.excity.Atlantic/St_Helena", "Santa Helena" },
             { "Africa/Maputo", Africa_Central },
             { "Africa/Ouagadougou", GMT },
             { "Africa/El_Aaiun",
@@ -1698,6 +1698,7 @@ public class TimeZoneNames_jv extends TimeZoneNamesBundle {
             { "America/Caracas", Venezuela },
             { "Asia/Hebron", Europe_Eastern },
             { "SystemV/PST8PDT", America_Pacific },
+            { "timezone.excity.Asia/Qostanay", "Kostanai" },
             { "Africa/Monrovia", GMT },
             { "Asia/Ust-Nera", Vladivostok },
             { "timezone.excity.America/Louisville", "Louisville" },
@@ -1717,7 +1718,7 @@ public class TimeZoneNames_jv extends TimeZoneNamesBundle {
             { "Asia/Amman", Europe_Eastern },
             { "Etc/UTC",
                 new String[] {
-                    "Wektu Kordinat Universal",
+                    "Wektu Universal Kakoordhinasi",
                     "UTC",
                     "",
                     "",
