@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -310,14 +310,6 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
                "Folklenda (Malvinu) salu laiks",
                "",
             };
-        final String[] Bhutan = new String[] {
-               "But\u0101nas laiks",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Apia = new String[] {
                "Apijas ziemas laiks",
                "",
@@ -326,6 +318,14 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
                "Apijas laiks",
                "",
             };
+        final String[] Bhutan = new String[] {
+               "But\u0101nas laiks",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Nauru = new String[] {
                "Nauru laiks",
                "",
@@ -566,12 +566,12 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Colombia = new String[] {
-               "Kolumbijas ziemas laiks",
+        final String[] Australia_Eastern = new String[] {
+               "Austr\u0101lijas austrumu ziemas laiks",
                "",
-               "Kolumbijas vasaras laiks",
+               "Austr\u0101lijas austrumu vasaras laiks",
                "",
-               "Kolumbijas laiks",
+               "Austr\u0101lijas austrumu laiks",
                "",
             };
         final String[] French_Guiana = new String[] {
@@ -582,12 +582,12 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Australia_Eastern = new String[] {
-               "Austr\u0101lijas austrumu ziemas laiks",
+        final String[] Colombia = new String[] {
+               "Kolumbijas ziemas laiks",
                "",
-               "Austr\u0101lijas austrumu vasaras laiks",
+               "Kolumbijas vasaras laiks",
                "",
-               "Austr\u0101lijas austrumu laiks",
+               "Kolumbijas laiks",
                "",
             };
         final String[] Chile = new String[] {
@@ -1046,12 +1046,12 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Mexico_Northwest = new String[] {
-               "Zieme\u013crietumu Meksikas ziemas laiks",
+        final String[] Volgograd = new String[] {
+               "Volgogradas ziemas laiks",
                "",
-               "Zieme\u013crietumu Meksikas vasaras laiks",
+               "Volgogradas vasaras laiks",
                "",
-               "Zieme\u013crietumu Meksikas laiks",
+               "Volgogradas laiks",
                "",
             };
         final String[] Easter = new String[] {
@@ -1062,6 +1062,14 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
                "Lieldienu salas laiks",
                "",
             };
+        final String[] Mexico_Northwest = new String[] {
+               "Zieme\u013crietumu Meksikas ziemas laiks",
+               "",
+               "Zieme\u013crietumu Meksikas vasaras laiks",
+               "",
+               "Zieme\u013crietumu Meksikas laiks",
+               "",
+            };
         final String[] DumontDUrville = new String[] {
                "Dimondirvilas laiks",
                "",
@@ -1214,14 +1222,6 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
                "Samaras laiks",
                "",
             };
-        final String[] Pyongyang = new String[] {
-               "Phenjanas laiks",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] India = new String[] {
                "Indijas ziemas laiks",
                "",
@@ -1252,7 +1252,16 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             { "America/St_Johns", Newfoundland },
             { "Europe/Paris", Europe_Central },
             { "GMT", GMT },
-            { "Africa/Casablanca", Europe_Western },
+            { "Africa/Casablanca",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                }
+            },
             { "Asia/Jerusalem", Israel },
             { "Asia/Tokyo", Japan },
             { "Europe/Bucharest", Europe_Eastern },
@@ -1336,7 +1345,6 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             { "Antarctica/McMurdo", New_Zealand },
             { "timezone.excity.America/Nome", "Noma" },
             { "Pacific/Tahiti", Tahiti },
-            { "HST", Hawaii_Aleutian },
             { "timezone.excity.America/Vancouver", "Vank\u016bvera" },
             { "timezone.excity.America/Matamoros", "Matamorosa" },
             { "Africa/Asmera", Africa_Eastern },
@@ -1448,12 +1456,12 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             { "timezone.excity.America/Sao_Paulo", "Sanpaulu" },
             { "Pacific/Gambier", Gambier },
             { "Africa/Gaborone", Africa_Central },
-            { "Asia/Pyongyang", Pyongyang },
+            { "Asia/Pyongyang", Korea },
             { "timezone.excity.America/New_York", "\u0145ujorka" },
             { "Asia/Gaza", Europe_Eastern },
             { "timezone.excity.Africa/Accra", "Akra" },
             { "timezone.excity.Etc/Unknown", "nezin\u0101ma pils\u0113ta" },
-            { "Asia/Qyzylorda", Kazakhstan_Eastern },
+            { "Asia/Qyzylorda", Kazakhstan_Western },
             { "timezone.excity.America/Thule", "Tule" },
             { "timezone.excity.America/Grand_Turk", "Grandtk\u0113rka" },
             { "America/Yakutat", Alaska },
@@ -1515,8 +1523,17 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             { "Asia/Vladivostok", Vladivostok },
             { "timezone.excity.Atlantic/St_Helena", "Sv.Hel\u0113nas sala" },
             { "Africa/Maputo", Africa_Central },
-            { "Africa/El_Aaiun", Europe_Western },
             { "Africa/Ouagadougou", GMT },
+            { "Africa/El_Aaiun",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                }
+            },
             { "timezone.excity.Pacific/Rarotonga", "Rarotonga" },
             { "timezone.excity.Europe/Luxembourg", "Luksemburga" },
             { "America/Cayman", America_Eastern },
@@ -1677,7 +1694,6 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             { "timezone.excity.America/Goose_Bay", "G\u016bsbeja" },
             { "timezone.excity.America/Eirunepe", "Eirunepe" },
             { "timezone.excity.America/Los_Angeles", "Losand\u017eelosa" },
-            { "MST", America_Mountain },
             { "America/Whitehorse", America_Pacific },
             { "timezone.excity.America/Cuiaba", "Kujaba" },
             { "Pacific/Noumea", New_Caledonia },
@@ -1714,6 +1730,7 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             { "America/Caracas", Venezuela },
             { "Asia/Hebron", Europe_Eastern },
             { "SystemV/PST8PDT", America_Pacific },
+            { "timezone.excity.Asia/Qostanay", "Kostanaja" },
             { "Africa/Monrovia", GMT },
             { "Asia/Ust-Nera", Vladivostok },
             { "timezone.excity.America/Louisville", "L\u016bivila" },
@@ -1890,7 +1907,7 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
                     "",
                 }
             },
-            { "Africa/Sao_Tome", Africa_Western },
+            { "Africa/Sao_Tome", GMT },
             { "Indian/Chagos", Indian_Ocean },
             { "timezone.excity.America/Metlakatla", "Metlakatla" },
             { "Asia/Yakutsk", Yakutsk },
@@ -1915,8 +1932,8 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             { "America/Metlakatla", Alaska },
             { "timezone.excity.Europe/Athens", "At\u0113nas" },
             { "Africa/Djibouti", Africa_Eastern },
-            { "EST", America_Eastern },
             { "timezone.excity.America/Indiana/Knox", "Noksa, Indi\u0101na" },
+            { "Asia/Qostanay", Kazakhstan_Eastern },
             { "Europe/Simferopol", Moscow },
             { "Europe/Sofia", Europe_Eastern },
             { "Africa/Nouakchott", GMT },
@@ -1938,6 +1955,7 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Jerusalem", "Jeruzaleme" },
             { "Atlantic/Faeroe", Europe_Western },
             { "timezone.excity.Asia/Riyadh", "Rij\u0101da" },
+            { "Antarctica/Casey", Australia_Western },
             { "Europe/Copenhagen", Europe_Central },
             { "timezone.excity.Africa/Bangui", "Bangi" },
             { "timezone.excity.Africa/Lusaka", "Lusaka" },
@@ -2101,7 +2119,7 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             { "Indian/Mayotte", Africa_Eastern },
             { "timezone.excity.America/St_Thomas", "Sentomasa" },
             { "timezone.excity.Europe/Busingen", "B\u012bzingene" },
-            { "Europe/Volgograd", Moscow },
+            { "Europe/Volgograd", Volgograd },
             { "America/Lower_Princes", Atlantic },
             { "timezone.excity.Europe/Istanbul", "Stambula" },
             { "timezone.excity.Europe/Sarajevo", "Sarajeva" },
