@@ -1429,8 +1429,8 @@ public class TimeZoneNames_nb extends TimeZoneNamesBundle {
             { "America/Indiana/Vevay", America_Eastern },
             { "timezone.excity.America/Grenada", "Grenada" },
             { "timezone.excity.Asia/Phnom_Penh", "Phnom Penh" },
-            { "timezone.excity.Europe/Rome", "Roma" },
             { "timezone.excity.Asia/Hebron", "Hebron" },
+            { "timezone.excity.Europe/Rome", "Roma" },
             { "Asia/Jakarta", Indonesia_Western },
             { "timezone.excity.Antarctica/Mawson", "Mawson" },
             { "timezone.excity.Asia/Karachi", "Karachi" },
@@ -1691,8 +1691,8 @@ public class TimeZoneNames_nb extends TimeZoneNamesBundle {
             { "timezone.excity.Africa/Maputo", "Maputo" },
             { "timezone.excity.Africa/Luanda", "Luanda" },
             { "timezone.excity.America/Goose_Bay", "Goose Bay" },
-            { "timezone.excity.America/Eirunepe", "Eirunepe" },
             { "timezone.excity.America/Los_Angeles", "Los Angeles" },
+            { "timezone.excity.America/Eirunepe", "Eirunepe" },
             { "America/Whitehorse", America_Pacific },
             { "timezone.excity.America/Cuiaba", "Cuiab\u00e1" },
             { "Pacific/Noumea", New_Caledonia },
@@ -1729,7 +1729,7 @@ public class TimeZoneNames_nb extends TimeZoneNamesBundle {
             { "America/Caracas", Venezuela },
             { "Asia/Hebron", Europe_Eastern },
             { "SystemV/PST8PDT", America_Pacific },
-            { "timezone.excity.Asia/Qostanay", "Kostanay" },
+            { "timezone.excity.Asia/Qostanay", "Kostanaj" },
             { "Africa/Monrovia", GMT },
             { "Asia/Ust-Nera", Vladivostok },
             { "timezone.excity.America/Louisville", "Louisville" },
@@ -1778,8 +1778,8 @@ public class TimeZoneNames_nb extends TimeZoneNamesBundle {
             { "Pacific/Rarotonga", Cook },
             { "America/Guatemala", America_Central },
             { "Australia/Hobart", Australia_Eastern },
-            { "timezone.excity.Europe/Skopje", "Skopje" },
             { "timezone.excity.America/Chihuahua", "Chihuahua" },
+            { "timezone.excity.Europe/Skopje", "Skopje" },
             { "America/Belize", America_Central },
             { "America/Managua", America_Central },
             { "America/Indiana/Petersburg", America_Eastern },
@@ -1860,8 +1860,8 @@ public class TimeZoneNames_nb extends TimeZoneNamesBundle {
             { "America/Havana", Cuba },
             { "timezone.excity.America/Edmonton", "Edmonton" },
             { "timezone.excity.Africa/Sao_Tome", "S\u00e3o Tom\u00e9" },
-            { "timezone.excity.America/Dawson", "Dawson" },
             { "timezone.excity.Africa/Abidjan", "Abidjan" },
+            { "timezone.excity.America/Dawson", "Dawson" },
             { "America/Barbados", Atlantic },
             { "timezone.excity.America/Guadeloupe", "Guadeloupe" },
             { "timezone.excity.Africa/Freetown", "Freetown" },
@@ -2072,8 +2072,8 @@ public class TimeZoneNames_nb extends TimeZoneNamesBundle {
             { "timezone.excity.Africa/Blantyre", "Blantyre" },
             { "timezone.excity.Europe/Malta", "Malta" },
             { "Pacific/Tarawa", Gilbert_Islands },
-            { "timezone.excity.Australia/Sydney", "Sydney" },
             { "timezone.excity.Asia/Qatar", "Qatar" },
+            { "timezone.excity.Australia/Sydney", "Sydney" },
             { "timezone.excity.America/Sitka", "Sitka" },
             { "SystemV/EST5", America_Eastern },
             { "timezone.excity.Antarctica/Davis", "Davis" },
@@ -2128,8 +2128,8 @@ public class TimeZoneNames_nb extends TimeZoneNamesBundle {
             { "Asia/Kamchatka", Kamchatka },
             { "timezone.excity.Asia/Samarkand", "Samarkand" },
             { "Africa/Khartoum", Africa_Central },
-            { "timezone.excity.Australia/Adelaide", "Adelaide" },
             { "timezone.excity.Asia/Singapore", "Singapore" },
+            { "timezone.excity.Australia/Adelaide", "Adelaide" },
             { "Europe/Belgrade", Europe_Central },
             { "timezone.excity.Europe/Vienna", "Wien" },
             { "Africa/Bissau", GMT },
@@ -2162,8 +2162,8 @@ public class TimeZoneNames_nb extends TimeZoneNamesBundle {
             { "timezone.excity.Pacific/Tongatapu", "Tongatapu" },
             { "timezone.excity.Antarctica/Syowa", "Syowa" },
             { "timezone.excity.America/Jamaica", "Jamaica" },
-            { "timezone.excity.America/Hermosillo", "Hermosillo" },
             { "timezone.excity.Pacific/Funafuti", "Funafuti" },
+            { "timezone.excity.America/Hermosillo", "Hermosillo" },
             { "timezone.excity.Europe/Podgorica", "Podgorica" },
             { "timezone.excity.Indian/Reunion", "R\u00e9union" },
             { "timezone.excity.Pacific/Noumea", "Noum\u00e9a" },
@@ -2216,8 +2216,8 @@ public class TimeZoneNames_nb extends TimeZoneNamesBundle {
             },
             { "Asia/Anadyr", Anadyr },
             { "timezone.excity.Indian/Chagos", "Chagos" },
-            { "timezone.excity.Asia/Kabul", "Kabul" },
             { "timezone.excity.America/Iqaluit", "Iqaluit" },
+            { "timezone.excity.Asia/Kabul", "Kabul" },
             { "America/Winnipeg", America_Central },
             { "timezone.excity.Europe/Amsterdam", "Amsterdam" },
             { "timezone.excity.Atlantic/Bermuda", "Bermuda" },
