@@ -71,11 +71,11 @@ public class TimeZoneNames_qu_BO extends TimeZoneNamesBundle {
     @Override
     protected final Object[][] getContents() {
         final String[] Peru = new String[] {
-               "",
+               "Hora Estandar de Per\u00fa",
                "\u2205\u2205\u2205",
-               "",
+               "Hora de Verano de Per\u00fa",
                "\u2205\u2205\u2205",
-               "",
+               "Hora de Per\u00fa",
                "\u2205\u2205\u2205",
             };
         final String[] Bolivia = new String[] {
