@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -599,7 +599,7 @@ public class TimeZoneNames_tk extends TimeZoneNamesBundle {
                "",
             };
         final String[] Gilbert_Islands = new String[] {
-               "Gilberta adalary wagty",
+               "Gilbert adalary wagty",
                "",
                "",
                "",
@@ -1331,13 +1331,12 @@ public class TimeZoneNames_tk extends TimeZoneNamesBundle {
             { "America/Catamarca", Argentina },
             { "America/Godthab", Greenland_Western },
             { "timezone.excity.America/St_Lucia", "Sent-L\u00fdusi\u00fda" },
-            { "timezone.excity.Asia/Novokuznetsk", "Nowokuznetsk" },
+            { "timezone.excity.Asia/Novokuznetsk", "Nowokuznesk" },
             { "timezone.excity.Europe/Berlin", "Berlin" },
             { "Africa/Lagos", Africa_Western },
             { "timezone.excity.Pacific/Midway", "Midue\u00fd" },
             { "Europe/Rome", Europe_Central },
             { "Indian/Mauritius", Mauritius },
-            { "timezone.excity.America/Godthab", "Nuk" },
             { "timezone.excity.America/Martinique", "Martinika" },
             { "America/Dawson_Creek", America_Mountain },
             { "America/St_Thomas", Atlantic },
@@ -1345,7 +1344,6 @@ public class TimeZoneNames_tk extends TimeZoneNamesBundle {
             { "Asia/Dili", East_Timor },
             { "timezone.excity.Australia/Perth", "Pert" },
             { "Africa/Bamako", GMT },
-            { "timezone.excity.Africa/Asmera", "Asmera" },
             { "timezone.excity.Arctic/Longyearbyen", "Longir" },
             { "Pacific/Wallis", Wallis },
             { "timezone.excity.America/Tegucigalpa", "Tegusigalpa" },
@@ -1406,7 +1404,7 @@ public class TimeZoneNames_tk extends TimeZoneNamesBundle {
             { "Asia/Jakarta", Indonesia_Western },
             { "timezone.excity.Antarctica/Mawson", "Mouson" },
             { "timezone.excity.Asia/Karachi", "Kara\u00e7i" },
-            { "timezone.excity.America/Resolute", "Rozul\u00fdut" },
+            { "timezone.excity.America/Resolute", "Rezol\u00fdut" },
             { "timezone.excity.Africa/Nouakchott", "Nuak\u015fot" },
             { "timezone.excity.Africa/Bamako", "Bamako" },
             { "timezone.excity.America/Argentina/Salta", "Salta" },
@@ -1442,7 +1440,6 @@ public class TimeZoneNames_tk extends TimeZoneNamesBundle {
             { "timezone.excity.America/Grand_Turk", "Grand-Terk" },
             { "America/Yakutat", Alaska },
             { "Europe/Vienna", Europe_Central },
-            { "timezone.excity.America/Winnipeg", "Winipeg" },
             { "timezone.excity.Antarctica/Macquarie", "Makkuori" },
             { "timezone.excity.Europe/Uzhgorod", "U\u017egorod" },
             { "timezone.excity.America/Caracas", "Karakas" },
@@ -1704,6 +1701,7 @@ public class TimeZoneNames_tk extends TimeZoneNamesBundle {
             { "America/Caracas", Venezuela },
             { "Asia/Hebron", Europe_Eastern },
             { "SystemV/PST8PDT", America_Pacific },
+            { "timezone.excity.Asia/Qostanay", "Kostana\u00fd" },
             { "Africa/Monrovia", GMT },
             { "Asia/Ust-Nera", Vladivostok },
             { "timezone.excity.America/Louisville", "Luiswill" },
@@ -1785,7 +1783,7 @@ public class TimeZoneNames_tk extends TimeZoneNamesBundle {
             { "Asia/Dubai", Gulf },
             { "Europe/Isle_of_Man", GMT },
             { "America/Araguaina", Brasilia },
-            { "timezone.excity.Pacific/Easter", "Pashi adasy" },
+            { "timezone.excity.Pacific/Easter", "Pasha adasy" },
             { "Asia/Novosibirsk", Novosibirsk },
             { "Africa/Tunis", Europe_Central },
             { "Pacific/Fakaofo", Tokelau },
@@ -2070,7 +2068,7 @@ public class TimeZoneNames_tk extends TimeZoneNamesBundle {
             { "timezone.excity.America/Argentina/La_Rioja", "La-Rioha" },
             { "Africa/Luanda", Africa_Western },
             { "timezone.excity.Europe/Mariehamn", "Mari\u00fdehamn" },
-            { "timezone.excity.America/St_Johns", "Sent-D\u017eons" },
+            { "timezone.excity.America/St_Johns", "Sent-Jons" },
             { "timezone.excity.America/St_Barthelemy", "Sen-Bartelemi" },
             { "timezone.excity.America/Santiago", "Sant\u00fdago" },
             { "Asia/Muscat", Gulf },
@@ -2169,7 +2167,7 @@ public class TimeZoneNames_tk extends TimeZoneNamesBundle {
             { "Europe/Bratislava", Europe_Central },
             { "timezone.excity.Atlantic/Stanley", "Stenli" },
             { "Pacific/Tongatapu", Tonga },
-            { "timezone.excity.Asia/Rangoon", "Rangun" },
+            { "timezone.excity.Asia/Rangoon", "\u00ddangon" },
             { "timezone.excity.Asia/Thimphu", "Timpu" },
             { "Europe/Ulyanovsk",
                 new String[] {
